[all-commits] [llvm/llvm-project] 0852ac: [PowerPC] Remove itinerary IIC_LdStDCBA (#207227)

Alexey Bataev via All-commits all-commits at lists.llvm.org
Fri Jul 17 13:20:13 PDT 2026


  Branch: refs/heads/users/alexey-bataev/spr/slp-gather-operands-of-associative-binary-chains-into-one-node
  Home:   https://github.com/llvm/llvm-project
  Commit: 0852ac5649a0ac6959af6fbc2e4cf6cf4bad7238
      https://github.com/llvm/llvm-project/commit/0852ac5649a0ac6959af6fbc2e4cf6cf4bad7238
  Author: Kai Nacke <kai.peter.nacke at ibm.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/PowerPC/PPCSchedule.td
    M llvm/lib/Target/PowerPC/PPCSchedule440.td
    M llvm/lib/Target/PowerPC/PPCScheduleA2.td
    M llvm/lib/Target/PowerPC/PPCScheduleE500.td
    M llvm/lib/Target/PowerPC/PPCScheduleE500mc.td
    M llvm/lib/Target/PowerPC/PPCScheduleE5500.td
    M llvm/lib/Target/PowerPC/PPCScheduleG3.td

  Log Message:
  -----------
  [PowerPC] Remove itinerary IIC_LdStDCBA (#207227)

The itinerary IIC_LdStDCBA is defined and used in scheduling models, but
no instruction is assigned to it. However, since the instruction is
basically retired (not part of the portable Power ISA), and all
scheduling models model it similar to IIC_LdStDCBF, the itinerary can be
removed.


  Commit: 96cab305c0402e051d16e748911bd469b4ad57fe
      https://github.com/llvm/llvm-project/commit/96cab305c0402e051d16e748911bd469b4ad57fe
  Author: Robert Imschweiler <robert.imschweiler at amd.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/IR/VerifierAMDGPU.cpp
    M llvm/test/Assembler/callbr.ll

  Log Message:
  -----------
  [AMDGPU] Improve amdgcn_kill verification (#208220)


  Commit: 8c22bbde747ce8c577318c3fb6cafaae6f1b8aec
      https://github.com/llvm/llvm-project/commit/8c22bbde747ce8c577318c3fb6cafaae6f1b8aec
  Author: Craig Topper <craig.topper at sifive.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/RISCV/RISCVISelLowering.cpp

  Log Message:
  -----------
  [RISCV][P-ext] Replace lowerBuildVectorAsRV32PNarrowingShift with shuffle lowering. (#209088)

Add an implementation of isExtractSubvectorCheap for extracting
v2i16/v4i8 from a v4i16/v8i8 vector on RV32. This allows the
build_vector+extract_elt pattern to be turned into
shuffle_vector+extract_subvectors.

Assisted-by: Claude


  Commit: 00674044ab7111ce25ac9a613fefeace7dff1125
      https://github.com/llvm/llvm-project/commit/00674044ab7111ce25ac9a613fefeace7dff1125
  Author: Benjamin Jurk <106487517+bnjmnjrk at users.noreply.github.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/include/llvm/IR/PatternMatch.h
    M llvm/lib/Transforms/InstCombine/InstCombineCasts.cpp
    M llvm/unittests/IR/PatternMatch.cpp

  Log Message:
  -----------
  [PatternMatch] Add m_SpecificType(Type*) matcher (#208427)

Fixes #208401.


  Commit: d333df5aeb31ecf867e1a7908a7814485f4aa7f0
      https://github.com/llvm/llvm-project/commit/d333df5aeb31ecf867e1a7908a7814485f4aa7f0
  Author: aokblast <aokblast at FreeBSD.org>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M lldb/source/Target/Target.cpp

  Log Message:
  -----------
  [LLDB] Print stderr in HandleStop (#208875)

There are some testcases silently fail in stopping hook without
returning anything on FreeBSD. We dump the error from the handler to
make it easier to debug.


  Commit: 7fc7d8d5d2c10db1cff7f53175ad4cb158f0890d
      https://github.com/llvm/llvm-project/commit/7fc7d8d5d2c10db1cff7f53175ad4cb158f0890d
  Author: forking-google-bazel-bot[bot] <265904573+forking-google-bazel-bot[bot]@users.noreply.github.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M utils/bazel/llvm-project-overlay/libc/BUILD.bazel

  Log Message:
  -----------
  [Bazel] Fixes e3d3b3b (#210068)

This fixes e3d3b3b0cf3672480d6f781a9726cec1e7983d14.

Buildkite error link:
https://buildkite.com/llvm-project/upstream-bazel/builds?commit=e3d3b3b0cf3672480d6f781a9726cec1e7983d14

Co-authored-by: Google Bazel Bot <google-bazel-bot at google.com>


  Commit: 638d6736400891b03f211487ccb643a49f14f743
      https://github.com/llvm/llvm-project/commit/638d6736400891b03f211487ccb643a49f14f743
  Author: Zeyi Xu <mitchell.xu2 at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/lib/Sema/SemaLifetimeSafety.h
    A clang/test/Sema/LifetimeSafety/annotation-suggestions-fixits.c

  Log Message:
  -----------
  [LifetimeSafety] Add better lifetimebound fix-it spelling for C (#209967)

Use `__attribute__((lifetimebound))` as the default lifetimebound fix-it
spelling in pre-C23 C.
C++ and C23 continue to use `[[clang::lifetimebound]]` as the default
spelling.

When no explicit lifetimebound macro is configured, pre-C23 C only looks
for `__attribute__((lifetimebound))`, C++ and C23 keep looking for
`[[clang::lifetimebound]]` macros first, then
`__attribute__((lifetimebound))`.

Follow up of https://github.com/llvm/llvm-project/pull/204045


  Commit: 9ec7974432975674b0128ea85a54cb3e5b0ffa75
      https://github.com/llvm/llvm-project/commit/9ec7974432975674b0128ea85a54cb3e5b0ffa75
  Author: LU-JOHN <John.Lu at amd.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/CMakeLists.txt

  Log Message:
  -----------
  [AMDGPU] Update libc/runtime target to use amdgpu (#210032)

Update libc/runtime targets to use "amdgpu" instead of "amdgcn". This
change is necessary to do libc testing with a
check-libc-amdgpu-amd-amdhsa target. The previous
check-libc-amdgcn-amd-amdhsa target already stopped working after
https://github.com/llvm/llvm-project/pull/209247.

Signed-off-by: John Lu <John.Lu at amd.com>


  Commit: dfa1360735f5a834ce96c8c63594e2cdc3bfe0ea
      https://github.com/llvm/llvm-project/commit/dfa1360735f5a834ce96c8c63594e2cdc3bfe0ea
  Author: Ayokunle Amodu <ayokunle321 at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/lib/CIR/CodeGen/CIRGenBuiltinAMDGPU.cpp
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn-gfx1250.hip
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn-vi-f16.hip
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn.hip

  Log Message:
  -----------
  [CIR][AMDGPU] Add support for AMDGCN cos builtins (#197806)

Adds codegen for the following AMDGCN cos builtins:

- __builtin_amdgcn_cosf (float)
- __builtin_amdgcn_cosh (half)
- __builtin_amdgcn_cos_bf16 (bfloat16)

These are lowered to the corresponding `llvm.amdgcn.cos` intrinsic.


  Commit: 8f0a479f46c98e1a098319786d0848e4b9e0a98d
      https://github.com/llvm/llvm-project/commit/8f0a479f46c98e1a098319786d0848e4b9e0a98d
  Author: jandrovins <46629861+jandrovins at users.noreply.github.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/IPO/Instrumentor.cpp
    A llvm/test/Instrumentation/Instrumentor/load_store_gpu_ind.json
    A llvm/test/Instrumentation/Instrumentor/load_store_gpu_ind.ll

  Log Message:
  -----------
  [Instrumentor] Fix indirect arguments on gpu targets (#209835)

When an argument is passed indirectly,
`IRTCallDescription::createLLVMCall` spills it into a temporary alloca
and passes that alloca address to the runtime call. The alloca is
created in the target's alloca address space. On GPUs it is not address
space 0, which is what the runtime expects for indirect parameters. The
alloca pointer was passed as the argument, so its type didn't match the
call's declared parameter type, causing a "bad signature" assertion in
`CallInst::init` when instrumenting GPU code that requires indirection.
The solution is therefore to cast this pointer to address space 0 before
passing it the the instrumentor call.


  Commit: 689fa1d6d74a465130ad0b1705813e14d1cd5b1a
      https://github.com/llvm/llvm-project/commit/689fa1d6d74a465130ad0b1705813e14d1cd5b1a
  Author: Hardik Kumar <hardikxk at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/include/clang/AST/CommentLexer.h

  Log Message:
  -----------
  Fix Unintialised char *CommentLexer resulting in potential UB. (#210067)

The patch intialised the  pointer to a .
Previously the pointer would have some garbage value which might have
resulted in UB.

closes #210034


  Commit: f57bdc62619417a2ee9076ac05db9d115c3ba464
      https://github.com/llvm/llvm-project/commit/f57bdc62619417a2ee9076ac05db9d115c3ba464
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Scalar/ConstraintElimination.cpp
    A llvm/test/Transforms/ConstraintElimination/and-negative.ll
    M llvm/test/Transforms/PhaseOrdering/constraint-eliminiation-interactions.ll

  Log Message:
  -----------
  [ConstraintElim] Handle (X & Y) <s 0 as X <s 0 && Y <s 0. (#210033)

InstCombine canonicalizes X <s 0 && Y <s 0 as (X & Y) <s 0. Teach
ConstraintElimination to recover the signed-negative information by
looking through compares of binary ANDs.

Alive2 Proof: https://alive2.llvm.org/ce/z/R6DWqD

Depends on https://github.com/llvm/llvm-project/pull/209743 

PR: https://github.com/llvm/llvm-project/pull/210033


  Commit: c9ec54a8a781166546c1001a8bfb2448fbacda44
      https://github.com/llvm/llvm-project/commit/c9ec54a8a781166546c1001a8bfb2448fbacda44
  Author: Craig Topper <craig.topper at sifive.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/RISCV/RISCVInstrInfo.cpp
    M llvm/test/CodeGen/RISCV/rvp-simd-64.ll

  Log Message:
  -----------
  [RISCV] Add DUMMY_REG_PAIR_WITH_X0->GPR copy to copyPhysReg. (#209964)

The register coalescer can convert (extract_subreg x0_pair, sub_gpr_odd)
to a read of DUMMY_REG_PAIR_WITH_X0. This patch treats it the same as a
copy from X0.

I don't know if this is a good long term fix, but I think it's ok for
now. I will continue to look for other options.


  Commit: a5b70908d9cacd0aa1c918c920e8a6118b4340ce
      https://github.com/llvm/llvm-project/commit/a5b70908d9cacd0aa1c918c920e8a6118b4340ce
  Author: Shilei Tian <i at tianshilei.me>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/include/clang/Basic/BuiltinsAMDGPU.td
    M clang/test/CodeGen/amdgpu-builtin-is-invocable.c
    M clang/test/CodeGen/amdgpu-builtin-processor-is.c
    M clang/test/CodeGenCXX/dynamic-cast-address-space.cpp
    M llvm/include/llvm/IR/IntrinsicsAMDGPU.td
    M llvm/lib/Target/AMDGPU/AMDGPU.td
    M llvm/lib/Target/AMDGPU/AMDGPUInstructionSelector.cpp
    M llvm/lib/Target/AMDGPU/AMDGPULegalizerInfo.cpp
    M llvm/lib/Target/AMDGPU/AsmParser/AMDGPUAsmParser.cpp
    M llvm/lib/Target/AMDGPU/GCNSubtarget.h
    M llvm/lib/Target/AMDGPU/MIMGInstructions.td
    M llvm/lib/Target/AMDGPU/SIISelLowering.cpp
    M llvm/lib/Target/AMDGPU/Utils/AMDGPUBaseInfo.cpp
    M llvm/lib/Target/AMDGPU/Utils/AMDGPUBaseInfo.h
    M llvm/lib/Target/AMDGPU/VOP3Instructions.td
    M llvm/lib/TargetParser/AMDGPUTargetParser.cpp
    M llvm/test/CodeGen/AMDGPU/GlobalISel/inst-select-amdgcn.exp.compr.mir
    M llvm/test/CodeGen/AMDGPU/GlobalISel/llvm.amdgcn.intersect_ray.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.dual_intersect_ray.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.exp.compr.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.fma.legacy.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.intersect_ray.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.mov.dpp8.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.permlane.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.sudot4.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.sudot8.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.tanh.ll
    M llvm/test/CodeGen/AMDGPU/s-wakeup-barrier.ll
    M llvm/test/CodeGen/AMDGPU/unsupported-av-load.ll
    M llvm/test/CodeGen/AMDGPU/unsupported-av-store.ll

  Log Message:
  -----------
  [AMDGPU] Guard more intrinsics with target features (#203956)


  Commit: 53dae32b8a3e973a1677bd2745b9128741d69f59
      https://github.com/llvm/llvm-project/commit/53dae32b8a3e973a1677bd2745b9128741d69f59
  Author: Kseniya Tikhomirova <kseniya.tikhomirova at intel.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M libsycl/include/sycl/__impl/queue.hpp

  Log Message:
  -----------
  [libsycl] fix nd_range template resolution (#210081)

Signed-off-by: Tikhomirova, Kseniya <kseniya.tikhomirova at intel.com>


  Commit: d76f5249eaca89f73ff8e55783153a8376938abf
      https://github.com/llvm/llvm-project/commit/d76f5249eaca89f73ff8e55783153a8376938abf
  Author: Charles Zablit <c_zablit at apple.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M lldb/tools/lldb-server/lldb-gdbserver.cpp

  Log Message:
  -----------
  [lldb][Windows] Don't let the inferior inherit the --pipe handle (#207024)

`lldb-server` writes its listening socket id to the `--pipe` handle and
then closes it. The parent process that spawned it reads the pipe until
EOF purely as a synchronization point (`"the server is now listening"`).

On Windows the inferior is launched with `bInheritHandles=TRUE` (it
needs the ConPTY handles), so it also inherited the pipe's write end.
That kept the write end open after `lldb-server` closed its own handle,
so the parent never saw EOF: it blocked until its read timeout and the
client's connection handshake timed out first.

This patch clears `HANDLE_FLAG_INHERIT` on the `--pipe` handle so the
inferior cannot keep the write end open, while leaving it valid for
lldb-server's own use.

rdar://180736036


  Commit: 694c561cf73e81943395e18b2d96621baf68efe5
      https://github.com/llvm/llvm-project/commit/694c561cf73e81943395e18b2d96621baf68efe5
  Author: Fangrui Song <i at maskray.me>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/include/llvm/ADT/GenericCycleImpl.h
    M llvm/include/llvm/ADT/GenericCycleInfo.h
    M llvm/lib/Transforms/Utils/FixIrreducible.cpp

  Log Message:
  -----------
  [CycleInfo] Store cycles in a flat preorder array. NFC (#209981)

Store cycles by value in one array in cycle-forest preorder, each cycle
immediately followed by its descendants, instead of heap-allocating each
cycle and holding its children in a std::vector<std::unique_ptr<>>.
Child and top-level iteration become pointer arithmetic that skips a
subtree via a new NumDescendants count, and sizeof(GenericCycle) drops
from 72 to 48. GenericCycleInfoCompute builds the forest with temporary
nodes, then flatten() moves it into the array.

GenericCycle still exposes raw pointers into this array. The eventual
goal is to replace them with an opaque handle, so all access goes
through GenericCycleInfo and the storage stays an implementation detail.

Aided by Fable 5


  Commit: 16c6374250a465204e067b518577a2b4fd655f93
      https://github.com/llvm/llvm-project/commit/16c6374250a465204e067b518577a2b4fd655f93
  Author: Tom Stellard <tstellar at redhat.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M .github/workflows/llvm-abi-tests.yml

  Log Message:
  -----------
  workflows/llvm-abi-tests: Fix typo (#209917)

Introduced by 9bd8bbb2b76c55ca83ddb6e0aa8a3a79b65706d4.


  Commit: be1728c99d806654d4ce4e7ad17aa89885e8053c
      https://github.com/llvm/llvm-project/commit/be1728c99d806654d4ce4e7ad17aa89885e8053c
  Author: Rithik Sharma <rithiksh02 at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/include/clang/CIR/Dialect/IR/CIRAttrs.td
    M clang/include/clang/CIR/Dialect/IR/CIROps.td
    A clang/include/clang/CIR/Dialect/IR/CIRStdOps.td
    M clang/include/clang/CIR/Dialect/Passes.h
    M clang/lib/CIR/CodeGen/CIRGenClass.cpp
    M clang/lib/CIR/CodeGen/CIRGenFunction.cpp
    M clang/lib/CIR/CodeGen/CIRGenModule.cpp
    M clang/lib/CIR/CodeGen/CIRGenModule.h
    M clang/lib/CIR/Dialect/IR/CIRDialect.cpp
    M clang/lib/CIR/Dialect/Transforms/IdiomRecognizer.cpp
    M clang/lib/CIR/Dialect/Transforms/LoweringPrepare.cpp
    M clang/lib/CIR/Lowering/CIRPasses.cpp
    A clang/test/CIR/CodeGen/func-identity-attr.c
    A clang/test/CIR/CodeGen/func-identity-attr.cpp
    A clang/test/CIR/IR/func-identity-attr.cir
    A clang/test/CIR/Transforms/idiom-recognizer-guards-void-result.cpp
    A clang/test/CIR/Transforms/idiom-recognizer-guards.cpp
    A clang/test/CIR/Transforms/idiom-recognizer-inline-namespace.cpp
    A clang/test/CIR/Transforms/idiom-recognizer.cir
    M clang/test/CIR/Transforms/idiom-recognizer.cpp
    M clang/tools/cir-opt/cir-opt.cpp

  Log Message:
  -----------
  [CIR] Add support for the IdiomRecognizer pass (#208854)

This patch adds the `IdiomRecognizer` pass, which raises calls to known
standard library functions into dedicated operations that later passes
can optimize. The implementation follows the ClangIR incubator, and
upstream had only the pass skeleton and the frontend wiring.

The pass recognizes the standard find algorithm and raises it to the new
operation `cir.std.find`. A call is raised when its callee carries the
matching identity tag, the argument count and the types line up, the
callee is not variadic, and the call is not `musttail`. LoweringPrepare
lowers the operation back to the original call with its attributes, so
behavior never changes when no transform fires.

The tag is the new `func_identity` form under the `func_info` union on
`cir.func`. It holds one entry from an enum naming the entities the
recognizer knows, so the tag itself carries no names. `CIRGen` attaches
it by the plain name, the std membership with inline namespaces looked
through, and whether the function is free, so members, static members,
operators, and functions outside std never match, while the recognizer
checks the shape of each call.

The pass reads facts from the operations alone, so the AST requirement
and its wiring are gone, the pass is registered with `cir-opt`, and a
test drives it over parsed CIR assembly.


  Commit: 3736a7bed1baae7c4b461062f89ddd76f799480d
      https://github.com/llvm/llvm-project/commit/3736a7bed1baae7c4b461062f89ddd76f799480d
  Author: Ilia Kuklin <ikuklin at accesssoftek.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M lldb/docs/dil-expr-lang.ebnf
    M lldb/source/ValueObject/DILEval.cpp
    M lldb/test/API/commands/frame/var-dil/expr/Literals/TestFrameVarDILLiterals.py
    M lldb/test/API/commands/frame/var-dil/expr/Literals/main.cpp
    A lldb/test/API/commands/frame/var-dil/expr/NullptrVar/Makefile
    A lldb/test/API/commands/frame/var-dil/expr/NullptrVar/TestFrameVarDILNullptrVar.py
    A lldb/test/API/commands/frame/var-dil/expr/NullptrVar/main.c

  Log Message:
  -----------
  [lldb] Add `nullptr` literal to DIL (#208831)

DIL will first attempt resolving `nullptr` as a variable, and if there
is none, `nullptr` will be resolved as a null pointer.


  Commit: ab5e01593562aa25bd104118ff42192d4a6ea80f
      https://github.com/llvm/llvm-project/commit/ab5e01593562aa25bd104118ff42192d4a6ea80f
  Author: Fangrui Song <i at maskray.me>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/include/llvm/ADT/GenericCycleImpl.h
    M llvm/include/llvm/ADT/GenericCycleInfo.h
    M llvm/include/llvm/ADT/GenericUniformityImpl.h
    M llvm/include/llvm/IR/GenericConvergenceVerifierImpl.h
    M llvm/lib/CodeGen/MachineCycleAnalysis.cpp
    M llvm/lib/CodeGen/MachineSink.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUGlobalISelDivergenceLowering.cpp
    M llvm/lib/Target/AMDGPU/SIInstrInfo.cpp
    M llvm/lib/Target/AMDGPU/SILowerSGPRSpills.cpp
    M llvm/lib/Transforms/IPO/AttributorAttributes.cpp
    M llvm/lib/Transforms/Utils/FixIrreducible.cpp

  Log Message:
  -----------
  [CycleInfo] Move cycle accessors to GenericCycleInfo. NFC (#209990)

Move member functions off GenericCycle onto GenericCycleInfo.
GenericCycle now holds only data and the child-iterator type, and all
cycle queries go through GenericCycleInfo. This prepares replacing the
GenericCycle pointer with an opaque handle.

Aided by Claude Opus 4.8


  Commit: 0d37efa88b64ee83230599c13587b06ec43e06c0
      https://github.com/llvm/llvm-project/commit/0d37efa88b64ee83230599c13587b06ec43e06c0
  Author: Matt Arsenault <Matthew.Arsenault at amd.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/SPIRV/SPIRVPrepareFunctions.cpp

  Log Message:
  -----------
  SPIRV: Fix constructing temporary TTI in SPIRVPrepareFunctions (#209977)

Passes should obtain TargetTransformInfo from the analysis manager
and never construct one. It may contain pipeline configuration state
(e.g., TargetLibraryInfo).

Co-authored-by: Claude (Claude Opus 4.8) <noreply at anthropic.com>


  Commit: 4a578be311736c684214e87aa07800cd76dd2471
      https://github.com/llvm/llvm-project/commit/4a578be311736c684214e87aa07800cd76dd2471
  Author: Matt Arsenault <Matthew.Arsenault at amd.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/PowerPC/PPCTargetTransformInfo.cpp

  Log Message:
  -----------
  PPC: Avoid constructing TargetTransformInfo in isHardwareLoopProfitable (#209972)

PPCTTIImpl::isHardwareLoopProfitable constructed a throwaway
TargetTransformInfo only to call CodeMetrics::analyzeBasicBlock. TTI
may contain pipeline configuration state, and should only be queried
from the PassManager. It was also particularly ugly to construct one
here given that we're inside a TTIImpl.

Most of what analyzeBasicBlock computes was not used here. Directly
sum the instruction code size costs, which was the only used component
of the analysis.

Co-authored-by: Claude (Claude Opus 4.8) <noreply at anthropic.com>


  Commit: 2fc864be4c7b254d61a0d2c397660951ac108cb7
      https://github.com/llvm/llvm-project/commit/2fc864be4c7b254d61a0d2c397660951ac108cb7
  Author: Matt Arsenault <Matthew.Arsenault at amd.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/unittests/Frontend/OpenMPIRBuilderTest.cpp
    M llvm/unittests/FuzzMutate/StrategiesTest.cpp
    M llvm/unittests/Target/AMDGPU/AMDGPUMCExprTest.cpp
    M llvm/unittests/Target/AMDGPU/AMDGPUUnitTests.cpp
    M llvm/unittests/Target/AMDGPU/AMDGPUUnitTests.h
    M llvm/unittests/Target/AMDGPU/CSETest.cpp
    M llvm/unittests/Target/AMDGPU/DwarfRegMappings.cpp
    M llvm/unittests/Target/AMDGPU/ExecMayBeModifiedBeforeAnyUse.cpp
    M llvm/unittests/Target/AMDGPU/PALMetadata.cpp
    M llvm/unittests/Target/AMDGPU/UniformityAnalysisTest.cpp
    M llvm/unittests/Transforms/Utils/CodeExtractorTest.cpp

  Log Message:
  -----------
  AMDGPU: Use subarch triples in more unit tests (#210011)

Avoid looking up the target by the cpu name with the legacy
amdgcn name.

Co-authored-by: Claude (Claude-Opus-4.8)


  Commit: 49744c0cc07c85f201267d75ec064eab743270d4
      https://github.com/llvm/llvm-project/commit/49744c0cc07c85f201267d75ec064eab743270d4
  Author: Ron Green [NVIDIA] <rogreen at nvidia.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M flang/lib/Parser/openacc-parsers.cpp
    M flang/test/Parser/acc-unparse.f90

  Log Message:
  -----------
  [flang][OpenACC] Allow blanks around ':' in a gang-arg (#210089)

The parsers for the STATIC, DIM, and NUM forms of an OpenACC gang-arg
used the token strings "STATIC: ", "DIM: ", and "NUM: ", none of which
permit a blank between the keyword and the ':' separator. A space in a
TokenStringMatch pattern is the only place a blank is accepted in the
source (outside the leading/trailing skip), so a directive such as

    !$acc loop gang(static : 1)

was rejected with "expected end of OpenACC directive", even though
free-form Fortran allows optional blanks around the separator.

Move the blank in each token string to before the ':' ("STATIC :", etc.)
so zero or more blanks are accepted on either side of the separator. The
_tok form keeps the blank optional, so the no-space spelling still
parses without a warning.

Add parser/unparse coverage for the spaced spellings of the static, dim,
and num gang arguments.


  Commit: 4180e2bb885271956e80344354b046a9b4cf3031
      https://github.com/llvm/llvm-project/commit/4180e2bb885271956e80344354b046a9b4cf3031
  Author: Fangrui Song <i at maskray.me>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/include/llvm/ADT/GenericUniformityImpl.h

  Log Message:
  -----------
  [UniformityAnalysis] Make divergent-exit cycle print order deterministic (#210107)

Once the set spills to the heap its iteration order follows allocation
addresses, so the printed order is nondeterministic.

Fix https://reviews.llvm.org/D130746 ("RFC: Uniformity Analysis for
Irreducible Control Flow")


  Commit: 74dee943ac272caa4cd80a2a23c7f866dd96b4ec
      https://github.com/llvm/llvm-project/commit/74dee943ac272caa4cd80a2a23c7f866dd96b4ec
  Author: Arthur Eubanks <aeubanks at google.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    A llvm/test/tools/llvm-reduce/remove-funcs-inline-history.ll
    M llvm/tools/llvm-reduce/deltas/ReduceFunctions.cpp

  Log Message:
  -----------
  [llvm-reduce] Fix !inline_history verifier issues (#199373)

We'd RAUW a function which would cause !inline_history metadata nodes to
be `ptr null` which doesn't pass the verifier.

Instead we can keep around metadata usages of the function with
replaceNonMetadataUsesWith().


  Commit: 8da6ab53c7533b9bc1e8eb5a2c8eaf195c45c0b3
      https://github.com/llvm/llvm-project/commit/8da6ab53c7533b9bc1e8eb5a2c8eaf195c45c0b3
  Author: UebelAndre <github at uebelandre.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M utils/bazel/.bazelrc
    M utils/bazel/llvm-project-overlay/clang-tools-extra/include-cleaner/BUILD.bazel
    M utils/bazel/llvm-project-overlay/llvm/BUILD.bazel
    M utils/bazel/llvm-project-overlay/llvm/lit_test.bzl
    A utils/bazel/llvm-project-overlay/llvm/utils/lit/BUILD.bazel
    M utils/bazel/llvm-project-overlay/llvm/utils/lit/tests/BUILD.bazel
    M utils/bazel/llvm-project-overlay/mlir/tblgen.bzl
    M utils/bazel/llvm-project-overlay/mlir/test/BUILD.bazel

  Log Message:
  -----------
  [bazel] Updated lit_test to work from external workspaces (#204489)

This change should not change the behavior of tests but instead ensure
that no matter where a test is run (either as an external repo or as an
overlay from `./utils/bazel`) that the rendered source paths are correct
for that context.


  Commit: 202cb24d246a871e7ae0b5ebf900582d76e7a334
      https://github.com/llvm/llvm-project/commit/202cb24d246a871e7ae0b5ebf900582d76e7a334
  Author: Qiongsi Wu <qiongsiwu at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/include/clang/Basic/DiagnosticSerializationKinds.td
    M clang/lib/Serialization/ASTReader.cpp
    M clang/unittests/Serialization/ModuleCacheTest.cpp

  Log Message:
  -----------
  [clang][Modules] Adding Specific Diagnostics when a Finalized PCM is Out-of-date due to Input File Changes (#209857)

We have good diagnostics coverage when a pcm cannot be dropped in
`ASTReader::readASTCore`, because we call `canRecoverFromOutOfDate` to
check if the pcm is finalized or not. This check is missing for input
file changes.

This PR fixes the diagnostics, so we do not fall to the generic error
`err_module_rebuild_finalized`, which is hard to reason and act on.


  Commit: a730dda7d520cff562e77efbe02b5bba470a2b36
      https://github.com/llvm/llvm-project/commit/a730dda7d520cff562e77efbe02b5bba470a2b36
  Author: Qiongsi Wu <qiongsiwu at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/include/clang/Basic/AtomicLineLogger.h
    M clang/include/clang/DependencyScanning/DependencyScanningService.h
    M clang/include/clang/DependencyScanning/DependencyScanningWorker.h
    M clang/include/clang/DependencyScanning/InProcessModuleCache.h
    M clang/include/clang/Serialization/InMemoryModuleCache.h
    M clang/include/clang/Serialization/ModuleCache.h
    M clang/lib/DependencyScanning/DependencyScannerImpl.cpp
    M clang/lib/DependencyScanning/DependencyScanningWorker.cpp
    M clang/lib/DependencyScanning/InProcessModuleCache.cpp
    M clang/lib/Frontend/CompilerInstance.cpp
    M clang/lib/Serialization/InMemoryModuleCache.cpp
    M clang/lib/Serialization/ModuleCache.cpp
    M clang/lib/Tooling/DependencyScanningTool.cpp
    A clang/test/ClangScanDeps/logging-drop-pcm.c
    A clang/test/ClangScanDeps/logging-simple-by-name.c
    A clang/test/ClangScanDeps/logging-simple.c
    A clang/test/ClangScanDeps/logging-two-threads.c
    M clang/tools/clang-scan-deps/ClangScanDeps.cpp
    M clang/tools/clang-scan-deps/Opts.td
    M clang/unittests/Basic/AtomicLineLoggerTest.cpp
    M clang/unittests/DependencyScanning/InProcessModuleCacheTest.cpp
    M clang/unittests/Serialization/InMemoryModuleCacheTest.cpp

  Log Message:
  -----------
  [clang][DependencyScanning] Logging Dependency Scanning Events (#195896)

This PR sets up an `AtomicLineLogger` (added by
https://github.com/llvm/llvm-project/pull/205395) to log the sequence of
dependency scanning events. The logging is triggered by a new `LogPath`
option in `DependencyScanningServiceOptions`. This PR adds an option
`-log-path=` to `clang-scan-deps` to trigger the log.

We are logging 16 events during dependency scanning. 

| Event | Logged In | When |
|-------|-----------|------|
| `starting scanning command: <args>` | `DependencyScanningWorker.cpp` |
Start of each TU scan |
| `finished scanning command: <args>` | `DependencyScanningWorker.cpp` |
End of each TU scan |
| `init_compiler_instance_with_context: <args>` |
`DependencyScanningTool.cpp` | CompilerInstanceWithContext created for
by-name scanning |
| `start scan_by_name: <module name>` | `DependencyScanningTool.cpp` |
Start of a by-name module query |
| `finish scan_by_name: <module name>` | `DependencyScanningTool.cpp` |
End of a by-name module query |
| `module_compile_thread: parent=<TID> pcm_compile: <pcm path>` |
`CompilerInstance::compileModule` | A new thread is created to compile a
pcm |
| `timestamp_read: <pcm path>` |
`InProcessModuleCache::getModuleTimestamp` | Validation timestamp read |
| `timestamp_write: <pcm path>` |
`InProcessModuleCache::updateModuleTimestamp` | Validation timestamp
update |
| `pcm_write: <pcm path>` | `InProcessModuleCache::write` | PCM write to
disk attempted |
| `pcm_read_disk: <pcm path>` | `InProcessModuleCache::read` | PCM read
from disk attempted |
| `pcm_read_cached: <pcm path>` | `InMemoryModuleCache::lookupPCM` | PCM
looked up in in-memory cache |
| `pcm_add: <pcm path>` | `InMemoryModuleCache::addPCM` | PCM added to
cache (not validated) |
| `pcm_add_built: <pcm path>` | `InMemoryModuleCache::addBuiltPCM` | PCM
added to cache (final) |
| `pcm_finalized: <pcm path>` | `InMemoryModuleCache::finalizePCM` | PCM
marked as validated/final |
| `pcm_dropped: <pcm path>` | `InMemoryModuleCache::tryToDropPCM` | PCM
dropped (validation failed) |
| `pcm_not_dropped: <pcm path>` | `InMemoryModuleCache::tryToDropPCM` |
PCM not dropped (validation failed, but already final) |

In addition to checking the logger's functionality,
`clang/test/ClangScanDeps/logging-simple.c` checks against the change
committed by https://github.com/llvm/llvm-project/pull/177062. Without
https://github.com/llvm/llvm-project/pull/177062,
`clang/test/ClangScanDeps/logging-simple.c` fails.

This implementation adds a single instance of `AtomicLineLogger` to the
`DependencyScanningService`. Most of the plumbing goes into the
`ModuleCache` and its derived classes.

Assisted-by: claude-opus-4.6

rdar://39907408


  Commit: 908b5931ce3d9630ae3b897bd4c523945038fdcd
      https://github.com/llvm/llvm-project/commit/908b5931ce3d9630ae3b897bd4c523945038fdcd
  Author: Nikita Terentev <svet58585 at mail.ru>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/test/CodeGen/PowerPC/builtins-ppc-fma.c
    M clang/test/CodeGen/PowerPC/builtins-ppc-fpconstrained.c

  Log Message:
  -----------
  [NFC][Clang][PowerPC] Fix suspicious unsequenced volatile accesses in codegen tests (#199338)

When trying to add new Sema check in PR
https://github.com/llvm/llvm-project/pull/180955 some tests failed.
The following pattern is observed in these tests:
```
volatile x;
x = __builtinXXX(x, x, x);

```
For C and C++ standards order of evaluate funcall argument is
unsequence(or indeterminate sequence) and unsequence access for same
volatile variable is UB(because read volatile qualified variable is
side-effects).

As far as I undestand, unsequenced accesses is unwanted and new warning
is correct.
This PR try to fix it for tests:
```
\clang\test\CodeGen\PowerPC\builtins-ppc-fma.c
\clang\test\CodeGen\PowerPC\builtins-ppc-fpconstrained.c
```
Topics on discourse:
https://discourse.llvm.org/t/suspicious-use-volatile-qualified-variable-in-clang-codegen-tests/90837
Closed similar issue for SystemZ :
https://github.com/llvm/llvm-project/issues/186584


  Commit: dd2e6e03c75918dce69e9d1f46e7b356ef31c60d
      https://github.com/llvm/llvm-project/commit/dd2e6e03c75918dce69e9d1f46e7b356ef31c60d
  Author: Alexander Richardson <mail at alexrichardson.me>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/RISCV/RISCVRegisterInfo.td

  Log Message:
  -----------
  [RISCV][RVY] Fix DwarfRegAlias for X10_Y to X15_Y (#210104)

The initial commit had typos here missing the leading 1.
This was not noticed since we don't have any tests yet that
emit .cfi_offset etc.

Fixes 5eb3969c7a0b192d74bf4730f854d4cfc25a6c77


  Commit: 409f15dbb1d3853fb563e6ac902a1067411c8b9f
      https://github.com/llvm/llvm-project/commit/409f15dbb1d3853fb563e6ac902a1067411c8b9f
  Author: Alex Langford <alangford at apple.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M lldb/include/lldb/Core/Section.h
    M lldb/source/API/SBSection.cpp
    M lldb/source/Commands/CommandObjectMemory.cpp
    M lldb/source/Plugins/ObjectFile/ELF/ELFHeader.cpp
    M lldb/source/Plugins/ObjectFile/ELF/ObjectFileELF.cpp
    M lldb/source/Plugins/ObjectFile/Mach-O/ObjectFileMachO.cpp
    M lldb/source/Target/SectionLoadList.cpp
    M lldb/source/Target/Target.cpp
    M lldb/tools/lldb-test/lldb-test.cpp

  Log Message:
  -----------
  [lldb] Section::GetName should return a StringRef (#209926)

Section currently owns a ConstString to hold onto its name. I plan on
changing this in the future, but first I want to remove ConstString from
its API. This commit starts with `GetName`.


  Commit: 03c539c79af2d917be5f5120fb49e714d0f23101
      https://github.com/llvm/llvm-project/commit/03c539c79af2d917be5f5120fb49e714d0f23101
  Author: Craig Topper <craig.topper at sifive.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/RISCV/RISCVLoadStoreOptimizer.cpp

  Log Message:
  -----------
  [RISCV] Use MCRegister. NFC (#210110)


  Commit: 5d99b0a9a79dd72ae45b88a7815edaf600808698
      https://github.com/llvm/llvm-project/commit/5d99b0a9a79dd72ae45b88a7815edaf600808698
  Author: Mauri de Souza Meneguzzo <mauri870 at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M compiler-rt/lib/tsan/rtl/tsan_interface.h
    M compiler-rt/lib/tsan/rtl/tsan_interface_atomic.cpp

  Log Message:
  -----------
  [tsan][go]: add a128 store, load, compare_exchange (#196833)

This commit adds a128 load, store and compare_exchange to the Go
sanitizer functions. This is needed for a new Go atomic type that
operate on 16-byte values.

The SANITIZER_GO macro was gating a128 and is now lifted. Based on the
__TSAN_HAS_INT128 macro definition, the only architecture excluded by it
that intersects with [Go race support
](https://go.dev/doc/articles/race_detector#Requirements) is s390x.

For https://github.com/golang/go/issues/61236


  Commit: fb908ede5170c8eadb4ff86b491ca48a23f23c17
      https://github.com/llvm/llvm-project/commit/fb908ede5170c8eadb4ff86b491ca48a23f23c17
  Author: Erich Keane <ekeane at nvidia.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/docs/ReleaseNotes.md
    M clang/lib/Sema/SemaTemplate.cpp
    M clang/test/CXX/temp/temp.param/p10-2a.cpp

  Log Message:
  -----------
  Add fallback type for Constrained placeholders other than plain auto. (#209893)

We were diagnosing this and leave the type in place, but that broke
invariants when
looking it up later. This patch just sets a fallback type to just the
'auto' (or a supported
type at least) instead, so that we gracefully continue.

Fixes: #208658


  Commit: 55fc45605710c642cf49a732f7d96a95c120db9f
      https://github.com/llvm/llvm-project/commit/55fc45605710c642cf49a732f7d96a95c120db9f
  Author: Farid Zakaria <farid.m.zakaria at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/CodeGen/TargetLoweringObjectFileImpl.cpp

  Log Message:
  -----------
  [NFC] Refactor when selecting x86-64 EH encoding to be less prone to error (#210109)

Use a case-scoped local (EHCM) rather than mutating the object file's
code model, so only the EH encoding selection is affected.


  Commit: f6ed48325939e40940fccce886e5414d26b7114e
      https://github.com/llvm/llvm-project/commit/f6ed48325939e40940fccce886e5414d26b7114e
  Author: hulxv <hulxxv at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M libc/src/__support/math/CMakeLists.txt
    M libc/src/__support/math/acos.h
    M libc/src/__support/math/acosbf16.h
    M libc/src/__support/math/acosf.h
    M libc/src/__support/math/acospif.h
    M libc/src/__support/math/asin.h
    M libc/src/__support/math/asin_utils.h
    M libc/src/__support/math/asinbf16.h
    M libc/src/__support/math/asinf.h
    M libc/src/__support/math/asinpi.h
    M libc/src/__support/math/asinpif.h
    M libc/src/__support/math/atan2f.h
    M libc/src/__support/math/atan2f16.h
    M libc/src/__support/math/atan_utils.h
    M libc/src/__support/math/atanf.h
    R libc/src/__support/math/inv_trigf_utils.h
    M utils/bazel/llvm-project-overlay/libc/BUILD.bazel

  Log Message:
  -----------
  [libc][math] reduce duplicated inv trig helpers (#191364)

Instead of duplicate inv trig helpers for float and double. we can unify
them when that is possible and drop inv_trigf_utils after moving helpers
to asin_utils and atan_utils. That makes everything clean.


  Commit: dce66b626c98c2c85b77b6b77cef24adc4f01460
      https://github.com/llvm/llvm-project/commit/dce66b626c98c2c85b77b6b77cef24adc4f01460
  Author: Damian Rouson <rouson at lbl.gov>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M flang/docs/FortranStandardsSupport.md

  Log Message:
  -----------
  [Flang] [Docs] Update DO CONCURRENT status (#209299)

Update the documentation of
1. `reduce` locality support
2. `do concurrent` support (link to implementation details).

---------

Co-authored-by: Dan Bonachea <dobonachea at lbl.gov>
Co-authored-by: Tarun Prabhu <tarunprabhu at gmail.com>


  Commit: 37cf7d04a3a7ec460aabed51a9a383d60bc63572
      https://github.com/llvm/llvm-project/commit/37cf7d04a3a7ec460aabed51a9a383d60bc63572
  Author: Zhen Wang <zhenw at nvidia.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M flang/lib/Lower/ConvertCall.cpp
    A flang/test/Lower/CUDA/cuda-managed-func-result.cuf

  Log Message:
  -----------
  [flang][cuda] Fix invalid host free of managed allocatable function results (#209945)

An allocatable function result with a CUDA data attribute is allocated
with the CUDA allocator, but the caller freed the temporary with a host
`free` (via `hlfir.destroy` → `fir.freemem`), corrupting the heap.
Release it through the CUDA-aware deallocation (`cuf.deallocate`)
instead.


  Commit: 5f371b2add3e2784e6e9921b42842e2a6622e24e
      https://github.com/llvm/llvm-project/commit/5f371b2add3e2784e6e9921b42842e2a6622e24e
  Author: Anshil Gandhi <95053726+gandhi56 at users.noreply.github.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AMDGPU/SIRegisterInfo.cpp
    M llvm/test/CodeGen/AMDGPU/eliminate-frame-index-flat-scratch-svs.mir

  Log Message:
  -----------
  [AMDGPU] Fold constant offset into SV form addressing in SVS frame index fallback (#208629)

Depends on #208624 (which depends on #208612).

In the SVS fallback path of `SIRegisterInfo::eliminateFrameIndex` for
flat scratch, the scratch address was materialized by moving the full
frame offset into the scavenged vaddr VGPR and forcing the
instruction's immediate offset to `0`, which also silently dropped
any pre-existing immediate offset on the instruction.

This splits the full constant offset with `TII->splitFlatOffset`, folding
as much as possible into the SV form instruction's immediate offset
field and materializing only the remainder (plus the frame register,
if any) into the vaddr VGPR.

Test: adds `scratch_{store,load}_svs_split_offset` to
`eliminate-frame-index-flat-scratch-svs.mir` (non-zero instruction
offset, now preserved and folded) and regenerates the existing checks.

Made with [Cursor](https://cursor.com)

Resolves https://github.com/llvm/llvm-project/issues/178968


  Commit: d4f4524291d734c4b3ddb55d205c6fffeefbea6a
      https://github.com/llvm/llvm-project/commit/d4f4524291d734c4b3ddb55d205c6fffeefbea6a
  Author: Ayokunle Amodu <ayokunle321 at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/lib/CIR/CodeGen/CIRGenBuiltinAMDGPU.cpp
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn-gfx1250.hip
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn.hip

  Log Message:
  -----------
  [CIR][AMDGPU] Add support for AMDGCN exp2 builtins (#198025)

Adds codegen support for the following AMDGCN exp2 builtins:

- __builtin_amdgcn_exp2f (float)
- __builtin_amdgcn_exp2_bf16 (bfloat16)

These are lowered to the corresponding `llvm.amdgcn.exp2` intrinsic.


  Commit: 4c50e41095b36cfa2e362a4f1990c4df59533836
      https://github.com/llvm/llvm-project/commit/4c50e41095b36cfa2e362a4f1990c4df59533836
  Author: DylanFleming-arm <85629460+DylanFleming-arm at users.noreply.github.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M libc/src/mathvec/abi_prefix.h

  Log Message:
  -----------
  [libc][mathvec] Fix missing ABI-prefix from causing errors (#210127)

abi_prefix.h throws errors for unsupported ABI targets. This patch
modifies that behaviour to instead fall back onto a default
naming scheme instead, as to not break non-vfabi supporting targets.


  Commit: 6563d2500c82deb27c7dab9bc17334de777f8cbc
      https://github.com/llvm/llvm-project/commit/6563d2500c82deb27c7dab9bc17334de777f8cbc
  Author: David CARLIER <devnexen at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M compiler-rt/lib/sanitizer_common/sanitizer_symbolizer_internal.h
    M compiler-rt/lib/sanitizer_common/sanitizer_symbolizer_libcdep.cpp
    M compiler-rt/lib/sanitizer_common/tests/sanitizer_symbolizer_test.cpp

  Log Message:
  -----------
  [sanitizer_common] fix shadowed ret hiding symbolizer read failures. (#209971)

The inner `bool ret` from ReadFromFile shadowed the outer one that is
returned, so a dead/closed symbolizer (0-byte read or read error) was
reported as success: SendCommand never restarted the crashed process,
and the addr2line path aborted on a CHECK over an empty buffer.
Regression from acfeb1a6c244. Add a regression test that feeds an EOF fd
through ReadFromSymbolizer and expects failure.


  Commit: e1fa984ae0a87cf6de3b656496ced466b35995c0
      https://github.com/llvm/llvm-project/commit/e1fa984ae0a87cf6de3b656496ced466b35995c0
  Author: Mariusz Borsa <wrotki at msn.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    A compiler-rt/test/asan/TestCases/Darwin/atos-canary-symbolize.cpp

  Log Message:
  -----------
  [Sanitizers][Darwin] Add atos-canary test (#209338)

We've observed tests using atos symbolizer ocasionally failing for
several test runs on x86_64 machines, then stabilizing again. We were
unable to reproduce
this with local builds, so it's unclear what the root cause is.

To help investigate similar failures in the future, we're adding a test
exercising atos itself. Should atos start to fail again, this test
should fail too, and provide way more info helping debugging than other
tests do

Co-authored-by: Claude Opus 4.8 (1M context) <noreply at anthropic.com>

---------

Co-authored-by: Mariusz Borsa <m_borsa at apple.com>
Co-authored-by: Claude Opus 4.8 (1M context) <noreply at anthropic.com>


  Commit: 5fc5c2e4cde7ca12cbbd3868a8c24e0bbfcf570a
      https://github.com/llvm/llvm-project/commit/5fc5c2e4cde7ca12cbbd3868a8c24e0bbfcf570a
  Author: Daniel Paoliello <danpao at microsoft.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/lib/CodeGen/CGClass.cpp
    M clang/lib/CodeGen/CGExprCXX.cpp
    M clang/lib/CodeGen/CodeGenModule.cpp
    M clang/lib/CodeGen/CodeGenModule.h
    M clang/test/CodeGenCXX/microsoft-vector-deleting-dtors.cpp
    M clang/test/CodeGenCXX/microsoft-vector-deleting-dtors2.cpp
    A clang/test/CodeGenCXX/msvc-global-delete-forwarding-at-delete-site.cpp
    M clang/test/CodeGenCXX/msvc-global-delete-scalar-array-split.cpp
    M clang/test/CodeGenCXX/msvc-global-delete-scope-no-dtor.cpp
    M clang/test/CodeGenCXX/msvc-no-global-delete-forwarding.cpp

  Log Message:
  -----------
  [clang][win] Fix __global_delete wrappers for Arm64EC and cross-TU ::delete (#209585)

PR #188372 made Clang's MSVC-ABI deleting-destructor path route global
deletes
through compiler-generated __global_delete / __global_array_delete
wrappers
instead of referencing ::operator delete directly. This lets a deleting
destructor be emitted in environments (e.g. kernel mode) where no global
::operator delete exists: each wrapper defaults to a trapping
__empty_global_delete fallback, and a real forwarding body that calls
::operator delete is materialized only when the program actually uses
::delete.

This change refines how those wrappers and their fallbacks are emitted,
fixing
two problems that made the #188372 mechanism fail in practice.

New behavior:

- The trapping fallback is now emitted as a weak GlobalAlias to
__empty_global_delete rather than via an /alternatename directive. This
lowers
to a COFF weak-external-with-default -- exactly what MSVC emits -- so a
real
__global_delete defined in any TU overrides the fallback in every other
TU at
  link time.

- A ::delete expression now registers the wrapper for its resolved
global
operator delete directly (in EmitCXXDeleteExpr), so the strong
forwarding body
is emitted in that TU regardless of where the class's deleting
destructor is
defined. This matches MSVC, which emits the forwarder at every ::delete
site.

Bugs fixed:

1. Arm64EC (miscompile -> LNK2019). /alternatename only names the plain
symbol,
not the backend-generated "$$h" hybrid EC symbol referenced by the exit
thunk, so Arm64EC images left __global_delete$exit_thunk unresolved. The
weak
GlobalAlias correctly produces the "$$h" symbol, exit thunk, and plain
alias
   (verified on both x64 and Arm64EC).

2. Cross-TU ::delete (runtime crash). Previously the forwarding body was
only
emitted in a TU that *both* emitted a matching vector deleting
destructor and
contained a ::delete. A TU that only performed `::delete p` -- with the
class
defined elsewhere -- emitted no forwarder, so nothing overrode the
weak-alias
trap and the program executed a trapping __empty_global_delete at
runtime
(STATUS_ILLEGAL_INSTRUCTION). Registering the wrapper at the ::delete
site
   fixes this.

To share wrapper-creation logic between the deleting-destructor path and
the
delete-expression path, getOrCreateMSVCGlobalDeleteWrapper is promoted
from a
static helper in CGClass.cpp to a CodeGenModule method.

Verified end-to-end: a weak alias in one TU and a strong forwarder in
another
resolve to the forwarder under both lld-link and MSVC link.exe, and the
previously-crashing delete-only TU now runs cleanly.


  Commit: db43e54c966ce9146a05bc0e8cb1550f65f89e35
      https://github.com/llvm/llvm-project/commit/db43e54c966ce9146a05bc0e8cb1550f65f89e35
  Author: Andreas Jonson <andjo403 at hotmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Scalar/ConstraintElimination.cpp
    M llvm/test/Transforms/ConstraintElimination/reproducer-remarks.ll
    M llvm/test/Transforms/ConstraintElimination/trunc.ll

  Log Message:
  -----------
  [ConstraintElim] Add trunc nuw support to condition checks (#209844)

Adding support for trunc nuw %x to i1 by using the m_ICmpLike pattern in
conditions the same way as icmp ne %x, 0

proof: https://alive2.llvm.org/ce/z/ZyDWZ2


  Commit: da6f3e6cc2565e4c6cf720931845c8eee132ce86
      https://github.com/llvm/llvm-project/commit/da6f3e6cc2565e4c6cf720931845c8eee132ce86
  Author: Ikhlas Ajbar <iajbar at quicinc.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/Hexagon/HexagonRDFOpt.cpp
    A llvm/test/CodeGen/Hexagon/rdfopt-liveins-hang.mir

  Log Message:
  -----------
  [Hexagon] Fix HexagonRDFOpt hang during live-in recomputation (#209986)

After HexagonRDFOpt, the compiler recomputed live-in registers for every
block in one batch. On large inputs (e.g. kernel builds) this was slow,
and on some functions each pass changed the live-in values of other
blocks, triggering more passes until the compiler hung (PR #207422).

Fix: process blocks one at a time in post-order (successors before
predecessors) and stop as soon as nothing changes. Add a pass limit as a
safety net to keep compile time bounded in all cases.


  Commit: c0b8c59b65afd268f286f56ef71f6433ac47dfd1
      https://github.com/llvm/llvm-project/commit/c0b8c59b65afd268f286f56ef71f6433ac47dfd1
  Author: David CARLIER <devnexen at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M compiler-rt/lib/memprof/memprof_allocator.cpp
    A compiler-rt/test/memprof/TestCases/memprof_histogram_tail_clear.cpp
    A compiler-rt/test/memprof/TestCases/memprof_nonhistogram_tail_clear.cpp

  Log Message:
  -----------
  [compiler-rt][memprof] clear histogram tail granule on allocation. (#208911)

ClearShadow rounded the size down, leaving the partial tail counter
(ceil(size/8)-th) uncleared, so a recycled chunk leaked a stale count
into the last histogram bucket. Round up instead.


  Commit: e59415baa96d15415a230d1c438c722dca71516e
      https://github.com/llvm/llvm-project/commit/e59415baa96d15415a230d1c438c722dca71516e
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/test/Transforms/SLPVectorizer/X86/mul-shl-nsw-intmin.ll

  Log Message:
  -----------
  [SLP][NFC]Add tests with incorrect nsw propagation in shl/mul, NFC



Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/210145


  Commit: 909ba8d3508cf7177da65a4d1399f7bc5a3a4b98
      https://github.com/llvm/llvm-project/commit/909ba8d3508cf7177da65a4d1399f7bc5a3a4b98
  Author: Changpeng Fang <changpeng.fang at amd.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AMDGPU/AMDGPU.td
    M llvm/lib/Target/AMDGPU/SIFoldOperands.cpp
    M llvm/test/CodeGen/AMDGPU/bf16-math.ll

  Log Message:
  -----------
  [AMDGPU] Select upper 16-bits for inline constants in packed BF16 (#209861)

>From gfx1250 software programming guide, v_pk_*_bf16 instructions using
inline constants must use OPSEL to select the upper 16-bits.

Fixes: LCOMPILER-2445


  Commit: 8116ab2889d74f25b8c5c0f0dbd7f6bb3aabfc8c
      https://github.com/llvm/llvm-project/commit/8116ab2889d74f25b8c5c0f0dbd7f6bb3aabfc8c
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/InstCombine/InstCombineCalls.cpp
    M llvm/test/Transforms/InstCombine/sincos.ll

  Log Message:
  -----------
  [InstCombine] Use getInsertionPointAfterDef to get sin/cos InsertPt. (#210130)

The current logic added in
https://github.com/llvm/llvm-project/pull/194616
picks an incorrect insert point for the argument is an invoke.

Use getInsertionPointAfterDef and bail out if there is no such insert
point.

Fixes crashes in the added tests.

Fixes https://github.com/llvm/llvm-project/issues/210111


  Commit: 85cc99660cf051157f0ce50e3a976312b1f829bd
      https://github.com/llvm/llvm-project/commit/85cc99660cf051157f0ce50e3a976312b1f829bd
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/SLPVectorizer.cpp
    M llvm/test/Transforms/SLPVectorizer/X86/mul-shl-nsw-intmin.ll

  Log Message:
  -----------
  [SLP]Drop nsw when shl by BW-1 is converted to mul

shl nsw X, BW-1 is valid at X = -1, but mul X, INT_MIN is not nsw-safe
there. Drop nsw on the vector mul when a shl lane with shift amount
BW-1 is unified into mul during opcode interchange.

Fixes #210093

Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/210152


  Commit: e78a880505ca0c9ed102fc48100b4cdb280f4e34
      https://github.com/llvm/llvm-project/commit/e78a880505ca0c9ed102fc48100b4cdb280f4e34
  Author: Craig Topper <craig.topper at sifive.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/RISCV/RISCVISelLowering.cpp
    M llvm/lib/Target/RISCV/RISCVInstrInfoP.td
    M llvm/test/CodeGen/RISCV/rvp-simd-32.ll
    M llvm/test/CodeGen/RISCV/rvp-simd-64.ll

  Log Message:
  -----------
  [RISCV][P-ext] Make undef vectors Legal. (#210106)

Add a few additional isel patterns to avoid false dependencies. We may
want to enable the BreakFalseDep pass in the future.


  Commit: 152fdb8ae8725dab7e529c5cedec1d5151506307
      https://github.com/llvm/llvm-project/commit/152fdb8ae8725dab7e529c5cedec1d5151506307
  Author: Scott Manley <rscottmanley at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M mlir/lib/Dialect/OpenACC/Transforms/ACCCGToGPU.cpp

  Log Message:
  -----------
  [OpenACC] emit NYI for multi-rank or non-memref type array reduction (#210143)

This should be an NYI and not an assertion


  Commit: 1387002dc6bee9b9f4b430afebc4141a0f603bb1
      https://github.com/llvm/llvm-project/commit/1387002dc6bee9b9f4b430afebc4141a0f603bb1
  Author: Muhammad Bassiouni <60100307+bassiounix at users.noreply.github.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/include/clang/Basic/DiagnosticParseKinds.td
    M clang/lib/Parse/ParseExprCXX.cpp
    M clang/lib/Parse/ParseStmt.cpp

  Log Message:
  -----------
  [Clang][NFC] Update diagnostic handling for C2y compatibility in parser (#209920)

Follow-up on #198244 after #209241


  Commit: a11e3727f82f1395e7554f348c76a9af5f05b0b5
      https://github.com/llvm/llvm-project/commit/a11e3727f82f1395e7554f348c76a9af5f05b0b5
  Author: Craig Topper <craig.topper at sifive.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/RISCV/RISCVISelLowering.cpp

  Log Message:
  -----------
  [RISCV][P-ext] Remove redundant shuffle lowering for packed widening high-half convert. (#210128)

The more general lowerVECTOR_SHUFFLEAsPZip can handle this case.


  Commit: d9d1d919de92b1086b583168b4edccfa19bc854d
      https://github.com/llvm/llvm-project/commit/d9d1d919de92b1086b583168b4edccfa19bc854d
  Author: Alex Duran <alejandro.duran at intel.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M offload/plugins-nextgen/level_zero/src/L0Plugin.cpp

  Log Message:
  -----------
  [OFFLOAD][L0] Don't return error on initImpl if library/drivers are missing (#210083)

When a Level Zero driver is not present in the environment the current
behavior makes olInit fail if the level_zero plugin is requested. This
changes the behavior to match other plugins where it doesn't fail but
return 0 supported devices.


  Commit: 44e3f3cb248de5c1a071182367ee719baf3683df
      https://github.com/llvm/llvm-project/commit/44e3f3cb248de5c1a071182367ee719baf3683df
  Author: Akshay K <iit.akshay at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/lib/CIR/CodeGen/CIRGenExprScalar.cpp
    M clang/test/CIR/CodeGen/ternary-throw.cpp

  Log Message:
  -----------
  [CIR] Fix use-after-free when emitting ternary with a throw-expression arm (#208850)

Fixes #208848.

When a conditional operator arm is a noreturn expression, such as
`throw`, `VisitAbstractConditionalOperator` saved an insertion point in
the empty dead-code block created after the expression. The intent was
to insert a `cir.yield` later, once the types of both arms were known.
However, `LexicalScope::cleanup()` removes that empty block when the
arm’s scope exits, leaving the deferred insertion point with a dangling
block pointer.

Avoid saving the insertion point for noreturn arms. These regions
already terminate with `cir.unreachable` and do not require a
`cir.yield`. The CIR verifier accepts ternary regions that terminate
with `cir.unreachable`.

Extended `ternary-throw.cpp` with scalar-rvalue cases covering `throw`
in either arm and in both arms. The existing tests only covered glvalue
conditionals, which take the LValue emission path and never reach this
code.


  Commit: b74a97cae97a7732df5bcdef3d09f08a2e586468
      https://github.com/llvm/llvm-project/commit/b74a97cae97a7732df5bcdef3d09f08a2e586468
  Author: firmiana <firmiana402 at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M lldb/source/Expression/DWARFExpression.cpp
    M lldb/unittests/Expression/DWARFExpressionTest.cpp

  Log Message:
  -----------
  [lldb] Produce generic results for DWARF relational operations (#210122)

DWARF relational operations produce a generic result, whose width is the
target address size. LLDB currently assigns the C++ `bool` comparison
result directly to `Scalar`; because `Scalar` has no `bool` constructor,
this creates a 32-bit integer even on 64-bit targets.

The stricter binary operand checks added in #201288 exposed this in
x86-64 `_sigtramp` CFI. A later `DW_OP_plus` combines a 64-bit generic
address with the 32-bit relational result, so evaluation fails and
signal-frame unwinding stops. The generic-operand relaxation in #209641
does not cover this case because the relational result is narrower than
the address size.

Convert the results of `DW_OP_eq`, `DW_OP_ge`, `DW_OP_gt`, `DW_OP_le`,
`DW_OP_lt`, and `DW_OP_ne` through the existing `to_generic` helper.

## Testing

Add a unit test that evaluates each relational opcode with an 8-byte
address size and then consumes its result with `DW_OP_plus`.


  Commit: 5b46dcf59375181dee1fbd6e1d1cdb3f0c8f5289
      https://github.com/llvm/llvm-project/commit/5b46dcf59375181dee1fbd6e1d1cdb3f0c8f5289
  Author: Ilya Leoshkevich <iii at linux.ibm.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/include/llvm/DWP/DWP.h
    M llvm/lib/DWP/DWP.cpp
    A llvm/test/tools/llvm-dwp/SystemZ/big_endian_info_v5.s
    M llvm/test/tools/llvm-dwp/X86/compress.test

  Log Message:
  -----------
  [llvm-dwp] Fix endianness issues (#203424)

llvm-dwp fails on SystemZ, which is big-endian, as follows:

    $ cat min.c
    int main() {}
    $ clang -g -O0 -gsplit-dwarf min.c -o min
    $ llvm-dwp -e min -o min.dwp
error: compile unit exceeds .debug_info section range: 905969668 >= 58

This is because it hardcodes IsLittleEndian=true in multiple places. Fix
by forwarding endianness of the current object file.

Add a SystemZ-specific test.

Add proper big-endian support to X86/compress.test and add an
explanation regarding what the hardcoded blobs are and how they are
generated.


  Commit: c9a9737dee777f5fe19131911e8ca3c8ca3c7031
      https://github.com/llvm/llvm-project/commit/c9a9737dee777f5fe19131911e8ca3c8ca3c7031
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    A lld/docs/DTLTO.md
    R lld/docs/DTLTO.rst
    A lld/docs/ELF/large_sections.md
    R lld/docs/ELF/large_sections.rst
    A lld/docs/ELF/linker_script.md
    R lld/docs/ELF/linker_script.rst
    A lld/docs/ELF/start-stop-gc.md
    R lld/docs/ELF/start-stop-gc.rst
    A lld/docs/ELF/warn_backrefs.md
    R lld/docs/ELF/warn_backrefs.rst
    A lld/docs/MachO/index.md
    R lld/docs/MachO/index.rst
    A lld/docs/MachO/ld64-vs-lld.md
    R lld/docs/MachO/ld64-vs-lld.rst
    A lld/docs/NewLLD.md
    R lld/docs/NewLLD.rst
    A lld/docs/ReleaseNotes.md
    R lld/docs/ReleaseNotes.rst
    A lld/docs/WebAssembly.md
    R lld/docs/WebAssembly.rst
    A lld/docs/error_handling_script.md
    R lld/docs/error_handling_script.rst
    A lld/docs/index.md
    R lld/docs/index.rst
    A lld/docs/missingkeyfunction.md
    R lld/docs/missingkeyfunction.rst
    A lld/docs/windows_support.md
    R lld/docs/windows_support.rst

  Log Message:
  -----------
  [docs] Rename LLD docs to Markdown (#209894)

Tracking issue: https://github.com/llvm/llvm-project/issues/201242
Migration guide docs:
https://llvm.org/docs/SphinxQuickstartTemplate.html#markdown-migration-guidelines
RFC:
https://discourse.llvm.org/t/rfc-make-myst-markdown-the-llvm-docs-format-rip-rest/90840

This is the initial straight rename commit. It will probably break the
docs build, but it has to be a separate PR for blame preservation
purposes.


  Commit: f8107f628360eb0c7c4a04af98e768ffa637c1b3
      https://github.com/llvm/llvm-project/commit/f8107f628360eb0c7c4a04af98e768ffa637c1b3
  Author: Tim Corringham <timothy.corringham at amd.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/lib/Sema/HLSLExternalSemaSource.cpp
    M clang/test/AST/HLSL/Textures-AST.hlsl
    M clang/test/CodeGenHLSL/resources/Textures-GetDimensions.hlsl
    M clang/test/CodeGenHLSL/resources/Textures-Load.hlsl
    M clang/test/SemaHLSL/Resources/RWTexture2D-mips-errors.hlsl
    M clang/test/SemaHLSL/Resources/RWTexture2D-unsupported-methods-errors.hlsl
    M clang/test/SemaHLSL/Resources/Textures-GetDimensions.hlsl
    M clang/test/SemaHLSL/Resources/Textures-Load-errors.hlsl

  Log Message:
  -----------
  [HLSL] Implement RWTexture2DArray (#208725)

Add front-end support for RWTexture2DArray, and update related tests to
include coverage of this resource.

Fixes #194947

---------

Co-authored-by: Tim Corringham <tcorring at amd.com>


  Commit: ab35099249433e55ba586285c2087d0bd7f65e9c
      https://github.com/llvm/llvm-project/commit/ab35099249433e55ba586285c2087d0bd7f65e9c
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M lld/docs/DTLTO.md
    M lld/docs/ELF/large_sections.md
    M lld/docs/ELF/linker_script.md
    M lld/docs/ELF/start-stop-gc.md
    M lld/docs/ELF/warn_backrefs.md
    M lld/docs/MachO/index.md
    M lld/docs/MachO/ld64-vs-lld.md
    M lld/docs/NewLLD.md
    M lld/docs/ReleaseNotes.md
    M lld/docs/WebAssembly.md
    M lld/docs/conf.py
    M lld/docs/error_handling_script.md
    M lld/docs/index.md
    M lld/docs/missingkeyfunction.md
    M lld/docs/windows_support.md

  Log Message:
  -----------
  [docs] Rewrite LLD docs to Markdown (#209897)

Tracking issue: #201242
This is a stacked PR based on #209894 , which will be a standalone
commit that renames *.rst -> *.md before this PR lands for history
preservation purposes. See the [migration guide] for more information.

[migration guide]:
https://llvm.org/docs/SphinxQuickstartTemplate.html#markdown-migration-guidelines

This was prepared with rst2myst plus LLM-assisted cleanup. I paged
through all the generated HTML looking for migration artifacts, and all
of the differences I could find appear to be formatting error
corrections. Please spot check my work and approve if it looks good.


  Commit: d49307497bbf9f49e6a603c605319dc39113c51c
      https://github.com/llvm/llvm-project/commit/d49307497bbf9f49e6a603c605319dc39113c51c
  Author: Valentin Clement (バレンタイン クレメン) <clementval at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M flang/lib/Optimizer/Transforms/CUDA/CUFAddConstructor.cpp
    M flang/test/Fir/CUDA/cuda-constructor-2.f90

  Log Message:
  -----------
  [flang][cuda] Register allocator when cuf.allocate or cuf.deallocate are present (#210147)


  Commit: fe616e4d87cfbce9317537aa95e6068ac103a373
      https://github.com/llvm/llvm-project/commit/fe616e4d87cfbce9317537aa95e6068ac103a373
  Author: Jeff Bailey <jbailey at raspberryginger.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M libc/config/linux/aarch64/headers.txt
    M libc/config/linux/arm/headers.txt
    M libc/config/linux/i386/headers.txt
    M libc/config/linux/riscv/headers.txt
    M libc/config/linux/x86_64/headers.txt
    M libc/include/CMakeLists.txt
    A libc/include/alloca.yaml
    M libc/include/llvm-libc-macros/CMakeLists.txt
    A libc/include/llvm-libc-macros/alloca-macros.h
    M libc/test/include/CMakeLists.txt
    A libc/test/include/alloca_test.cpp

  Log Message:
  -----------
  [libc] Implement alloca.h header (#210150)

Implemented the alloca.h header for LLVM libc.

* libc/include/llvm-libc-macros/alloca-macros.h: Defined alloca macro
using __builtin_alloca.
* libc/include/alloca.yaml: Added header specification.
* libc/include/CMakeLists.txt,
libc/include/llvm-libc-macros/CMakeLists.txt: Registered the new header
and macro targets.
* libc/config/linux/*/headers.txt: Enabled the header for Linux targets
(x86_64, aarch64, arm, i386, riscv).
* libc/test/include/alloca_test.cpp, libc/test/include/CMakeLists.txt:
Added and registered functional unit tests.

Tested by running the new unit and hermetic tests.

Assisted-by: Automated tooling, human reviewed.


  Commit: c96a176dd15690ed8181c6764b26d0303008a40f
      https://github.com/llvm/llvm-project/commit/c96a176dd15690ed8181c6764b26d0303008a40f
  Author: Mauri de Souza Meneguzzo <mauri870 at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M compiler-rt/lib/tsan/rtl/tsan_interface.h

  Log Message:
  -----------
  [tsan] Enable __TSAN_HAS_INT128 on s390x and mips64 (#197319)

The s390x exclusion was added in
https://github.com/llvm/llvm-project/commit/b17673816d7f65e07015489993b22049e36b04db
(https://reviews.llvm.org/D105629)
citing lack of hardware 128-bit atomics. s390x does have the CDSG
instruction,
but `alignof(__int128) == 8` on the s390x psABI while CDSG requires
16-byte
alignment, so Clang does not define
`__GCC_HAVE_SYNC_COMPARE_AND_SWAP_16` for
this target. The mips64 exclusion has been present since
`__TSAN_HAS_INT128` was
introduced in
https://github.com/llvm/llvm-project/commit/06bbca9ec4bbc5a103c94c4973797ea4ddf944b5
(https://reviews.llvm.org/D18543) with no documented
rationale. Clang similarly does not define
`__GCC_HAVE_SYNC_COMPARE_AND_SWAP_16`
for mips64.

Both exclusions are unnecessary. When
`__GCC_HAVE_SYNC_COMPARE_AND_SWAP_16` is
not defined, all a128 operations use the SpinMutex-based emulation path,
which
serializes 128-bit accesses under a global lock without requiring any
hardware
CAS16 support.

Verified with Clang (targets: s390x-linux-gnu, mips64-linux-gnuabi64,
mips64el-linux-gnuabi64): all three produce the full set of 12
`__tsan_atomic128_*` symbols with zero `__sync_*_16 / __atomic_*_16`
libcall references.

Runtime testing has not been performed as I lack access to these
architectures.

Relates https://github.com/llvm/llvm-project/pull/196833
For https://github.com/golang/go/issues/61236


  Commit: 58db4cea87114268cca4c2957232de7db9327ceb
      https://github.com/llvm/llvm-project/commit/58db4cea87114268cca4c2957232de7db9327ceb
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    A llvm/test/Transforms/SLPVectorizer/X86/masked-blended-loads.ll

  Log Message:
  -----------
  [SLP][NFC]Add a test with GEPs under the same select condition, NFC



Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/210173


  Commit: 7cfe30df768f109dbaead1ed5f7538c10ba65d2e
      https://github.com/llvm/llvm-project/commit/7cfe30df768f109dbaead1ed5f7538c10ba65d2e
  Author: Kevin Bravo <kbravjr at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/docs/ReleaseNotes.md
    M llvm/docs/TableGen/ProgRef.rst
    M llvm/lib/TableGen/Record.cpp
    M llvm/test/TableGen/true-false.td

  Log Message:
  -----------
  [TableGen] Short-circuit !cond operator (#208942)

Fixes #163213 

TableGen `!cond` operator currently resolves all subsequent conditions
and values even if it already found a condition that resolves to `true`.
This change short-circuits on the first `true` resolution found
iterating from left to right. It folds a new `CondOpInit` with only the
conditions and values that have already been resolved, including the
current condition and value.


  Commit: f6f08fa7e5d56aa07f9ebc51500f2c9fd6df8e1b
      https://github.com/llvm/llvm-project/commit/f6f08fa7e5d56aa07f9ebc51500f2c9fd6df8e1b
  Author: Matsu <47756807+khaki3 at users.noreply.github.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M flang/lib/Semantics/resolve-names.cpp
    M flang/test/Lower/CUDA/cuda-implicit-managed-alloc.cuf

  Log Message:
  -----------
  [flang][cuda] Use managed allocation for saved locals (#210133)

Example:
```fortran
subroutine work
  real, allocatable, save :: q(:)
  allocate(q(10))
end
```

`SAVE` gives the local allocatable descriptor static storage. Implicitly
attributing it as Unified causes allocation to look it up as a
registered CUDA global, but no device symbol is registered for the
descriptor.

Fix: use Managed attribution for saved subprogram-local allocatables and
pointers, avoiding the invalid CUDA symbol lookup.


  Commit: aaa4ebd2ad174920ddce67c4641292a44788e879
      https://github.com/llvm/llvm-project/commit/aaa4ebd2ad174920ddce67c4641292a44788e879
  Author: John Paul Jepko <john.jepko at ericsson.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/docs/ReleaseNotes.md
    M clang/include/clang/Basic/DiagnosticSemaKinds.td
    M clang/lib/AST/ComputeDependence.cpp
    M clang/lib/Sema/SemaChecking.cpp
    M clang/test/AST/ByteCode/builtin-functions.cpp
    M clang/test/Analysis/bstring.c
    M clang/test/Analysis/malloc.c
    M clang/test/Analysis/pr22954.c
    M clang/test/Sema/builtin-memcpy.c
    M clang/test/Sema/builtin-object-size.c
    M clang/test/Sema/warn-fortify-source.c
    A clang/test/Sema/warn-stringop-overread-fortify.c
    A clang/test/Sema/warn-stringop-overread.c
    M clang/test/SemaCXX/warn-memset-bad-sizeof.cpp
    M compiler-rt/test/asan/TestCases/Windows/issue64990.cpp

  Log Message:
  -----------
  [Clang][Sema] Reland -Wstringop-overread with computeDependence fix (#208012)

Reland #183004 and follow-up #205201 (reverted in #207840) which adds `-Wstringop-overread` to warn when memory functions `memcpy`, `memmove`, `memcmp`, and other related builtins read more bytes than the source buffer size.

The revert was due to a crash when a memory function is called on `&x` where `x` is a static constexpr local inside a template. The original PR exposed a bug in `computeDependence(UnaryOperator*)` where only the value-dependence bit is set for this case, when the instantiation-dependence bit should also be set. This is the root cause behind the crash.

Fix `computeDependence` to properly set both value and instantiation-dependence bits, and add a regression for this crash via `warn-stringop-overread.c`.


  Commit: 68f703f3e58a52c41b39dfc654a675560b6c5614
      https://github.com/llvm/llvm-project/commit/68f703f3e58a52c41b39dfc654a675560b6c5614
  Author: Daniel Kiss <daniel.kiss at arm.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/docs/ReleaseNotes.md
    M clang/docs/UsersManual.md
    M clang/lib/Basic/Targets/AArch64.cpp
    M clang/lib/Basic/Targets/ARM.cpp
    M clang/lib/Driver/ToolChains/Clang.cpp
    M clang/test/CodeGen/AArch64/branch-protection-attr.c
    M clang/test/CodeGen/AArch64/sign-return-address.c
    M clang/test/Driver/aarch64-security-options.c
    M clang/test/Preprocessor/aarch64-target-features.c
    M llvm/docs/ReleaseNotes.md
    M llvm/include/llvm/TargetParser/ARMTargetParserCommon.h
    M llvm/lib/Target/AArch64/AArch64MachineFunctionInfo.cpp
    M llvm/lib/Target/AArch64/AArch64PointerAuth.cpp
    M llvm/lib/TargetParser/ARMTargetParserCommon.cpp
    M llvm/test/CodeGen/AArch64/sign-return-address.ll
    A llvm/test/CodeGen/AArch64/windows-pac-invalid-a-key.ll
    M llvm/test/CodeGen/AArch64/wineh-bti.ll

  Log Message:
  -----------
  [AArch64][COFF] Branch-protection=standard/pac-ret means "b-key" on Windows (#203989)

On AArch64 Windows the `B-key` is the only supported key for userspace,
let's make "standard" and "pac-ret" options generate "b-key".

Fixes: #203852


  Commit: 95ff1fa00ed4c35b3589fa92b591e02444fcc5d5
      https://github.com/llvm/llvm-project/commit/95ff1fa00ed4c35b3589fa92b591e02444fcc5d5
  Author: Anshil Gandhi <95053726+gandhi56 at users.noreply.github.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AMDGPU/SOPInstructions.td
    M llvm/test/CodeGen/AMDGPU/add-max.ll
    M llvm/test/CodeGen/AMDGPU/uaddsat.ll

  Log Message:
  -----------
  [AMDGPU] Lower uniform uaddsat.i32 to SALU insts (#210168)

Map uaddsat.i32(i32 %a, i32 %b) to the following:

```
s_not_b32 s4, s17          ; s17 = %b
s_min_u32 s4, s16, s4      ; s16 = %a
s_add_u32 s4, s4, s17
```

Co-authored-by: Shilei Tian <i at tianshilei.me>


  Commit: 0acbbccdbd5b5a218b459acc9abc6b3dc7f338a6
      https://github.com/llvm/llvm-project/commit/0acbbccdbd5b5a218b459acc9abc6b3dc7f338a6
  Author: Brad Smith <brad at comstyle.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/lib/Driver/ToolChains/Clang.cpp
    M clang/lib/Driver/ToolChains/Linux.cpp
    M clang/test/Driver/aarch64-features.c
    M clang/test/Driver/aarch64-fmv.c
    M clang/test/Driver/linux-ld.c

  Log Message:
  -----------
  [Android] Drop workarounds for older Android API levels pre 23 (#161893)

Drop workarounds for Android API levels pre 23.

The minimum Android API currently supported by the LTS NDK is 23.


  Commit: 7812fef524a0aef0b34599c2eb81b66843fbcdd8
      https://github.com/llvm/llvm-project/commit/7812fef524a0aef0b34599c2eb81b66843fbcdd8
  Author: Craig Topper <craig.topper at sifive.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/RISCV/RISCVISelLowering.cpp
    M llvm/lib/Target/RISCV/RISCVInstrInfoP.td
    A llvm/test/CodeGen/RISCV/rvp-widening-convert-isel.ll

  Log Message:
  -----------
  [RISCV][P-ext] Add RISCVISD::PWZIP for RV32. (#210134)

This node takes 2 32-bit vector inputs and produces a 64-bit vector
result. By extracting the subvector during lowering, we expose more
opportunities for optimizations.


  Commit: 5978ac06a2cc75025703008c373fc7c94246f7a3
      https://github.com/llvm/llvm-project/commit/5978ac06a2cc75025703008c373fc7c94246f7a3
  Author: Eric Christopher <echristo at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/CodeGen/AsmPrinter/DwarfExpression.cpp

  Log Message:
  -----------
  [NFC] Inline DwarfExpression frame register check (#210186)

Inline DwarfExpression frame register check as it's the only call.

Tested via make check.

Assisted by AI.


  Commit: bd0395ebfe9830b1e3dc9580021fb5a3ab343a51
      https://github.com/llvm/llvm-project/commit/bd0395ebfe9830b1e3dc9580021fb5a3ab343a51
  Author: Alexey Samsonov <vonosmas at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M libc/config/linux/aarch64/entrypoints.txt
    M libc/config/linux/riscv/entrypoints.txt
    M libc/config/linux/x86_64/entrypoints.txt
    M libc/docs/headers/time.rst
    M libc/include/sys/time.yaml
    M libc/include/time.yaml
    M libc/src/sys/time/CMakeLists.txt
    A libc/src/sys/time/gettimeofday.h
    M libc/src/sys/time/linux/CMakeLists.txt
    A libc/src/sys/time/linux/gettimeofday.cpp
    M libc/src/time/CMakeLists.txt
    R libc/src/time/gettimeofday.h
    M libc/src/time/linux/CMakeLists.txt
    R libc/src/time/linux/gettimeofday.cpp
    M libc/test/src/sys/time/CMakeLists.txt
    A libc/test/src/sys/time/gettimeofday_test.cpp
    M libc/test/src/time/CMakeLists.txt
    R libc/test/src/time/gettimeofday_test.cpp

  Log Message:
  -----------
  [libc] Move gettimeofday to sys/time.h header. (#210185)

`gettimeofday` is supposed to be declared in the `<sys/time.h>` header,
not the `<time.h>` where we've had it previously. Move the declaration
to the correct header, and move the files with implementation and unit
tests accordingly.

Note that `gettimeofday` is removed removed from POSIX-2024, but let's
keep it available for now, since there's fair amount of existing code
that still uses it.


  Commit: 5ed5468f3810cd3c424eec5e9288884f67594068
      https://github.com/llvm/llvm-project/commit/5ed5468f3810cd3c424eec5e9288884f67594068
  Author: Eric Christopher <echristo at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Scalar/LoopStrengthReduce.cpp

  Log Message:
  -----------
  [NFC][LSR] Remove duplicate debug expression update (#210188)

Remove duplicate debug expression update we assigned
the same DIExpression twice so let's just remove the redundant call.

Tested via make check.

Assisted by AI.


  Commit: 205a66201235c03b892e075ae548d6ea12f024a3
      https://github.com/llvm/llvm-project/commit/205a66201235c03b892e075ae548d6ea12f024a3
  Author: Jacek Caban <jacek at codeweavers.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/lib/Driver/ToolChains/MinGW.cpp
    M clang/test/Driver/mingw-sysroot.cpp

  Log Message:
  -----------
  [clang][mingw] Try both native and ARM64EC triples when looking for a sysroot on the ARM64EC target (#210017)

Similarly to MSVC, a MinGW toolchain may provide support for both ARM64
and ARM64EC in a single sysroot. Structuring the toolchain this way has
the additional advantage of seamlessly supporting linking ARM64X images.

Support this configuration in findClangRelativeSysroot.


  Commit: 092ac9c0c776fc5a3eddf779643d004230260300
      https://github.com/llvm/llvm-project/commit/092ac9c0c776fc5a3eddf779643d004230260300
  Author: David Mentler <mentlerd at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M lldb/docs/resources/test.md
    A lldb/packages/Python/lldbsuite/support/xcode.py
    M lldb/packages/Python/lldbsuite/test/dotest.py
    M lldb/packages/Python/lldbsuite/test/dotest_args.py

  Log Message:
  -----------
  [lldb][test] Allow dotest.py to call for Xcode to attach (#209628)

This speeds up the debugging of API tests a little on macOS.

(AppleScript written by Claude based on Xcode.sdef)


  Commit: eb819b90735b819c1afd98ab3aa14183fa57157e
      https://github.com/llvm/llvm-project/commit/eb819b90735b819c1afd98ab3aa14183fa57157e
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    A llvm/test/Transforms/SLPVectorizer/sub-nsw-icmp-eq-zero-reorder.ll

  Log Message:
  -----------
  [SLP][NFC]Add a test with incorrect nsw in reordered sub feeding equal cmp, NFC



Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/210204


  Commit: e5c143f96b37f2215a0b07d46df7600d06a372f4
      https://github.com/llvm/llvm-project/commit/e5c143f96b37f2215a0b07d46df7600d06a372f4
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/SLPVectorizer.cpp
    M llvm/test/Transforms/SLPVectorizer/sub-nsw-icmp-eq-zero-reorder.ll

  Log Message:
  -----------
  [SLP]Drop nsw when reordering a sub feeding icmp eq/ne 0

A sub used only by icmp eq/ne 0 is treated as commutative, so SLP may
swap its operands, and nsw does not survive a - b -> b - a (a - b can
be INT_MIN while b - a overflows).

Fixes #210177

Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/210205


  Commit: 396d2555ddac2d6a4885ec3ad2c73fcee00f5bd3
      https://github.com/llvm/llvm-project/commit/396d2555ddac2d6a4885ec3ad2c73fcee00f5bd3
  Author: Jonas Devlieghere <jonas at devlieghere.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/WebAssembly/MCTargetDesc/WebAssemblyInstPrinter.cpp
    M llvm/test/MC/Disassembler/WebAssembly/wasm.txt

  Log Message:
  -----------
  [WebAssembly] Don't assert on a non-zero call_indirect table index (#210120)

WebAssemblyInstPrinter::printInst asserted that a non-symbol table
operand of call_indirect is the immediate 0, on the assumption that only
MVP single-table compilation units reach the printer. That is true for
code generated by the compiler, but the printer is shared by the
disassembler.

The disassembler must produce output for any byte sequence it is pointed
at and shouldn't abort on the operand values it decodes. A non-zero
immediate table index is both a valid encoding, from a multi-table
module, and a routine result of best-effort disassembly of a range that
is not all code, which is how I hit this in LLDB.

Print the table operand when it is a symbol or a non-zero immediate, and
omit it only for the implicit table 0. This makes the output lossless
and unambiguous, matching how a table symbol is already printed. MVP and
table-symbol output are unchanged, so there is no effect on the
compiler's assembly.


  Commit: 71a7c24dec4fe7ab5eda28650cf8d9138b9ca994
      https://github.com/llvm/llvm-project/commit/71a7c24dec4fe7ab5eda28650cf8d9138b9ca994
  Author: Ikhlas Ajbar <iajbar at quicinc.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    A llvm/test/MC/Hexagon/relax-align.s

  Log Message:
  -----------
  [Hexagon] Add MC lit test for dropped fixups after packet relaxation (#210157)

Test that a branch fixup is preserved when MC relaxes a packet
containing a conditional compare-and-jump due to a following .p2align
directive. Regression test for issue #163851.


  Commit: 5337314b4bea4be5e86396eb21e59f4d123af175
      https://github.com/llvm/llvm-project/commit/5337314b4bea4be5e86396eb21e59f4d123af175
  Author: Aiden Grossman <aidengrossman at google.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/WebAssembly/WebAssembly.h
    M llvm/lib/Target/WebAssembly/WebAssemblyCodeGenPassBuilder.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyPassRegistry.def
    M llvm/lib/Target/WebAssembly/WebAssemblySetP2AlignOperands.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyTargetMachine.cpp

  Log Message:
  -----------
  [WebAssembly] Port WebAssemblySetP2AlignOperandsPass

Standard NewPM pass porting.

Reviewers: dschuff, sbc100, aheejin

Pull Request: https://github.com/llvm/llvm-project/pull/209871


  Commit: 0fc03f0454b5a5d6d35338a6f4d1092960d63e17
      https://github.com/llvm/llvm-project/commit/0fc03f0454b5a5d6d35338a6f4d1092960d63e17
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    A bolt/docs/BOLTAArch64OptimizationStatus.md
    R bolt/docs/BOLTAArch64OptimizationStatus.rst
    A bolt/docs/GettingStarted.md
    R bolt/docs/GettingStarted.rst
    A bolt/docs/index.md
    R bolt/docs/index.rst

  Log Message:
  -----------
  [bolt][docs] Rename BOLT docs to Markdown (#210198)

Tracking issue: #201242
See the [migration guide] for more information. 

[migration guide]:
https://llvm.org/docs/SphinxQuickstartTemplate.html#markdown-migration-guidelines

This is the initial straight rename commit. It will probably break the
docs build, but it has to be a separate PR for blame preservation
purposes.


  Commit: 2494e80d1cd91911713ec8451a961e07b9da8b9c
      https://github.com/llvm/llvm-project/commit/2494e80d1cd91911713ec8451a961e07b9da8b9c
  Author: Aiden Grossman <aidengrossman at google.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/WebAssembly/WebAssembly.h
    M llvm/lib/Target/WebAssembly/WebAssemblyCodeGenPassBuilder.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyFixBrTableDefaults.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyPassRegistry.def
    M llvm/lib/Target/WebAssembly/WebAssemblyTargetMachine.cpp

  Log Message:
  -----------
  [WebAssembly] Port WebAssemblyFixBrTableDefaultsPass

Standard NewPM pass porting.

Reviewers: dschuff, sbc100, aheejin

Pull Request: https://github.com/llvm/llvm-project/pull/209882


  Commit: d0dd060443b657f3d96bd1b2dcd32974cccfa6fc
      https://github.com/llvm/llvm-project/commit/d0dd060443b657f3d96bd1b2dcd32974cccfa6fc
  Author: Shilei Tian <i at tianshilei.me>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/test/CodeGen/AMDGPU/GlobalISel/inst-select-amdgcn.exp.compr.mir
    M llvm/test/CodeGen/AMDGPU/GlobalISel/llvm.amdgcn.intersect_ray.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.dual_intersect_ray.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.exp.compr.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.intersect_ray.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.tanh.ll
    M llvm/test/CodeGen/AMDGPU/s-wakeup-barrier.ll

  Log Message:
  -----------
  [NFC] Use new target triple for some tests (#210202)

They were mistakenly reverted back to the old ones.


  Commit: 565ef24d6c1b31e2fbf736b2b115d49d49b86af7
      https://github.com/llvm/llvm-project/commit/565ef24d6c1b31e2fbf736b2b115d49d49b86af7
  Author: Aiden Grossman <aidengrossman at google.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Target/WebAssembly/WebAssembly.h
    M llvm/lib/Target/WebAssembly/WebAssemblyCleanCodeAfterTrap.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyCodeGenPassBuilder.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyPassRegistry.def
    M llvm/lib/Target/WebAssembly/WebAssemblyTargetMachine.cpp

  Log Message:
  -----------
  [WebAssembly] Port WebAssemblyCleanCodeAfterTrapPass

Standard NewPM pass porting.

Reviewers: sbc100, dschuff, aheejin

Pull Request: https://github.com/llvm/llvm-project/pull/209892


  Commit: 03ab16cb415ff8dc2cb06332a628b79a718c74d8
      https://github.com/llvm/llvm-project/commit/03ab16cb415ff8dc2cb06332a628b79a718c74d8
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M bolt/docs/BOLTAArch64OptimizationStatus.md
    M bolt/docs/GettingStarted.md
    M bolt/docs/index.md

  Log Message:
  -----------
  [docs] Finish MyST migration for BOLT docs (#210199)

Tracking issue: #201242
See the [migration guide] for more information. 

[migration guide]:
https://llvm.org/docs/SphinxQuickstartTemplate.html#markdown-migration-guidelines
This is a stacked PR based on #210198, which will be a standalone commit
that
renames *.rst -> *.md before this PR lands for history preservation
purposes.

This was prepared with rst2myst plus LLM-assisted cleanup. I paged
through all the generated HTML looking for migration artifacts, and all
of the differences I could find appear to be formatting error
corrections. Please spot check my work and approve if it looks good. You
can use the HTML links below to confirm it renders properly.

-----

Before/after validation links:
| Source file | Before HTML | After HTML |
| --- | --- | --- |
| `bolt/docs/BOLTAArch64OptimizationStatus.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/bolt/docs-old/BOLTAArch64OptimizationStatus.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/bolt/docs/BOLTAArch64OptimizationStatus.html)
|
| `bolt/docs/GettingStarted.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/bolt/docs-old/GettingStarted.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/bolt/docs/GettingStarted.html)
|
| `bolt/docs/index.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/bolt/docs-old/index.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/bolt/docs/index.html)
|


  Commit: 611d015f0030e0d4f1b3bd2270205f6f6b6e20eb
      https://github.com/llvm/llvm-project/commit/611d015f0030e0d4f1b3bd2270205f6f6b6e20eb
  Author: Peter Collingbourne <pcc at google.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/utils/gn/README.rst
    M llvm/utils/gn/build/BUILD.gn
    M llvm/utils/gn/build/BUILDCONFIG.gn
    M llvm/utils/gn/build/buildflags.gni
    M llvm/utils/gn/build/symlink_or_copy.gni
    M llvm/utils/gn/build/toolchain/BUILD.gn
    M llvm/utils/gn/secondary/BUILD.gn
    M llvm/utils/gn/secondary/bolt/tools/driver/BUILD.gn
    M llvm/utils/gn/secondary/clang-tools-extra/clang-doc/tool/BUILD.gn
    M llvm/utils/gn/secondary/clang-tools-extra/clangd/xpc/framework/BUILD.gn
    M llvm/utils/gn/secondary/clang/lib/Headers/BUILD.gn
    M llvm/utils/gn/secondary/clang/tools/driver/BUILD.gn
    M llvm/utils/gn/secondary/lld/tools/lld/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-ar/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-cxxfilt/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-debuginfod-find/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-debuginfod/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-dwp/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-libtool-darwin/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-lipo/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-ml/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-nm/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-objcopy/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-objdump/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-rc/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-readobj/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-readtapi/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-size/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-strings/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-symbolizer/BUILD.gn

  Log Message:
  -----------
  gn build: Support building debug binaries from a release build directory.

This change makes it so that all binaries in `bin` have a corresponding
debug binary target `$TARGET.dbg` that will build a debug binary in
`bin.dbg/$TARGET`. This is implemented using a separate toolchain for
the debug builds. This has the following advantages over a separate
debug build directory:

1. Can use release mode tblgen to generate code for the debug build
   binaries, which speeds up the build because it can run tblgen faster as
   well as being able to reuse the tblgen binary from the release build.

2. Can reuse runtimes built in the release mode clang's resource
   directory, avoiding the need to build them again with a slow debug
   build of clang.

Assisted-by: gemini

Reviewers: aeubanks, nico

Reviewed By: aeubanks

Pull Request: https://github.com/llvm/llvm-project/pull/197843


  Commit: a45ae4cf77776bdae8ab79c3b5b4d4ef7cbd7d99
      https://github.com/llvm/llvm-project/commit/a45ae4cf77776bdae8ab79c3b5b4d4ef7cbd7d99
  Author: lntue <lntue at google.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M libc/src/__support/FPUtil/Hypot.h
    M libc/src/__support/math/hypot.h
    M libc/test/src/math/smoke/hypot_test.cpp

  Log Message:
  -----------
  [libc][math] Fix double-rounding errors with denormal inputs for hypot function. (#208247)

The issue was reported by Paul Zimmermann.

Solution: for denormal inputs, we use 1.0 + x trick after proper scaling
to mimick rounding at denormal scale.


  Commit: eafc387c1da0620642f469fde70455c554ba3470
      https://github.com/llvm/llvm-project/commit/eafc387c1da0620642f469fde70455c554ba3470
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M orc-rt/include/CMakeLists.txt
    A orc-rt/include/orc-rt/CCallback.h
    A orc-rt/test/unit/CCallbackTest.cpp
    M orc-rt/test/unit/CMakeLists.txt

  Log Message:
  -----------
  [orc-rt] Add asCCallback utility -- C callbacks for methods. (#210048)

Adds orc_rt::asCCallback<&Class::method>, which produces a C-ABI
function pointer that forwards to the given member function. The first
parameter of the generated trampoline is an opaque context pointer (
void * for non-const methods, const void * for const methods) that is
cast back to the class type and used as the receiver:

  struct Counter {
    void inc(int N) { Count += N; }
    int Count = 0;
  };

  Counter C;
  void (*CB)(void *, int) = asCCallback<&Counter::inc>;
  CB(asCCallbackContext<&Counter::inc>(C), 2); // C.Count == 2

asCCallbackContext produces the matching context pointer via
static_cast, so any base-class offset is applied and const-ness is
preserved; pairing it with asCCallback by the same method keeps things
correct under inheritance and const-qualification. (A raw cast of &C
would give the trampoline the wrong `this` when method's class is a base
at a non-zero offset.)

Specializations cover the const x noexcept combinations. The trampoline
is always noexcept -- a C caller cannot unwind a C++ exception, so an
escaping one terminates -- and return/argument types are restricted to
C-compatible (non-reference, trivially copyable) types via
static_assert.


  Commit: 5658411aed0f610380323918ce4b02016f2df6f2
      https://github.com/llvm/llvm-project/commit/5658411aed0f610380323918ce4b02016f2df6f2
  Author: Kaitlin Peng <kaitlinpeng at microsoft.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/lib/CodeGen/Targets/SPIR.cpp
    M clang/test/CodeGenHLSL/resources/RWBuffer-imageformat.hlsl
    M llvm/lib/Target/SPIRV/SPIRVInstructionSelector.cpp
    M llvm/test/CodeGen/SPIRV/hlsl-resources/SignedBufferLoadStore.ll
    M llvm/test/CodeGen/SPIRV/hlsl-resources/UnsignedBufferLoadStore.ll

  Log Message:
  -----------
  [SPIRV] Pack 64-bit vec2 typed buffers into 4x32-bit images (#208626)


  Commit: 6b9929001d0b46d087e871934e50e4783147fa7d
      https://github.com/llvm/llvm-project/commit/6b9929001d0b46d087e871934e50e4783147fa7d
  Author: Amir Ayupov <aaupov at fb.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M bolt/docs/profiles.md
    M bolt/include/bolt/Profile/DataReader.h
    M bolt/lib/Profile/DataReader.cpp
    A bolt/test/X86/profile-symbols-mode.s

  Log Message:
  -----------
  [BOLT] Add fdata symbols mode (#209932)

Add a new fdata profile mode accepting symbol names as-is.

It addresses the UX gap surfaced by #208313 that all methods of selecting
functions to process (symbolized profile types, `-funcs*` options) expect
disambiguated local symbols. 

Introduce fdata mode activated by a `symbols` header line, where each subsequent
line is a (mangled) symbol name. The names are matched against restored function
names (with disambiguation suffix stripped), and every matching function gets an
execution count of 1. 

This can be used to drive selective instrumentation (`--instrument-hot-only`) or
basic linker-script style optimizations.

Symbols are stored as branch entry data so matching reuses the existing default
branch profile path.

Test Plan:
Update docs/profiles.md and add profile-symbols-mode.s


  Commit: 398f2117379f42764e433d19ea0d0cd65009a4aa
      https://github.com/llvm/llvm-project/commit/398f2117379f42764e433d19ea0d0cd65009a4aa
  Author: Aviral Goel <aviralg at users.noreply.github.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/include/clang/ScalableStaticAnalysis/Core/EntityLinker/StaticLibrary.h
    M clang/include/clang/ScalableStaticAnalysis/Core/EntityLinker/TUSummaryEncoding.h
    A clang/test/Analysis/Scalable/ssaf-linker/Outputs/lib-explicit-triple.json
    A clang/test/Analysis/Scalable/ssaf-linker/Outputs/lib-namespace-override.json
    A clang/test/Analysis/Scalable/ssaf-linker/Outputs/libempty.json
    A clang/test/Analysis/Scalable/ssaf-linker/Outputs/libtwo.json
    M clang/test/Analysis/Scalable/ssaf-linker/help.test
    A clang/test/Analysis/Scalable/ssaf-linker/static-library-create.test
    A clang/test/Analysis/Scalable/ssaf-linker/static-library-help.test
    A clang/test/Analysis/Scalable/ssaf-linker/static-library-time.test
    A clang/test/Analysis/Scalable/ssaf-linker/static-library-verbose.test
    M clang/tools/clang-ssaf-linker/CMakeLists.txt
    M clang/tools/clang-ssaf-linker/SSAFLinker.cpp
    A clang/tools/clang-ssaf-linker/StaticLibraryCreateCLI.cpp
    A clang/tools/clang-ssaf-linker/StaticLibraryCreateCLI.h

  Log Message:
  -----------
  [clang][ssaf] Add static-library create subcommand (#208799)

This change adds `clang-ssaf-linker static-library create` for bundling
TU summaries into a StaticLibrary archive. The linker has been
refactored to dispatch on `cl::SubCommand`; invocations without a
subcommand still run the existing linker pipeline unchanged for backward
compatibility.

rdar://181930526


  Commit: 9f839a4396916283cc28e45d18d7f4742ad5094a
      https://github.com/llvm/llvm-project/commit/9f839a4396916283cc28e45d18d7f4742ad5094a
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/SLPVectorizer.cpp

  Log Message:
  -----------
  [SLP][NFC]Fix non-determinism in pointers comparison, NFC



Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/210216


  Commit: a07b91d8243b8a8051dbbe5739eacc7942269c61
      https://github.com/llvm/llvm-project/commit/a07b91d8243b8a8051dbbe5739eacc7942269c61
  Author: Med Ismail Bennani <ismail at bennani.ma>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M lldb/bindings/python/CMakeLists.txt
    M lldb/bindings/python/python-wrapper.swig
    M lldb/docs/CMakeLists.txt
    A lldb/examples/python/templates/scripted_stackframe_recognizer.py
    A lldb/include/lldb/Interpreter/Interfaces/ScriptedStackFrameRecognizerInterface.h
    M lldb/include/lldb/Interpreter/ScriptInterpreter.h
    M lldb/include/lldb/Target/StackFrameRecognizer.h
    M lldb/include/lldb/lldb-enumerations.h
    M lldb/include/lldb/lldb-forward.h
    M lldb/source/Interpreter/ScriptInterpreter.cpp
    M lldb/source/Plugins/ScriptInterpreter/Python/CMakeLists.txt
    M lldb/source/Plugins/ScriptInterpreter/Python/Interfaces/ScriptInterpreterPythonInterfaces.cpp
    M lldb/source/Plugins/ScriptInterpreter/Python/Interfaces/ScriptInterpreterPythonInterfaces.h
    M lldb/source/Plugins/ScriptInterpreter/Python/Interfaces/ScriptedPythonInterface.cpp
    A lldb/source/Plugins/ScriptInterpreter/Python/Interfaces/ScriptedStackFrameRecognizerPythonInterface.cpp
    A lldb/source/Plugins/ScriptInterpreter/Python/Interfaces/ScriptedStackFrameRecognizerPythonInterface.h
    M lldb/source/Plugins/ScriptInterpreter/Python/SWIGPythonBridge.h
    M lldb/source/Plugins/ScriptInterpreter/Python/ScriptInterpreterPython.cpp
    M lldb/source/Plugins/ScriptInterpreter/Python/ScriptInterpreterPythonImpl.h
    M lldb/source/Target/StackFrameRecognizer.cpp
    M lldb/test/API/commands/frame/recognizer/TestFrameRecognizer.py
    M lldb/test/API/commands/frame/recognizer/recognizer.py
    M lldb/unittests/ScriptInterpreter/Python/PythonTestSuite.cpp

  Log Message:
  -----------
  [lldb/script] Migrate frame recognizers onto ScriptedPythonInterface  (#209805)

Give `frame recognizer add -l` a formal
ScriptedStackFrameRecognizerInterface, matching the architecture already
used by ScriptedProcess, ScriptedBreakpoint, etc.: a C++ interface
header, a Python-backed implementation built on
ScriptedPythonInterface's CreatePluginObject/Dispatch machinery,
PluginManager registration, and a generatable Python ABC template
(scripted_stackframe_recognizer.py).

get_recognized_arguments' documented contract returns a plain list of
lldb.SBValue (not an lldb.SBValueList), so it bypasses the generic
Dispatch<ValueObjectListSP>() extractor and calls the SWIG bridge
directly, matching the legacy behavior exactly.

ScriptedStackFrameRecognizer now holds a single interface object created
once in its constructor and reused across every RecognizeFrame() call,
same lifecycle as before.

Signed-off-by: Med Ismail Bennani <ismail at bennani.ma>


  Commit: 3e1948e9a528d1bc82f2a671a00c02fa8717f26f
      https://github.com/llvm/llvm-project/commit/3e1948e9a528d1bc82f2a671a00c02fa8717f26f
  Author: Eric Christopher <echristo at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/unittests/IR/MetadataTest.cpp

  Log Message:
  -----------
  Add expression validation tests for DW_OP_swap (#210184)

Add DIExpression validation tests for DW_OP_swap that we noticed were
missing. The tests are based on the existing expression tests for
DW_OP_stack_value.

Tested via make check.

Assisted by AI.


  Commit: b9869c8c920a7dfa983e215bc30729b13d8b353b
      https://github.com/llvm/llvm-project/commit/b9869c8c920a7dfa983e215bc30729b13d8b353b
  Author: Shanzhi Chen <chenshanzhi at huawei.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AArch64/AArch64ISelLowering.cpp
    M llvm/lib/Target/AArch64/AArch64ISelLowering.h
    M llvm/test/CodeGen/AArch64/sve-fixed-length-masked-64-128bit-loads.ll
    M llvm/test/CodeGen/AArch64/sve-fixed-length-masked-64-128bit-stores.ll

  Log Message:
  -----------
  [AArch64][SVE] Support lowering masked loads/stores of <4 x bf16> and <8 x bf16> (#208744)

Add support for lowering masked loads/stores of <4 x bf16> and <8 x
bf16> when target features contain "+sve" and "+bf16".

Fixes: #201149


  Commit: 464b46a73b7592c95222cf2e64b34ffe6f2cf251
      https://github.com/llvm/llvm-project/commit/464b46a73b7592c95222cf2e64b34ffe6f2cf251
  Author: Benjamin Luke <benjamin.luke at sony.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M clang/docs/ReleaseNotes.md
    M clang/include/clang/Basic/ABIVersions.def
    M clang/include/clang/Basic/LangOptions.def
    M clang/include/clang/CodeGen/CGFunctionInfo.h
    M clang/include/clang/CodeGen/CodeGenABITypes.h
    M clang/lib/CodeGen/ABIInfo.h
    M clang/lib/CodeGen/CGCUDARuntime.cpp
    M clang/lib/CodeGen/CGCall.cpp
    M clang/lib/CodeGen/CGClass.cpp
    M clang/lib/CodeGen/CGDeclCXX.cpp
    M clang/lib/CodeGen/CGExpr.cpp
    M clang/lib/CodeGen/CGExprCXX.cpp
    M clang/lib/CodeGen/CGExprComplex.cpp
    M clang/lib/CodeGen/CGHLSLRuntime.cpp
    M clang/lib/CodeGen/CGObjCRuntime.cpp
    M clang/lib/CodeGen/CGVTables.cpp
    M clang/lib/CodeGen/CodeGenABITypes.cpp
    M clang/lib/CodeGen/CodeGenFunction.cpp
    M clang/lib/CodeGen/CodeGenFunction.h
    M clang/lib/CodeGen/CodeGenTypes.h
    M clang/lib/CodeGen/ItaniumCXXABI.cpp
    M clang/lib/CodeGen/MicrosoftCXXABI.cpp
    M clang/lib/CodeGen/Targets/X86.cpp
    M clang/test/CodeGen/sysv_abi.c
    A clang/test/CodeGen/target-avx-function-abi.c
    A clang/test/CodeGenCXX/target-avx-method-abi.cpp
    M clang/unittests/CodeGen/CodeGenExternalTest.cpp
    M clang/unittests/CodeGen/TestCompiler.h

  Log Message:
  -----------
  [clang][CodeGen][X86_64] Honor per-function AVX ABI in C/C++ call paths, maintain old psABI for PlayStation. (#193298)

Fixes https://github.com/llvm/llvm-project/issues/64706

Wire per function x86 AVX ABI level into CodeGen arrangement methods so
__attribute(__target("avx"))) / __attribute(__target("avx512f"))) on
methods, ctors, and free-functions affects ABI lowering consistently.
    
Specifically:
- Added X86AVXABILevel member to CGFunctionInfo.
- Populated X86AVXABILevel member in CGFunctionInfo objects via
arrangement methods declared in CodeGenTypes.h.
- Respect CGFunctionInfo AVX Level in X86_64ABIInfo::computeInfo.
- Add/extend regression tests for:
- free-function target-attribute AVX ABI lowering
- C++ method/ctor target-attribute AVX ABI lowering
- PS4/PS5 legacy ABI behavior (no per-function AVX ABI change)

---------

Co-authored-by: Aaron Ballman <aaron at aaronballman.com>


  Commit: 7fec267c9a44c76604e1135ee0ef694c4eaae784
      https://github.com/llvm/llvm-project/commit/7fec267c9a44c76604e1135ee0ef694c4eaae784
  Author: sohail <sohailraj.satapathy at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libc/test/src/stdfix/DiviFxTest.h

  Log Message:
  -----------
  [libc][stdfix] Guard DiviFxTest shift edge cases against narrow IntType (#209970)

Fixes riscv32 buildbot failure from #206115.


  Commit: 9d2181c78f4e248069e39ec0e5b899dfbfcf3d6a
      https://github.com/llvm/llvm-project/commit/9d2181c78f4e248069e39ec0e5b899dfbfcf3d6a
  Author: Eric Christopher <echristo at gmail.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M llvm/lib/CodeGen/AsmPrinter/DwarfExpression.cpp

  Log Message:
  -----------
  [NFC] Reuse DwarfExpression fragment (#210181)

Reuse DwarfExpression fragment information since nothing changes it
between the outside of the loop and the inside of the loop.

Tested via make check.

Assisted by AI.


  Commit: 1a3347f608394b12c5a18cb5b3457af4e85449a1
      https://github.com/llvm/llvm-project/commit/1a3347f608394b12c5a18cb5b3457af4e85449a1
  Author: Jordan Rupprecht <rupprecht at google.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M utils/bazel/llvm-project-overlay/clang/BUILD.bazel

  Log Message:
  -----------
  [bazel][clang][ssaf] Fix 398f2117379f42764e433d19ea0d0cd65009a4aa (#210222)


  Commit: 27d7b61322f1528cc582a62d1b74683d24cc987b
      https://github.com/llvm/llvm-project/commit/27d7b61322f1528cc582a62d1b74683d24cc987b
  Author: Harrison Hao <57025411+harrisonGPU at users.noreply.github.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Scalar/GVN.cpp

  Log Message:
  -----------
  [GVN][NFC] Use LoadInst::getProperties() when creating PRE load (#208605)

Use load's properties via getProperties() instead of individually
forwarding isVolatile(), getAlign(), getOrdering() and getSyncScopeID().

Reference: https://github.com/llvm/llvm-project/pull/206470


  Commit: 4a75259134c72d8be7fa3ea36c9dc7bfc02640ac
      https://github.com/llvm/llvm-project/commit/4a75259134c72d8be7fa3ea36c9dc7bfc02640ac
  Author: hev <wangrui at loongson.cn>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/LoongArch/LoongArchISelLowering.cpp
    A llvm/test/CodeGen/LoongArch/lasx/issue207316.ll
    M llvm/test/CodeGen/LoongArch/lasx/xvexth.ll
    M llvm/test/CodeGen/LoongArch/lsx/vexth.ll

  Log Message:
  -----------
  [LoongArch] Fix invalid VEXTH combines for unsupported type extensions (#209725)

`performEXTENDCombine` could form `VEXTH`/`VEXTH_U` nodes for
unsupported type combinations, such as extending `v8i8` to `v8i32` or
`v2i64` to `v2i128`. These illegal nodes would later reach instruction
selection and trigger backend failures:

* `Cannot select: LoongArchISD::VEXTH`
* `Don't know how to legalize this operation`

Prevent these combines from firing by verifying that the destination
type is legal and has exactly twice the total bit width of the source
before forming a `VEXTH`/`VEXTH_U` node.
    
Apply the same checks to `performSHLCombine` for consistency.


Fixes
https://github.com/llvm/llvm-project/pull/207316#issuecomment-4978234865
Fixes
https://github.com/llvm/llvm-project/pull/207316#issuecomment-4979233899


  Commit: 8aaa15e82688177db7c0c3fa06103d10f6799598
      https://github.com/llvm/llvm-project/commit/8aaa15e82688177db7c0c3fa06103d10f6799598
  Author: Haohai Wen <haohai.wen at intel.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/include/llvm/ObjectYAML/BBAddrMapYAML.h
    M llvm/lib/ObjectYAML/BBAddrMapYAML.cpp
    M llvm/lib/ObjectYAML/ELFEmitter.cpp

  Log Message:
  -----------
  [ObjectYAML][NFC] Hoist BBAddrMap yaml2obj encoder into a shared helper (#205991)

Preparatory NFC refactor to let the upcoming COFF emitter reuse the
BBAddrMap YAML encoder.


  Commit: ddd21a5500bc65354211c0088520d0b331e862d7
      https://github.com/llvm/llvm-project/commit/ddd21a5500bc65354211c0088520d0b331e862d7
  Author: Vijay Kandiah <vkandiah at nvidia.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M flang/include/flang/Lower/CUDA.h
    M flang/lib/Lower/Allocatable.cpp
    M flang/lib/Lower/ConvertVariable.cpp
    M flang/lib/Semantics/resolve-names.cpp
    A flang/test/Lower/CUDA/cuda-gpu-unified.cuf
    R flang/test/Lower/CUDA/cuda-implicit-managed-alloc.cuf

  Log Message:
  -----------
  [flang][cuda] Managed backing for -gpu=unified allocatables/pointers (#210149)

Under `-gpu=unified`, allocatables and pointers with no explicit CUDA data
attribute must be reachable from the device. Back them with CUDA managed
memory by selecting the unified allocator index at the ALLOCATE site (in
lowering), instead of stamping an implicit `Unified`/`Managed` CUDA data attribute
on the symbol in the frontend — the approach introduced in PR #209292.
This is necessary because attributing the symbol in the frontend routed every
plain allocatable/pointer through the CUDA Fortran managed descriptor
pipeline (constructor registration, `cuf.allocate`/`cuf.free`), which added
per-`ALLOCATE` overhead, forced special-casing for objects that may not legally carry a
CUDA attribute (COMMON members, derived-type components, module globals), and
changed symbol semantics used well beyond allocation. Choosing the allocator
index at the `ALLOCATE` site keeps the object a plain host allocatable/pointer while
the storage still comes from the managed allocator.


  Commit: 963e226d9a6b923b10c8e328438838bd42e03d18
      https://github.com/llvm/llvm-project/commit/963e226d9a6b923b10c8e328438838bd42e03d18
  Author: Tom Stellard <tstellar at redhat.com>
  Date:   2026-07-16 (Thu, 16 Jul 2026)

  Changed paths:
    M .github/workflows/release-binaries.yml
    M .github/workflows/validate-release-version/action.yml

  Log Message:
  -----------
  workflows: Fixes for release-binaries and upload-release-artifact (#209246)

There were some bugs in upload-release-artifact workflow and
release-binaries was not including this action in its checkout.


  Commit: fe64fbbafc19e46ef461fac3ec0b4144a1ffc847
      https://github.com/llvm/llvm-project/commit/fe64fbbafc19e46ef461fac3ec0b4144a1ffc847
  Author: Madhur Amilkanthwar <madhura at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/SLPVectorizer.cpp
    M llvm/lib/Transforms/Vectorize/SLPVectorizer/SLPUtils.cpp
    M llvm/lib/Transforms/Vectorize/SLPVectorizer/SLPUtils.h

  Log Message:
  -----------
  [SLP][modularisation][NFC] Extract mask, shuffle and AA helpers into SLUtils 3/3 (#209973)

Move the mask/shuffle construction and alias-analysis free helpers out
of SLPVectorizer.cpp into SLPVectorizer/SLPUtils.{h,cpp} (namespace
llvm::slpvectorizer).

Moved:
  transformScalarShuffleIndiciesToVector
  getShufflevectorNumGroups
  calculateShufflevectorMask
  UseMask (enum)
  buildUseMask
  isUndefVector
  doesInTreeUserNeedToExtract
  getLocation
  isSimple
  addMask
  fixupOrderingIndices
  getAltInstrMask
  replicateMask

RFC: https://discourse.llvm.org/t/modularizing-slpvectorizer-cpp/90922


  Commit: 3c6b4870425e7b62a966ff04f51f78920adbedb8
      https://github.com/llvm/llvm-project/commit/3c6b4870425e7b62a966ff04f51f78920adbedb8
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M orc-rt/include/orc-rt/Session.h
    M orc-rt/include/orc-rt/TaskGroup.h
    M orc-rt/test/unit/SessionTest.cpp
    M orc-rt/test/unit/TaskGroupTest.cpp

  Log Message:
  -----------
  [orc-rt] Add TaskGroup::TokenSource; drop raw group accessor (#210240)

Session::managedCodeTaskGroup() returned the raw
std::shared_ptr<TaskGroup> for the managed-code group, exposing the
group's full interface -- including close() and addOnComplete() -- to
callers, even though those operations are reserved for the Session.

Add TaskGroup::TokenSource, a strong handle whose sole role is to serve
as an argument to the TaskGroup::Token constructor. Session now exposes
managedCodeTokenSource() in its place, so clients can acquire tokens (to
keep managed code alive across shutdown) without gaining the ability to
close the group or register completion callbacks.


  Commit: f2ef5670cf70371153caeb0ebbeae2323a61f8e0
      https://github.com/llvm/llvm-project/commit/f2ef5670cf70371153caeb0ebbeae2323a61f8e0
  Author: Carl Ritson <carl.ritson at amd.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AMDGPU/AMDGPUWaitSGPRHazards.cpp
    M llvm/lib/Target/AMDGPU/GCNHazardRecognizer.cpp
    M llvm/test/CodeGen/AMDGPU/atomic_optimizations_dpp_lds_expected_active_lanes.ll
    M llvm/test/CodeGen/AMDGPU/atomic_optimizations_global_pointer.ll
    M llvm/test/CodeGen/AMDGPU/atomic_optimizations_local_pointer.ll
    M llvm/test/CodeGen/AMDGPU/atomic_optimizations_pixelshader.ll
    M llvm/test/CodeGen/AMDGPU/gfx11-sgpr-hazard-latency.mir
    M llvm/test/CodeGen/AMDGPU/global-saddr-atomics-min-max-system.ll
    M llvm/test/CodeGen/AMDGPU/global_atomics_scan_fadd.ll
    M llvm/test/CodeGen/AMDGPU/global_atomics_scan_fmax.ll
    M llvm/test/CodeGen/AMDGPU/global_atomics_scan_fmin.ll
    M llvm/test/CodeGen/AMDGPU/global_atomics_scan_fsub.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.add.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.and.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.fadd.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.fmax.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.fmin.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.fsub.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.max.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.min.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.or.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.sub.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.umax.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.umin.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.xor.ll
    M llvm/test/CodeGen/AMDGPU/valu-mask-write-hazard.mir

  Log Message:
  -----------
  [AMDGPU] Refactor GFX11 VALU Mask Hazard Waitcnt Merging (#169213)

Move GFX11 SGPR VALU mask hazard waitcnt merging to the a forward scan
within the AMDGPUWaitSGPRHazard pass.
This simplifies the hazard recognizer code and allows merging of waitcnt
instructions in cases where SGPRs unaffected by pending writes are used.
In turn this greatly decreasing numbers of waits inserted in sequences
of V_CMP instructions writing SGPRs improving VALU pipeline performance.


  Commit: 78ed03f555ea75d2337f618930c062f4d881a08b
      https://github.com/llvm/llvm-project/commit/78ed03f555ea75d2337f618930c062f4d881a08b
  Author: Eugene Epshteyn <eepshteyn at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    A flang/test/Lower/global-initialization-parens.f90

  Log Message:
  -----------
  [flang] Add lowering tests for parenthesized initial values (#209664)

Add a LIT test that baselines the current lowering of parenthesized
initial values in fir.global initializer regions. Today a parenthesized
scalar or derived constant survives constant folding as a Parentheses
node and is lowered to a fir.no_reassoc operation inside the global init
region, while parentheses around characters, array named-constants, and
structure-constructor components are stripped before lowering.

This test pins that behavior so that an upcoming change to the
initializer-lowering path shows its behavior delta explicitly and has a
regression guard.

Assisted-by: AI


  Commit: 15ae01dd24261bd70947aab884098e5dcd4096dd
      https://github.com/llvm/llvm-project/commit/15ae01dd24261bd70947aab884098e5dcd4096dd
  Author: David Zbarsky <dzbarsky at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang-tools-extra/clangd/CMakeLists.txt
    A clang-tools-extra/clangd/LSPBinder.cpp
    M clang-tools-extra/clangd/LSPBinder.h
    M llvm/include/llvm/Support/LSP/Transport.h
    M llvm/lib/Support/LSP/Transport.cpp
    M llvm/utils/gn/secondary/clang-tools-extra/clangd/BUILD.gn
    M utils/bazel/llvm-project-overlay/clang-tools-extra/clangd/BUILD.bazel

  Log Message:
  -----------
  [clangd][Support] Outline LSP payload decode errors (#203121)

Move failed payload handling from `clangd::LSPBinder::parse<T>` and
`llvm::lsp::MessageHandler::parse<T>` into their non-inline
`handleParseError` functions, while keeping successful payload
conversion specialized in each `parse<T>` instantiation.

For a Darwin arm64 build, stripped clangd decreased by 32,848 bytes and
`__TEXT,__text` decreased by 25,180 bytes.

`ClangdTests --gtest_filter=LSPBinderTest.*` passes, and
`llvm/lib/Support/LSP/Transport.cpp` passes a standalone syntax compile.

Work towards #202616

AI tool disclosure: Co-authored with OpenAI Codex.

Co-authored-by: OpenAI Codex <noreply at openai.com>


  Commit: c488b2c2407bf29bb20f67bb8f3cf39c637d231e
      https://github.com/llvm/llvm-project/commit/c488b2c2407bf29bb20f67bb8f3cf39c637d231e
  Author: Sameer Sahasrabuddhe <sameer.sahasrabuddhe at amd.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/docs/AMDGPUDMAOperations.md

  Log Message:
  -----------
  [Docs][AMDGPU] Consistent use of "wave-uniform", "per-lane" and "immediate" (#209974)

When documenting DMA operations, use consistent qualifiers
(wave-uniform, per-lane, immediate) instead of referring to SGPRs and
VGPRs.

Assisted-By: Claude Opus 4.6


  Commit: a376783e2ed3a44f63991c97513711faad09525b
      https://github.com/llvm/llvm-project/commit/a376783e2ed3a44f63991c97513711faad09525b
  Author: maflcko <6399679+maflcko at users.noreply.github.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M compiler-rt/lib/ubsan/ubsan_diag.cpp
    M compiler-rt/test/ubsan/TestCases/Integer/suppressions-nested-calls.c

  Log Message:
  -----------
  [compiler-rt][ubsan] Fix suppressions for inlined functions (#206735)

Align suppression PC handling with getCallerLocation(), so function
suppressions identify the inlined function that caused a report.

Intentionally match only the innermost inline frame.

Extend suppressions-nested-calls.c coverage to -O1.


Fixes https://github.com/llvm/llvm-project/issues/209501

---------

Co-authored-by: MarcoFalke <*~=`'#}+{/-|&$^_ at 721217.xyz>


  Commit: 30bc042395a6cf0aa1e5de4fcc625d5b8c611767
      https://github.com/llvm/llvm-project/commit/30bc042395a6cf0aa1e5de4fcc625d5b8c611767
  Author: maflcko <6399679+maflcko at users.noreply.github.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M compiler-rt/test/lit.common.cfg.py

  Log Message:
  -----------
  [compiler-rt][test] Use configured Python for lit page-size probe (#209175)

Use the same Python executable configured for the test suite, rather
than relying on python3 being on PATH.

Co-authored-by: MarcoFalke <*~=`'#}+{/-|&$^_ at 721217.xyz>


  Commit: c5837b469c6d6f35eb0822cd9ebd7c2aa7e2ab75
      https://github.com/llvm/llvm-project/commit/c5837b469c6d6f35eb0822cd9ebd7c2aa7e2ab75
  Author: Pavel Labath <pavel at labath.sk>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libc/test/src/sys/socket/linux/CMakeLists.txt
    M libc/test/src/sys/socket/linux/bind_test.cpp
    M libc/test/src/sys/socket/linux/connect_accept_test.cpp
    M libc/test/src/sys/socket/linux/listen_test.cpp
    M libc/test/src/sys/socket/linux/socket_test_support.h
    M libc/test/src/sys/socket/linux/sockname_test.cpp
    M utils/bazel/llvm-project-overlay/libc/BUILD.bazel
    M utils/bazel/llvm-project-overlay/libc/test/src/sys/socket/BUILD.bazel

  Log Message:
  -----------
  [libc][bazel] Add remaining sys/socket functions and tests (#209798)

This patch adds the following sys/socket functions and syscall wrapper
libraries to BUILD.bazel:
- accept
- accept4
- bind
- connect
- getpeername
- getsockname
- listen
- sockatmark

I'm also enabling the unit tests for these functions. Running AF_UNIX
socket tests under Bazel ran into a problem where the absolute path to
the test sandbox directory exceeds the 108-byte limit of
sockaddr_un::sun_path. To work around that, I added a TestDirectoryScope
helper that temporarily chdirs into the test directory so the tests can
use short relative filenames, and restores the original working
directory on exit.

Assisted by Gemini.


  Commit: 9445ad3f91d4331eead867f8b3c9c8a3818edac0
      https://github.com/llvm/llvm-project/commit/9445ad3f91d4331eead867f8b3c9c8a3818edac0
  Author: Rana Pratap Reddy <RanaPratapReddy.Nimmakayala at amd.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/lib/CIR/CodeGen/CIRGenTypes.cpp
    A clang/test/CIR/CodeGenHIP/amdgcn-buffer-rsrc-type.hip

  Log Message:
  -----------
  [CIR][AMDGPU] Adds `__amdgpu_buffer_rsrc_t` in the buffer-resource address space (#204782)

CIR previously lowering every AMDGPU opaque pointer to
`!cir.ptr<!void>`. Now `__amdgpu_buffer_rsrc_t` lower to
`!cir.ptr<!void, target_address_space(8)>` similar to (`ptr
addrspace(8)` in LLVM IR) matching CodeGen.

This change requires for upcoming raw buffer load/store/atomic builtins.
Those builtins `__builtin_amdgcn_raw_buffer_load/store_b*,
__builtin_amdgcn_raw_ptr_buffer_atomic_*` take a
`__amdgpu_buffer_rsrc_t` as operand, and the corresponding LLVM
intrinsics expect a `ptr addrspace(8)` resource argument.


  Commit: 513ac13e7e5037af4b39c8c582dd7927f4c807fc
      https://github.com/llvm/llvm-project/commit/513ac13e7e5037af4b39c8c582dd7927f4c807fc
  Author: SiHuaN <liyongtai at iscas.ac.cn>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/lib/Headers/riscv_packed_simd.h
    M clang/test/CodeGen/RISCV/rvp-intrinsics.c

  Log Message:
  -----------
  [Clang][RISCV] Add P extension reinterpret cast intrinsics (#210241)

Implement the "Reinterpret casts" section of the RISC-V P extension intrinsic
spec in `riscv_packed_simd.h`.

The 82 `__riscv_preinterpret_<from>_<to>` intrinsics provide
bit-pattern-preserving conversions between packed types and equal-width
scalars, and between equal-width packed types. They generate no instructions;
each is a `__builtin_bit_cast`.


  Commit: 61fa8d3db491c4a864242f22ce31b730fb78ecb5
      https://github.com/llvm/llvm-project/commit/61fa8d3db491c4a864242f22ce31b730fb78ecb5
  Author: Matt Arsenault <Matthew.Arsenault at amd.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/include/llvm/CodeGen/LibcallLoweringInfo.h
    M llvm/lib/CodeGen/AtomicExpandPass.cpp
    M llvm/lib/CodeGen/DwarfEHPrepare.cpp
    M llvm/lib/CodeGen/ExpandIRInsts.cpp
    M llvm/lib/CodeGen/LibcallLoweringInfo.cpp
    M llvm/lib/CodeGen/PreISelIntrinsicLowering.cpp
    M llvm/lib/CodeGen/SafeStack.cpp
    M llvm/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp
    M llvm/lib/CodeGen/StackProtector.cpp
    M llvm/lib/Target/AArch64/GISel/AArch64O0PreLegalizerCombiner.cpp
    M llvm/lib/Target/AArch64/GISel/AArch64PreLegalizerCombiner.cpp

  Log Message:
  -----------
  CodeGen: Rename LibcallLoweringModuleAnalysisResult to ModuleLibcallLoweringInfo (#210176)


  Commit: 6f2bd9fd1a5e7c61893abf2f1e9246610e6a32f8
      https://github.com/llvm/llvm-project/commit/6f2bd9fd1a5e7c61893abf2f1e9246610e6a32f8
  Author: Valentin Clement (バレンタイン クレメン) <clementval at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M flang/include/flang/Optimizer/Transforms/Passes.td
    M flang/lib/Optimizer/Transforms/CUDA/CUFDeviceFuncTransform.cpp
    A flang/test/Fir/CUDA/cuda-device-func-transform-aio.mlir

  Log Message:
  -----------
  [flang][cuda] Add option to flag descriptor I/O as error (#210170)

Descriptor I/O is too expensive in some compilation mode (nordc). Add
ability to emit an error if they are found in device code.


  Commit: 02f55a9e5e4775bc17cc23f9d1e7f5ee23cf63cd
      https://github.com/llvm/llvm-project/commit/02f55a9e5e4775bc17cc23f9d1e7f5ee23cf63cd
  Author: Pavel Labath <pavel at labath.sk>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libc/config/linux/aarch64/headers.txt
    M libc/config/linux/riscv/headers.txt
    M libc/config/linux/x86_64/headers.txt

  Log Message:
  -----------
  [libc] add net/if.h to the list of installed headers (#210021)

on aarch64, riscv and x86_64.


  Commit: c571b0bd7330a4b737ad7dec31e7f2b52edd3953
      https://github.com/llvm/llvm-project/commit/c571b0bd7330a4b737ad7dec31e7f2b52edd3953
  Author: Pavel Labath <pavel at labath.sk>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libc/include/llvm-libc-types/struct_sockaddr_storage.h
    M libc/test/src/sys/socket/linux/sockaddr_storage_test.cpp

  Log Message:
  -----------
  [libc] Fix size of struct sockaddr_storage (#210037)

My cleverness with the union backfired as it introduced an
(architecture-specific) padding between before it. Drop the union to
avoid that.

This probably wouldn't break much as the structure exists just to
allocate space (and this made it larger), but we should fix it
nonetheless.


  Commit: c4903855b64ee801d1b9caeb970921a63475c98b
      https://github.com/llvm/llvm-project/commit/c4903855b64ee801d1b9caeb970921a63475c98b
  Author: Michael Kruse <llvm-project at meinersbur.de>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M flang-rt/CMakeLists.txt
    M flang/test/Driver/fakeflang.F
    M flang/tools/fakeflang/fakeflang.cpp
    M runtimes/cmake/config-Fortran.cmake

  Log Message:
  -----------
  [fakeflang] Also detect CMakeTestGNU.c (#210175)

Two fixes when using CMake < 3.28 after #209482:

* In addition to `flang`, also recognize `fakeflang` to determine
whether any workaround for CMake not completely supporting Flang is
needed. `fakeflang` is used as a shim in #209482.

* For CMake < 3.24, CMake does not reognize Flang at all and tries other
methods to detect to the compiler, including the file `CMakeTestGNU.c`.
Make `fakeflang` recognize it as a probe attempt.

This should fix the
[openmp-offload-amdgpu-clang-flang](https://lab.llvm.org/buildbot/#/builders/67)
buildbot. The buildbot is currently upgrade to a newer CMake version,
and the minimum required version of CMake will become 3.31 soon.


  Commit: 250f791e7002afb308e4a59dc5ef3e1f2e1c10af
      https://github.com/llvm/llvm-project/commit/250f791e7002afb308e4a59dc5ef3e1f2e1c10af
  Author: Raphael Isemann <rise at apple.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lldb/source/Plugins/SymbolLocator/DebugSymbols/SymbolLocatorDebugSymbols.cpp

  Log Message:
  -----------
  [lldb] Fix tsan error in SymbolLocatorDebugSymbols (#209698)

g_dlsym_DBGCopyFullDSYMURLForUUID and g_dlsym_DBGCopyDSYMPropertyLists
are two globals that are lazily initialized when first used. TSan
complains that this lazy init code is not thread-safe as there is no
synchronization mechanism. In practice, the only race that can happen
here is that we initialize the same values concurrently, which should be
'safe' on any platform.

This patch moves the initialization code into a static local that
returns a const object. This makes this code thread-safe by construction
and fixes the TSan error.

It also fixes that we keep calling dlopen if the initialization fails.
That is, the `g_dlsym_DBGCopyFullDSYMURLForUUID == nullptr` will always
be true on systems where the framework doesn't exist, so this code will
try loading it on every function call and fail.


  Commit: 89f5334990c5aa853fcbaa361aefe5b999e63dc5
      https://github.com/llvm/llvm-project/commit/89f5334990c5aa853fcbaa361aefe5b999e63dc5
  Author: Jeff Bailey <jbailey at raspberryginger.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libc/docs/CMakeLists.txt
    R libc/docs/headers/time.rst
    A libc/utils/docgen/time.yaml

  Log Message:
  -----------
  [libc][docs] Dynamically generate time.h documentation (#210197)

Removed the static time.rst file.

Added time to docgen_list in libc/docs/CMakeLists.txt. Created
libc/utils/docgen/time.yaml to define the functions.

Assisted-by: Automated tooling, human reviewed.


  Commit: d68dc184b1cec0a01876b3f635bce6c25a64edf6
      https://github.com/llvm/llvm-project/commit/d68dc184b1cec0a01876b3f635bce6c25a64edf6
  Author: Kareem Ergawy <kergawy at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M flang/lib/Lower/PFTBuilder.cpp
    A flang/test/Lower/pre-fir-tree-assigned-goto.f90

  Log Message:
  -----------
  [flang][PFT] record every target of an assigned GO TO (#210065)

Assigned GO TO (`go to v [, (l1, l2, ...)]`) is the third multiway
branch in the language, alongside the computed GO TO and arithmetic IF
that were addressed in PR #210012. Its PFTBuilder handler previously
did:

    [&](const parser::AssignedGotoStmt &) {
      eval.isUnstructured = true;
      markSuccessorAsNewBlock(eval);
    },

i.e. it recorded no branch targets at all -- neither `controlSuccessor`
nor `extraControlSuccessors` was populated.

Handle the assigned GO TO the same way PR #210012 handles the computed
GO TO and arithmetic IF: iterate every possible target and call
`markBranchTarget(eval, label)` for each, so that `controlSuccessor`
receives the first and `extraControlSuccessors` receives the rest.

Co-authored-by: Claude Sonnet 4.6 <noreply at anthropic.com>


  Commit: d134db0b2b989a2b15f91f24acca43497dfe0919
      https://github.com/llvm/llvm-project/commit/d134db0b2b989a2b15f91f24acca43497dfe0919
  Author: Sean Clarke <sclarke at tenstorrent.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Analysis/HashRecognize.cpp
    M llvm/lib/Transforms/Scalar/LoopIdiomRecognize.cpp
    M llvm/test/Analysis/HashRecognize/cyclic-redundancy-check.ll
    M llvm/test/Transforms/LoopIdiom/cyclic-redundancy-check.ll

  Log Message:
  -----------
  [HashRecognize] Remove byte-multiple trip count requirement (#210086)

The newly added carryless-multiply CRC loop optimization (#203405) does
not require a byte-multiple trip count unlike the Sarwate method which
was previously implemented. Loosen this requirement in HashRecognize and
reapply it in `optimizeCRCLoop`.


  Commit: cc98c1eb84c690c65fba77b72c269a869978c898
      https://github.com/llvm/llvm-project/commit/cc98c1eb84c690c65fba77b72c269a869978c898
  Author: Fangrui Song <i at maskray.me>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/include/llvm/ADT/GenericConvergenceVerifier.h
    M llvm/include/llvm/ADT/GenericCycleImpl.h
    M llvm/include/llvm/ADT/GenericCycleInfo.h
    M llvm/include/llvm/ADT/GenericUniformityImpl.h
    M llvm/include/llvm/ADT/GenericUniformityInfo.h
    M llvm/include/llvm/CodeGen/MachineCycleAnalysis.h
    M llvm/include/llvm/IR/CycleInfo.h
    M llvm/include/llvm/IR/GenericConvergenceVerifierImpl.h
    M llvm/lib/Analysis/CFG.cpp
    M llvm/lib/Analysis/UniformityAnalysis.cpp
    M llvm/lib/CodeGen/MachineCycleAnalysis.cpp
    M llvm/lib/CodeGen/MachineSink.cpp
    M llvm/lib/CodeGen/MachineUniformityAnalysis.cpp
    M llvm/lib/IR/CycleInfo.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUGlobalISelDivergenceLowering.cpp
    M llvm/lib/Target/AMDGPU/SIInstrInfo.cpp
    M llvm/lib/Target/AMDGPU/SILowerSGPRSpills.cpp
    M llvm/lib/Transforms/IPO/AttributorAttributes.cpp
    M llvm/lib/Transforms/Scalar/DeadStoreElimination.cpp
    M llvm/lib/Transforms/Utils/BasicBlockUtils.cpp
    M llvm/lib/Transforms/Utils/FixIrreducible.cpp

  Log Message:
  -----------
  [CycleInfo] Represent cycles by an opaque handle. NFC (#210117)

Consumers refer to a cycle by a GenericCycle pointer into
GenericCycleInfo's storage. Introduce GenericCycleRef, a value handle
wrapping the cycle's preorder index, and route every GenericCycleInfo
query and mutation through it. GenericCycle becomes an internal
implementation detail, so its storage representation can change without
touching callers.

Aided by Claude Opus 4.8, reviewed by Fable 5

Suggested by
https://github.com/llvm/llvm-project/pull/208614#pullrequestreview-4683378136


  Commit: 90e31c46d005ae0a7f5968c38a9310bee499923c
      https://github.com/llvm/llvm-project/commit/90e31c46d005ae0a7f5968c38a9310bee499923c
  Author: Nikita Popov <npopov at redhat.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/LTO/LTO.cpp
    A llvm/test/ThinLTO/X86/Inputs/cache-defined-globals-order.ll
    A llvm/test/ThinLTO/X86/cache-defined-globals-order.ll

  Log Message:
  -----------
  [LTO] Sort DefinedGlobals in LTO cache key (#210025)

Sort the DefindeGlobals by GUID when computing the LTO cache key, to
avoid making the cache key dependent on the insertion order. This fixes
large compile-time regressions in rust incremental builds.

Alternatively one could make collectDefinedGVSummariesPerModule() work
on the sortedRange(), but as that is also used in other places, it
probably makes sense to sort locally.

The issue was introduced in 760bb06cb3cd98832f1e4e7a4eaebd98b66d2bdd.


  Commit: b69dd3366863acff56b0b2efdc4c4938097bb43e
      https://github.com/llvm/llvm-project/commit/b69dd3366863acff56b0b2efdc4c4938097bb43e
  Author: Andrzej Warzyński <andrzej.warzynski at arm.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M mlir/test/Integration/Dialect/Vector/CPU/compress.mlir
    M mlir/test/Integration/Dialect/Vector/CPU/expand.mlir
    M mlir/test/Integration/Dialect/Vector/CPU/gather.mlir
    M mlir/test/Integration/Dialect/Vector/CPU/maskedload.mlir
    M mlir/test/Integration/Dialect/Vector/CPU/maskedstore.mlir
    M mlir/test/Integration/Dialect/Vector/CPU/scatter.mlir

  Log Message:
  -----------
  [mlir][vector][nfc] Update integration tests (#210090)

Add comments, unify naming, remove redundant printing hooks.


  Commit: 8b269587981fdc3b487cda5559ef75eeb475e613
      https://github.com/llvm/llvm-project/commit/8b269587981fdc3b487cda5559ef75eeb475e613
  Author: Simon Pilgrim <llvm-dev at redking.me.uk>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/test/Transforms/VectorCombine/X86/fold-signbit-reduction-cmp.ll

  Log Message:
  -----------
  [VectorCombine][X86] Add test coverage for #209714 (#210063)


  Commit: 981c0f9037fc2e1e5c70ba2cfe61128557b5eeff
      https://github.com/llvm/llvm-project/commit/981c0f9037fc2e1e5c70ba2cfe61128557b5eeff
  Author: David Spickett <david.spickett at arm.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lldb/test/API/functionalities/thread/finish-from-empty-func/TestEmptyFuncThreadStepOut.py
    M lldb/test/API/functionalities/thread/finish-from-empty-func/main.c

  Log Message:
  -----------
  [lldb][test] Handle potential compiler differences in TestEmptyFuncThreadStepOut.py (#210050)

Fixes #195958

It was reported that this test sometimes failed in CI because lldb would
step out to line 6 instead of line 7.

Jim Ingham expained on the issue that both could be valid locations
(https://github.com/llvm/llvm-project/issues/195958#issuecomment-4384269846).

There's no garauntee that "step out" would go to the source line after
the call you step out of. All it does is go to the first location
outside of the call. If the compiler so chose, that could be on the same
line as the call.

I was not able to reproduce this failure mode, but I think it was
happening in CI before, and is possible. So I've made the test accept
line 6 or 7. Anything further than that we've gone too far and the test
will fail.


  Commit: 9ee8b18b6c0758e57cedfa57e99ba85dfd247d35
      https://github.com/llvm/llvm-project/commit/9ee8b18b6c0758e57cedfa57e99ba85dfd247d35
  Author: Andrzej Warzyński <andrzej.warzynski at arm.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M mlir/test/Integration/Dialect/Vector/CPU/gather.mlir

  Log Message:
  -----------
  [mlir][vector] Fix e2e test post #210090 (#210270)

Failing bots:
  * https://lab.llvm.org/buildbot/#/builders/177/builds/37626
  * https://lab.llvm.org/buildbot/#/builders/116/builds/30570


  Commit: 4894d4e87c332af24809b20573d880a4073b738b
      https://github.com/llvm/llvm-project/commit/4894d4e87c332af24809b20573d880a4073b738b
  Author: Ian Anderson <iana at apple.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/include/clang/Options/Options.td
    M clang/test/Driver/darwin-target-variant-sdk-version.c

  Log Message:
  -----------
  [clang][driver] Add a -target-variant alias for -darwin-target-variant (#208388)

Swift Build uses the `-target-variant` argument which is an alias for
-darwin-target-variant that's only present in the Xcode version of
clang. Upstream it for general support and parity with swiftc.

Co-authored-by: Alex Lorenz <arphaman at gmail.com>


  Commit: 12c4c0bf0269218c6ffdddae1c895f892a3e4e75
      https://github.com/llvm/llvm-project/commit/12c4c0bf0269218c6ffdddae1c895f892a3e4e75
  Author: Jay Foad <jay.foad at amd.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AMDGPU/AMDGPUHWEvents.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUHWEvents.def
    M llvm/lib/Target/AMDGPU/AMDGPUHWEvents.h
    M llvm/lib/Target/AMDGPU/AMDGPUWaitcntUtils.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUWaitcntUtils.h
    M llvm/lib/Target/AMDGPU/SIInsertWaitcnts.cpp
    M llvm/test/CodeGen/AMDGPU/expert_scheduling_gfx12.mir

  Log Message:
  -----------
  [AMDGPU] Handle expert scheduling VA_VDST WAR hazards (#201619)

Handle WAR hazards where a VALU reading a VGPR is followed by a VMEM
writing the same VGPR. It is possible, though not very common, that the
VMEM will complete first. To guard against this the compiler must insert
a wait on VA_VDST.


  Commit: 2580624091e36b85c162439513eef8e752217a1d
      https://github.com/llvm/llvm-project/commit/2580624091e36b85c162439513eef8e752217a1d
  Author: cqwrteur <oyzawqgcfc at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libcxx/src/support/runtime/exception_pointer_msvc.ipp

  Log Message:
  -----------
  [libcxx] avoid include Uppercase windows headers (#208903)

We should use unknwn.h and windows.h instead of Unknwn.h and Windows.h
because Linux and other non‑Windows systems treat filenames as
case‑sensitive. Windows does not, so mixed‑case includes work there but
break elsewhere. Both mingw‑w64‑crt and windows‑msvc‑sysroot provide all
Windows headers in fully lowercase, so using the lowercase forms ensures
consistent cross‑platform builds.

Fixes #208901


  Commit: a3bcc010c7b7d5fa43ab7928a88312841c4322dd
      https://github.com/llvm/llvm-project/commit/a3bcc010c7b7d5fa43ab7928a88312841c4322dd
  Author: Jacek Caban <jacek at codeweavers.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lld/COFF/Driver.cpp
    M lld/COFF/InputFiles.cpp
    M lld/COFF/InputFiles.h
    A lld/test/COFF/link-dll-arm64x.s

  Log Message:
  -----------
  [LLD] [COFF] Fix linking directly against an ARM64X DLL without import library (#210080)

In mingw mode, when linking against a DLL, the user can either provide a
regular import library, or provide the actual DLL. When importing ARM64X
image, add both native and EC views to the symbol table on EC targets.
Also getMachine() on such images returns ARM64X, treat it as ARM64
instead.


  Commit: f520e7083a12f0642eff8fc19fc4c90ccccc7da5
      https://github.com/llvm/llvm-project/commit/f520e7083a12f0642eff8fc19fc4c90ccccc7da5
  Author: Arseniy Obolenskiy <arseniy.obolenskiy at amd.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/SPIRV/SPIRV.h
    M llvm/lib/Target/SPIRV/SPIRVEmitIntrinsics.cpp
    M llvm/lib/Target/SPIRV/SPIRVTargetMachine.cpp

  Log Message:
  -----------
  [SPIR-V][NewPM] Fix SPIRVEmitIntrinsics registration with the new pass manager (#209966)


  Commit: 0e1b0935ff6f326ba1b9c2d23ba9fa7b41e6941d
      https://github.com/llvm/llvm-project/commit/0e1b0935ff6f326ba1b9c2d23ba9fa7b41e6941d
  Author: Arseniy Obolenskiy <arseniy.obolenskiy at amd.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/SPIRV/SPIRVInstructionSelector.cpp
    M llvm/test/CodeGen/SPIRV/sitofp-with-bool.ll
    M llvm/test/CodeGen/SPIRV/uitofp-with-bool.ll

  Log Message:
  -----------
  [SPIR-V] Preserve signed i1 semantics in sitofp (#209232)

selectIToF hardcoded IsSigned=false when materializing the bool-to-int
conversion, so sitofp i1 true was miscompiled as 1.0 instead of -1.0


  Commit: 5fcab35be3b450256e3b02a735900071c0b74a54
      https://github.com/llvm/llvm-project/commit/5fcab35be3b450256e3b02a735900071c0b74a54
  Author: Jay Foad <jay.foad at amd.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AMDGPU/AsmParser/AMDGPUAsmParser.cpp
    A llvm/test/MC/AMDGPU/amdhsa-kernel-prologue.s
    M llvm/test/MC/AMDGPU/hsa-gfx1250-v4.s
    M llvm/test/MC/AMDGPU/hsa-gfx1251-v4.s

  Log Message:
  -----------
  [AMDGPU] Add assembler check for GFX1250 unclaused vmem workaround (#209517)

Warn if an entrypoint does not start with the standard workaround
sequence.


  Commit: 6cafa889cd398ca70992e0df518b2414a2607327
      https://github.com/llvm/llvm-project/commit/6cafa889cd398ca70992e0df518b2414a2607327
  Author: Nerixyz <nerixdev at outlook.de>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lldb/source/Plugins/SymbolFile/NativePDB/UdtRecordCompleter.cpp
    M lldb/test/Shell/SymbolFile/NativePDB/Inputs/globals-fundamental.lldbinit
    M lldb/test/Shell/SymbolFile/NativePDB/globals-fundamental.cpp
    A lldb/test/Shell/SymbolFile/NativePDB/static-class-constants.cpp

  Log Message:
  -----------
  [lldb][NativePDB] Use active bits for constant width (#196104)

Static constants with bit widths less than 16 (e.g. char/unsigned char)
in classes were not available. These constants are still encoded with 16
bits
([here](https://github.com/llvm/llvm-project/blob/dd145eb8997878143f648a7601741f6409330963/llvm/lib/DebugInfo/CodeView/CodeViewRecordIO.cpp#L341-L343))
even though they only need less bits. When we tried to create an
initializer for them, we'd check if the bit width (=16) was small enough
to fit into the target (<16). This would fail.

This was a problem in the following code:
```cpp
struct Foo {
  // width(unsigned char) = 8, but 255 was encoded and read as 16 bit
  static constexpr unsigned char u8_max = 255;
};
```

This PR fixes the issue by using `APSInt::getActiveBits` for unsigned
types and `APSInt::getSignificantBits` for signed types. They get the
number of bits required to encode the value. For example a constant 64
would need 7 bits in unsigned and 8 bits in signed types.


  Commit: e8f9589942ecd93d94de2af2e875964693e55129
      https://github.com/llvm/llvm-project/commit/e8f9589942ecd93d94de2af2e875964693e55129
  Author: Ilia Kuklin <ikuklin at accesssoftek.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/include/clang/Options/Options.td
    M clang/lib/Driver/ToolChains/Clang.cpp
    M clang/test/Driver/dxc_debug.hlsl
    M llvm/lib/MC/MCDXContainerWriter.cpp
    M llvm/lib/Target/DirectX/DXILWriter/DXILWriterPass.cpp
    M llvm/test/CodeGen/DirectX/ContainerData/ContainerFlags.ll

  Log Message:
  -----------
  [Driver][DirectX] Add `/Qstrip_debug` flag (#204832)

Add the flag that removes ILDB part from the main DXContainer.


  Commit: d444e3ebb8ae69cdb628be3b3b0c632f13df9a08
      https://github.com/llvm/llvm-project/commit/d444e3ebb8ae69cdb628be3b3b0c632f13df9a08
  Author: Chibuoyim (Wilson) Ogbonna <ogbonnachibuoyim12 at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/docs/ReleaseNotes.md
    M clang/lib/AST/ExprCXX.cpp
    M clang/test/SemaCXX/using-decl-templates.cpp

  Log Message:
  -----------
  [Clang][Sema] Fix crash in UnresolvedMemberExpr check (#209792)

This closes https://github.com/llvm/llvm-project/issues/209427

The test currently crashes because while iterating over the candidate
members of an unresolved member expression, `decl` is a `UsingShadowDecl`
with underlying decl as `UnresolvedUsingValueDecl`.

The current `isa<UnresolvedUsingValueDecl>(decl)` guard only checks the
outer `UsingShadowDecl` and misses the unresolved-using decl hidden
inside it, so `getAsFunction()` returns nullptr and
`cast<CXXMethodDecl>(nullptr)` asserts.
 
This patch checks the `UnresolvedUsingValueDecl` inside by calling
`getUnderlyingDecl()` before the guard.

This used to happen before a2794f9f363361f87a3538b90b78ff13381d5ce1.


  Commit: 06effa5b965f68a24dcea8550efc86225b186f54
      https://github.com/llvm/llvm-project/commit/06effa5b965f68a24dcea8550efc86225b186f54
  Author: mayanksolanki393 <mayanksolanki393 at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/IR/Verifier.cpp
    M llvm/test/Verifier/matrix-intrinsics.ll

  Log Message:
  -----------
  [LLVM][Verifier] Remove constant-only matrix stride check (#207665)

Remove the verifier check requiring constant column-major matrix
load/store strides to be greater than or equal to the row count.

The stride operand is not an immarg, so the verifier must not enforce
constraints that only apply when the argument happens to be constant.


  Commit: afa73e4ff6db57b0416eb44127105b8092bd01f8
      https://github.com/llvm/llvm-project/commit/afa73e4ff6db57b0416eb44127105b8092bd01f8
  Author: Antonio Frighetto <me at antoniofrighetto.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Scalar/ConstraintElimination.cpp
    M llvm/test/Transforms/ConstraintElimination/eq.ll
    M llvm/test/Transforms/ConstraintElimination/ne.ll

  Log Message:
  -----------
  [ConstraintElimination] Handle equality predicates with signed system (#205331)

Equality predicate solving has been supported for quite a while, eq/ne
facts were extended to the signed constraint system more recently
(7fb97bee9269f0d4239908ac8def70be696991c6). When solving
eq/ne conditions, query the signed system as well on inconclusive
answers from the unsigned one.

Fixes: https://github.com/llvm/llvm-project/issues/205282.
Fixes: https://github.com/llvm/llvm-project/issues/63505.


  Commit: 2b2df2677619cb0377d27d8b766b8fc265749345
      https://github.com/llvm/llvm-project/commit/2b2df2677619cb0377d27d8b766b8fc265749345
  Author: Jacek Caban <jacek at codeweavers.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lld/COFF/Driver.cpp
    M lld/COFF/InputFiles.cpp
    M lld/COFF/InputFiles.h
    R lld/test/COFF/link-dll-arm64x.s

  Log Message:
  -----------
  Revert "[LLD] [COFF] Fix linking directly against an ARM64X DLL without import library (#210080)" (#210299)

This reverts commit a3bcc010c7b7d5fa43ab7928a88312841c4322dd, which
breaks in asan build.


  Commit: 2a006dff821342c1726fd3137f804186851a26bb
      https://github.com/llvm/llvm-project/commit/2a006dff821342c1726fd3137f804186851a26bb
  Author: Joel Walker <theagingboy05 at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AArch64/AArch64ISelLowering.cpp
    A llvm/test/CodeGen/AArch64/GlobalISel/knownbits-vashr.mir

  Log Message:
  -----------
  [AArch64][GlobalISel] Add sign bits for G_VASHR (#210269)

Ports the `AArch64ISD::VASHR` case from
`ComputeNumSignBitsForTargetNode` to the GlobalISel hook: an arithmetic
right shift by K adds K copies of the sign bit, so the result has
`min(SignBits(Src) + K, ScalarSizeInBits)` sign bits. `G_VASHR`'s shift
amount is always an immediate in `[1, ElementBits]`.

Follow-up to #198314, which added the `G_FCM*` cases.

Assisted by Claude (Anthropic).


  Commit: a4cad33430cf5d2d03eb91ce5e41ed1b9ef7cc4d
      https://github.com/llvm/llvm-project/commit/a4cad33430cf5d2d03eb91ce5e41ed1b9ef7cc4d
  Author: Joel Walker <theagingboy05 at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Support/KnownBits.cpp
    M llvm/test/CodeGen/AArch64/GlobalISel/knownbits-urem.mir
    M llvm/test/Transforms/InstCombine/known-bits.ll

  Log Message:
  -----------
  [KnownBits] Use X < Y identity and umin(MaxX, MaxY - 1) bound in urem (#210262)

Tightens `KnownBits::urem` with the two facts `ConstantRange::urem`
already uses:

- `L % R == L` when `MaxL < MinR`: return the LHS bits unchanged. This
can propagate known one bits, which the current leading-zeros-only
reasoning never produces.
- `L % R <= umin(MaxL, MaxR - 1)`, since a zero divisor is UB: keep that
bound's leading zeros. This is one bit stronger than the per-operand
leading-zero count when `MaxR` is a power of two, and together with
`remGetLowBits` it subsumes the power-of-two-constant special case,
which is removed.

Soundness is covered by the existing exhaustive unit test (widths 1 and
4; additionally brute-forced at width 5). Across all 6480 valid width-4
KnownBits pairs, non-optimal results drop from 3332 to 2090. The
residual is number-theoretic (e.g. the exact value of `10 % 3`), out of
reach of leading-bit/range reasoning, so `CheckOptimality` stays off for
urem, as for udiv (#209360).

Assisted by Claude (Anthropic).


  Commit: 671c0a275a1f304f22855fabb299090233fdbd54
      https://github.com/llvm/llvm-project/commit/671c0a275a1f304f22855fabb299090233fdbd54
  Author: tyan0 <takashi.yano at nifty.ne.jp>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/lib/Driver/ToolChain.cpp
    A clang/test/Driver/Inputs/resource_dir/lib/cygwin/libclang_rt.builtins-x86_64.a
    A clang/test/Driver/Inputs/resource_dir_with_per_target_subdir/lib/x86_64-pc-windows-cygnus/libclang_rt.builtins.a
    A clang/test/Driver/cygwin-print-file-name.c

  Log Message:
  -----------
  [Clang][Driver] Fix compiler-rt library directory for cygwin (#208925)

If compiler-rt is built with `LLVM_ENABLE_PER_TARGET_RUNTIME_DIR=OFF`,
its search directory is incorrect.

Specifically, `ToolChain::getOSLibName()` returns `windows` instead of
`cygwin` in a Cygwin environment, due to falling back to getOS(). This
results in a link error against compiler-rt.

This patch makes `getOSLibName()` return `cygwin`, ensuring that
compiler-rt is linked correctly.

---------

Signed-off-by: Takashi Yano <takashi.yano at nifty.ne.jp>


  Commit: 8377d59dfade3f1a4bf5779ddd90359bd4ddc249
      https://github.com/llvm/llvm-project/commit/8377d59dfade3f1a4bf5779ddd90359bd4ddc249
  Author: Kseniya Tikhomirova <kseniya.tikhomirova at intel.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libsycl/src/event.cpp
    M libsycl/unittests/event/event.cpp

  Log Message:
  -----------
  [libsycl] add explicit instantiations for event::get_profiling_info (#210118)

Assisted by GH Copilot.

Signed-off-by: Tikhomirova, Kseniya <kseniya.tikhomirova at intel.com>


  Commit: 4d37b5bf3099d099302cce447168b3ece4efef5e
      https://github.com/llvm/llvm-project/commit/4d37b5bf3099d099302cce447168b3ece4efef5e
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/test/Transforms/LoopVectorize/VPlan/expand-scev.ll
    M llvm/test/Transforms/LoopVectorize/nested-loops-scev-expansion.ll

  Log Message:
  -----------
  [LV] Add additional SCEV expansion tests with AddRecs. (NFC) (#210159)

Add additional test coverage for SCEV expansion of AddRecs, including
cases where extends are needed, different start and steps, as well as
cases where the outer header is not the plan's entry block.


  Commit: a9e5bb572703780e3eea4a2759104a141ea73466
      https://github.com/llvm/llvm-project/commit/a9e5bb572703780e3eea4a2759104a141ea73466
  Author: Nico Weber <thakis at chromium.org>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/utils/gn/secondary/clang/tools/clang-ssaf-linker/BUILD.gn

  Log Message:
  -----------
  [gn build] Port 398f2117379f (#210308)


  Commit: 9a2d9c7fef47c0af321150f75d8f21db06cccb43
      https://github.com/llvm/llvm-project/commit/9a2d9c7fef47c0af321150f75d8f21db06cccb43
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Analysis/ScalarEvolution.cpp
    M llvm/test/Analysis/ScalarEvolution/exit-count-non-strict.ll
    M llvm/test/Analysis/ScalarEvolution/incorrect-exit-count.ll
    M llvm/test/CodeGen/AMDGPU/GlobalISel/divergence-divergent-i1-used-outside-loop.ll
    M llvm/test/CodeGen/AMDGPU/GlobalISel/divergence-structurizer.ll
    M llvm/test/CodeGen/AMDGPU/memset-pattern.ll
    M llvm/test/CodeGen/ARM/select-imm.ll
    A llvm/test/Transforms/IndVarSimplify/iv-widen-addrec-flag-inferred-late.ll

  Log Message:
  -----------
  [SCEV] Try to fold ZExt/SExt of AddRec before existing lookup. (#208805)

Move AddRec fold for ZExt & SExt before existing SCEV lookup. This can
improve results, when we constructed SCEV for a ZExt/SExt during earlier
analysis and flags on the operand AddRec have not been
refined/strengthend yet.

This improves results in some cases and fixes a regression here:
https://github.com/dtcxzyw/llvm-opt-benchmark-nightly/pull/654#discussion_r3554885279.

On a large C/C++ corpus with 32k bitcode files, ~2% more IVs get
widened, removing a large number of ZExt instructions.

Compile-time impact in the noise

https://llvm-compile-time-tracker.com/compare.php?from=167d65906cc3c636221158abe8289ab4a03dfc7d&to=381abca0d5ead4443d86287d754f47c21396a9be&stat=instructions:u


  Commit: 62a932ac3e2702a5493934c6362f9e058a204557
      https://github.com/llvm/llvm-project/commit/62a932ac3e2702a5493934c6362f9e058a204557
  Author: Abhina Sree <Abhina.Sreeskantharajan at ibm.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/lib/CodeGen/CodeGenModule.cpp
    A clang/test/CodeGen/SystemZ/systemz-module.flags.c
    M llvm/include/llvm/IR/Module.h
    M llvm/lib/IR/Module.cpp

  Log Message:
  -----------
  [SystemZ][z/OS] Fix zos_translation_time module flag (#210058)

The zos_translation_time flag needs to be 64-bit to handle the year 2038
problem.


  Commit: 23b0281d75a4320a4e6e3d837edf94911d98d252
      https://github.com/llvm/llvm-project/commit/23b0281d75a4320a4e6e3d837edf94911d98d252
  Author: Nikita Popov <npopov at redhat.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/X86/X86ISelDAGToDAG.cpp
    A llvm/test/CodeGen/X86/tailcall-i686-pic.ll

  Log Message:
  -----------
  [X86] Fix assertion failure for tail call on i686+pic (#210302)

The pattern for TCRETURNmi has a IsNotPIC predicate, but the
checkTCRetEnoughRegs() predicate that's part of the X86tcret_enough_regs
PatFrag is evaluated first, so we can't assert that PIC is disabled
here. We should just return false in that case.

Fixes https://github.com/llvm/llvm-project/issues/210300.


  Commit: 38104cf836c3903647c917a5b251e938f4eadbb9
      https://github.com/llvm/llvm-project/commit/38104cf836c3903647c917a5b251e938f4eadbb9
  Author: Paul Walker <paul.walker at arm.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AArch64/AArch64.h
    A llvm/lib/Target/AArch64/AArch64PTrueCoalescing.cpp
    M llvm/lib/Target/AArch64/AArch64PassRegistry.def
    M llvm/lib/Target/AArch64/AArch64TargetMachine.cpp
    M llvm/lib/Target/AArch64/CMakeLists.txt
    M llvm/test/CodeGen/AArch64/O3-pipeline.ll
    A llvm/test/CodeGen/AArch64/sve-ptrue-coalesce.mir

  Log Message:
  -----------
  [LLVM][SVE] Add MachineInst pass to coalesce PTRUE instructions. (#204820)

SVE predicate registers contain a bit for each byte of a data register.
When operating on bigger element types the overlaping predicate bits are
grouped together but typically only the least-significant-bit is read as
part of the operation. This means the value of the other bits does not
affect the operation, making it possible to use the result of PTRUE for
a larger element typed operation, assuming the predicate patterns are
equivalent. For example:

  ADD_S (PTRUE_H 31), Z0, Z1 == ADD_S (PTRUE_S 31), Z0, Z1

AArch64PTrueCoalescingPass uses this fact to reduce the number of PTRUE
instructions in a function, with the general trend towards needing a
single PTRUE based on the smallest element type in use.

NOTE: The pass will be enabled by default using a dedicated PR to make
it easier to revert if something goes wrong.


  Commit: de4f929700f8d87041e0b050ec6028f0ac5276ad
      https://github.com/llvm/llvm-project/commit/de4f929700f8d87041e0b050ec6028f0ac5276ad
  Author: David Spickett <david.spickett at arm.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_x86.cpp
    M lldb/source/Plugins/Process/Utility/NativeRegisterContextDBReg_x86.h

  Log Message:
  -----------
  [lldb][x86] Remove GCC 6 workaround (#210317)

Added by 3bea7306e8669f94bacafae68748a9139cfc0b98.

We now require GCC >= 7.4 so it can be removed.

I tested a standalone reproducer with GCC 7.3 and
clang 5. Neither have the problem.

https://godbolt.org/z/3zKrT9c8s

Standalone reproducer:
```
 struct Base {
   Base(int) {}
 };

 struct Derived : virtual Base {
 #ifdef WORKAROUND
     Derived(int a): Base(a) {}
 #endif
   virtual void g() = 0;
 };

 struct Final : Derived {
   Final(int n) : Base(n)
 #ifdef WORKAROUND
   , Derived(n)
 #endif
   {}
   void g() override {}
 };
```


  Commit: b9f5bcbcfbe6aa4943c808afd3bb82243ecb3193
      https://github.com/llvm/llvm-project/commit/b9f5bcbcfbe6aa4943c808afd3bb82243ecb3193
  Author: Nikita Popov <npopov at redhat.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/docs/ReleaseNotes.md
    M clang/include/clang/Basic/ABIVersions.def
    M clang/include/clang/Basic/LangOptions.def
    M clang/include/clang/CodeGen/CGFunctionInfo.h
    M clang/include/clang/CodeGen/CodeGenABITypes.h
    M clang/lib/CodeGen/ABIInfo.h
    M clang/lib/CodeGen/CGCUDARuntime.cpp
    M clang/lib/CodeGen/CGCall.cpp
    M clang/lib/CodeGen/CGClass.cpp
    M clang/lib/CodeGen/CGDeclCXX.cpp
    M clang/lib/CodeGen/CGExpr.cpp
    M clang/lib/CodeGen/CGExprCXX.cpp
    M clang/lib/CodeGen/CGExprComplex.cpp
    M clang/lib/CodeGen/CGHLSLRuntime.cpp
    M clang/lib/CodeGen/CGObjCRuntime.cpp
    M clang/lib/CodeGen/CGVTables.cpp
    M clang/lib/CodeGen/CodeGenABITypes.cpp
    M clang/lib/CodeGen/CodeGenFunction.cpp
    M clang/lib/CodeGen/CodeGenFunction.h
    M clang/lib/CodeGen/CodeGenTypes.h
    M clang/lib/CodeGen/ItaniumCXXABI.cpp
    M clang/lib/CodeGen/MicrosoftCXXABI.cpp
    M clang/lib/CodeGen/Targets/X86.cpp
    M clang/test/CodeGen/sysv_abi.c
    R clang/test/CodeGen/target-avx-function-abi.c
    R clang/test/CodeGenCXX/target-avx-method-abi.cpp
    M clang/unittests/CodeGen/CodeGenExternalTest.cpp
    M clang/unittests/CodeGen/TestCompiler.h

  Log Message:
  -----------
  Revert "[clang][CodeGen][X86_64] Honor per-function AVX ABI in C/C++ call paths, maintain old psABI for PlayStation." (#210303)

Reverts llvm/llvm-project#193298

Causes a major compile-time regression.


  Commit: 75ec1a4e80a9377f8f1e2ff063b094e016787926
      https://github.com/llvm/llvm-project/commit/75ec1a4e80a9377f8f1e2ff063b094e016787926
  Author: Manuel Carrasco <Manuel.Carrasco at amd.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/SPIRV/SPIRVNonSemanticDebugHandler.cpp
    M llvm/lib/Target/SPIRV/SPIRVNonSemanticDebugHandler.h
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-default-address-space.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-init-expr.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-multi-gve.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-no-backing-var.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-no-type.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-path-null.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-skip-static-member.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-skip-type-not-in-regs.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-static-member.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable.ll

  Log Message:
  -----------
  [SPIRV] Emit NonSemantic DebugGlobalVariable (#207230)

Add emitDebugGlobalVariable to the NSDI handler, translating each
DIGlobalVariable to a
[DebugGlobalVariable](https://github.khronos.org/SPIRV-Registry/nonsemantic/NonSemantic.Shader.DebugInfo.html#DebugGlobalVariable)
ext inst.


  Commit: 4f76a4c5a3f8711fe13b05c0f93ac78349396292
      https://github.com/llvm/llvm-project/commit/4f76a4c5a3f8711fe13b05c0f93ac78349396292
  Author: Erich Keane <ekeane at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/docs/ReleaseNotes.md

  Log Message:
  -----------
  [NFC] RelNotes Formatting fix I screwed up in 209893 (#210325)


  Commit: aef6bde636a753c7a0a799c3ab86ef38b622b448
      https://github.com/llvm/llvm-project/commit/aef6bde636a753c7a0a799c3ab86ef38b622b448
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M .github/workflows/llvm-abi-tests.yml
    M .github/workflows/release-binaries.yml
    M .github/workflows/validate-release-version/action.yml
    A bolt/docs/BOLTAArch64OptimizationStatus.md
    R bolt/docs/BOLTAArch64OptimizationStatus.rst
    A bolt/docs/GettingStarted.md
    R bolt/docs/GettingStarted.rst
    A bolt/docs/index.md
    R bolt/docs/index.rst
    M bolt/docs/profiles.md
    M bolt/include/bolt/Profile/DataReader.h
    M bolt/lib/Profile/DataReader.cpp
    A bolt/test/X86/profile-symbols-mode.s
    M clang-tools-extra/clangd/CMakeLists.txt
    A clang-tools-extra/clangd/LSPBinder.cpp
    M clang-tools-extra/clangd/LSPBinder.h
    M clang/docs/ReleaseNotes.md
    M clang/docs/UsersManual.md
    M clang/include/clang/AST/CommentLexer.h
    M clang/include/clang/Basic/AtomicLineLogger.h
    M clang/include/clang/Basic/BuiltinsAMDGPU.td
    M clang/include/clang/Basic/DiagnosticParseKinds.td
    M clang/include/clang/Basic/DiagnosticSemaKinds.td
    M clang/include/clang/Basic/DiagnosticSerializationKinds.td
    M clang/include/clang/CIR/Dialect/IR/CIRAttrs.td
    M clang/include/clang/CIR/Dialect/IR/CIROps.td
    A clang/include/clang/CIR/Dialect/IR/CIRStdOps.td
    M clang/include/clang/CIR/Dialect/Passes.h
    M clang/include/clang/DependencyScanning/DependencyScanningService.h
    M clang/include/clang/DependencyScanning/DependencyScanningWorker.h
    M clang/include/clang/DependencyScanning/InProcessModuleCache.h
    M clang/include/clang/Options/Options.td
    M clang/include/clang/ScalableStaticAnalysis/Core/EntityLinker/StaticLibrary.h
    M clang/include/clang/ScalableStaticAnalysis/Core/EntityLinker/TUSummaryEncoding.h
    M clang/include/clang/Serialization/InMemoryModuleCache.h
    M clang/include/clang/Serialization/ModuleCache.h
    M clang/lib/AST/ComputeDependence.cpp
    M clang/lib/AST/ExprCXX.cpp
    M clang/lib/Basic/Targets/AArch64.cpp
    M clang/lib/Basic/Targets/ARM.cpp
    M clang/lib/CIR/CodeGen/CIRGenBuiltinAMDGPU.cpp
    M clang/lib/CIR/CodeGen/CIRGenClass.cpp
    M clang/lib/CIR/CodeGen/CIRGenExprScalar.cpp
    M clang/lib/CIR/CodeGen/CIRGenFunction.cpp
    M clang/lib/CIR/CodeGen/CIRGenModule.cpp
    M clang/lib/CIR/CodeGen/CIRGenModule.h
    M clang/lib/CIR/CodeGen/CIRGenTypes.cpp
    M clang/lib/CIR/Dialect/IR/CIRDialect.cpp
    M clang/lib/CIR/Dialect/Transforms/IdiomRecognizer.cpp
    M clang/lib/CIR/Dialect/Transforms/LoweringPrepare.cpp
    M clang/lib/CIR/Lowering/CIRPasses.cpp
    M clang/lib/CodeGen/CGClass.cpp
    M clang/lib/CodeGen/CGExprCXX.cpp
    M clang/lib/CodeGen/CodeGenModule.cpp
    M clang/lib/CodeGen/CodeGenModule.h
    M clang/lib/CodeGen/Targets/SPIR.cpp
    M clang/lib/DependencyScanning/DependencyScannerImpl.cpp
    M clang/lib/DependencyScanning/DependencyScanningWorker.cpp
    M clang/lib/DependencyScanning/InProcessModuleCache.cpp
    M clang/lib/Driver/ToolChain.cpp
    M clang/lib/Driver/ToolChains/Clang.cpp
    M clang/lib/Driver/ToolChains/Linux.cpp
    M clang/lib/Driver/ToolChains/MinGW.cpp
    M clang/lib/Frontend/CompilerInstance.cpp
    M clang/lib/Headers/riscv_packed_simd.h
    M clang/lib/Parse/ParseExprCXX.cpp
    M clang/lib/Parse/ParseStmt.cpp
    M clang/lib/Sema/HLSLExternalSemaSource.cpp
    M clang/lib/Sema/SemaChecking.cpp
    M clang/lib/Sema/SemaLifetimeSafety.h
    M clang/lib/Sema/SemaTemplate.cpp
    M clang/lib/Serialization/ASTReader.cpp
    M clang/lib/Serialization/InMemoryModuleCache.cpp
    M clang/lib/Serialization/ModuleCache.cpp
    M clang/lib/Tooling/DependencyScanningTool.cpp
    M clang/test/AST/ByteCode/builtin-functions.cpp
    M clang/test/AST/HLSL/Textures-AST.hlsl
    A clang/test/Analysis/Scalable/ssaf-linker/Outputs/lib-explicit-triple.json
    A clang/test/Analysis/Scalable/ssaf-linker/Outputs/lib-namespace-override.json
    A clang/test/Analysis/Scalable/ssaf-linker/Outputs/libempty.json
    A clang/test/Analysis/Scalable/ssaf-linker/Outputs/libtwo.json
    M clang/test/Analysis/Scalable/ssaf-linker/help.test
    A clang/test/Analysis/Scalable/ssaf-linker/static-library-create.test
    A clang/test/Analysis/Scalable/ssaf-linker/static-library-help.test
    A clang/test/Analysis/Scalable/ssaf-linker/static-library-time.test
    A clang/test/Analysis/Scalable/ssaf-linker/static-library-verbose.test
    M clang/test/Analysis/bstring.c
    M clang/test/Analysis/malloc.c
    M clang/test/Analysis/pr22954.c
    A clang/test/CIR/CodeGen/func-identity-attr.c
    A clang/test/CIR/CodeGen/func-identity-attr.cpp
    M clang/test/CIR/CodeGen/ternary-throw.cpp
    A clang/test/CIR/CodeGenHIP/amdgcn-buffer-rsrc-type.hip
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn-gfx1250.hip
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn-vi-f16.hip
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn.hip
    A clang/test/CIR/IR/func-identity-attr.cir
    A clang/test/CIR/Transforms/idiom-recognizer-guards-void-result.cpp
    A clang/test/CIR/Transforms/idiom-recognizer-guards.cpp
    A clang/test/CIR/Transforms/idiom-recognizer-inline-namespace.cpp
    A clang/test/CIR/Transforms/idiom-recognizer.cir
    M clang/test/CIR/Transforms/idiom-recognizer.cpp
    M clang/test/CXX/temp/temp.param/p10-2a.cpp
    A clang/test/ClangScanDeps/logging-drop-pcm.c
    A clang/test/ClangScanDeps/logging-simple-by-name.c
    A clang/test/ClangScanDeps/logging-simple.c
    A clang/test/ClangScanDeps/logging-two-threads.c
    M clang/test/CodeGen/AArch64/branch-protection-attr.c
    M clang/test/CodeGen/AArch64/sign-return-address.c
    M clang/test/CodeGen/PowerPC/builtins-ppc-fma.c
    M clang/test/CodeGen/PowerPC/builtins-ppc-fpconstrained.c
    M clang/test/CodeGen/RISCV/rvp-intrinsics.c
    A clang/test/CodeGen/SystemZ/systemz-module.flags.c
    M clang/test/CodeGen/amdgpu-builtin-is-invocable.c
    M clang/test/CodeGen/amdgpu-builtin-processor-is.c
    M clang/test/CodeGenCXX/dynamic-cast-address-space.cpp
    M clang/test/CodeGenCXX/microsoft-vector-deleting-dtors.cpp
    M clang/test/CodeGenCXX/microsoft-vector-deleting-dtors2.cpp
    A clang/test/CodeGenCXX/msvc-global-delete-forwarding-at-delete-site.cpp
    M clang/test/CodeGenCXX/msvc-global-delete-scalar-array-split.cpp
    M clang/test/CodeGenCXX/msvc-global-delete-scope-no-dtor.cpp
    M clang/test/CodeGenCXX/msvc-no-global-delete-forwarding.cpp
    M clang/test/CodeGenHLSL/resources/RWBuffer-imageformat.hlsl
    M clang/test/CodeGenHLSL/resources/Textures-GetDimensions.hlsl
    M clang/test/CodeGenHLSL/resources/Textures-Load.hlsl
    A clang/test/Driver/Inputs/resource_dir/lib/cygwin/libclang_rt.builtins-x86_64.a
    A clang/test/Driver/Inputs/resource_dir_with_per_target_subdir/lib/x86_64-pc-windows-cygnus/libclang_rt.builtins.a
    M clang/test/Driver/aarch64-features.c
    M clang/test/Driver/aarch64-fmv.c
    M clang/test/Driver/aarch64-security-options.c
    A clang/test/Driver/cygwin-print-file-name.c
    M clang/test/Driver/darwin-target-variant-sdk-version.c
    M clang/test/Driver/dxc_debug.hlsl
    M clang/test/Driver/linux-ld.c
    M clang/test/Driver/mingw-sysroot.cpp
    M clang/test/Preprocessor/aarch64-target-features.c
    A clang/test/Sema/LifetimeSafety/annotation-suggestions-fixits.c
    M clang/test/Sema/builtin-memcpy.c
    M clang/test/Sema/builtin-object-size.c
    M clang/test/Sema/warn-fortify-source.c
    A clang/test/Sema/warn-stringop-overread-fortify.c
    A clang/test/Sema/warn-stringop-overread.c
    M clang/test/SemaCXX/using-decl-templates.cpp
    M clang/test/SemaCXX/warn-memset-bad-sizeof.cpp
    M clang/test/SemaHLSL/Resources/RWTexture2D-mips-errors.hlsl
    M clang/test/SemaHLSL/Resources/RWTexture2D-unsupported-methods-errors.hlsl
    M clang/test/SemaHLSL/Resources/Textures-GetDimensions.hlsl
    M clang/test/SemaHLSL/Resources/Textures-Load-errors.hlsl
    M clang/tools/cir-opt/cir-opt.cpp
    M clang/tools/clang-scan-deps/ClangScanDeps.cpp
    M clang/tools/clang-scan-deps/Opts.td
    M clang/tools/clang-ssaf-linker/CMakeLists.txt
    M clang/tools/clang-ssaf-linker/SSAFLinker.cpp
    A clang/tools/clang-ssaf-linker/StaticLibraryCreateCLI.cpp
    A clang/tools/clang-ssaf-linker/StaticLibraryCreateCLI.h
    M clang/unittests/Basic/AtomicLineLoggerTest.cpp
    M clang/unittests/DependencyScanning/InProcessModuleCacheTest.cpp
    M clang/unittests/Serialization/InMemoryModuleCacheTest.cpp
    M clang/unittests/Serialization/ModuleCacheTest.cpp
    M compiler-rt/lib/memprof/memprof_allocator.cpp
    M compiler-rt/lib/sanitizer_common/sanitizer_symbolizer_internal.h
    M compiler-rt/lib/sanitizer_common/sanitizer_symbolizer_libcdep.cpp
    M compiler-rt/lib/sanitizer_common/tests/sanitizer_symbolizer_test.cpp
    M compiler-rt/lib/tsan/rtl/tsan_interface.h
    M compiler-rt/lib/tsan/rtl/tsan_interface_atomic.cpp
    M compiler-rt/lib/ubsan/ubsan_diag.cpp
    A compiler-rt/test/asan/TestCases/Darwin/atos-canary-symbolize.cpp
    M compiler-rt/test/asan/TestCases/Windows/issue64990.cpp
    M compiler-rt/test/lit.common.cfg.py
    A compiler-rt/test/memprof/TestCases/memprof_histogram_tail_clear.cpp
    A compiler-rt/test/memprof/TestCases/memprof_nonhistogram_tail_clear.cpp
    M compiler-rt/test/ubsan/TestCases/Integer/suppressions-nested-calls.c
    M flang-rt/CMakeLists.txt
    M flang/docs/FortranStandardsSupport.md
    M flang/include/flang/Lower/CUDA.h
    M flang/include/flang/Optimizer/Transforms/Passes.td
    M flang/lib/Lower/Allocatable.cpp
    M flang/lib/Lower/ConvertCall.cpp
    M flang/lib/Lower/ConvertVariable.cpp
    M flang/lib/Lower/PFTBuilder.cpp
    M flang/lib/Optimizer/Transforms/CUDA/CUFAddConstructor.cpp
    M flang/lib/Optimizer/Transforms/CUDA/CUFDeviceFuncTransform.cpp
    M flang/lib/Parser/openacc-parsers.cpp
    M flang/lib/Semantics/resolve-names.cpp
    M flang/test/Driver/fakeflang.F
    M flang/test/Fir/CUDA/cuda-constructor-2.f90
    A flang/test/Fir/CUDA/cuda-device-func-transform-aio.mlir
    A flang/test/Lower/CUDA/cuda-gpu-unified.cuf
    R flang/test/Lower/CUDA/cuda-implicit-managed-alloc.cuf
    A flang/test/Lower/CUDA/cuda-managed-func-result.cuf
    A flang/test/Lower/global-initialization-parens.f90
    A flang/test/Lower/pre-fir-tree-assigned-goto.f90
    M flang/test/Parser/acc-unparse.f90
    M flang/tools/fakeflang/fakeflang.cpp
    M libc/config/linux/aarch64/entrypoints.txt
    M libc/config/linux/aarch64/headers.txt
    M libc/config/linux/arm/headers.txt
    M libc/config/linux/i386/headers.txt
    M libc/config/linux/riscv/entrypoints.txt
    M libc/config/linux/riscv/headers.txt
    M libc/config/linux/x86_64/entrypoints.txt
    M libc/config/linux/x86_64/headers.txt
    M libc/docs/CMakeLists.txt
    R libc/docs/headers/time.rst
    M libc/include/CMakeLists.txt
    A libc/include/alloca.yaml
    M libc/include/llvm-libc-macros/CMakeLists.txt
    A libc/include/llvm-libc-macros/alloca-macros.h
    M libc/include/llvm-libc-types/struct_sockaddr_storage.h
    M libc/include/sys/time.yaml
    M libc/include/time.yaml
    M libc/src/__support/FPUtil/Hypot.h
    M libc/src/__support/math/CMakeLists.txt
    M libc/src/__support/math/acos.h
    M libc/src/__support/math/acosbf16.h
    M libc/src/__support/math/acosf.h
    M libc/src/__support/math/acospif.h
    M libc/src/__support/math/asin.h
    M libc/src/__support/math/asin_utils.h
    M libc/src/__support/math/asinbf16.h
    M libc/src/__support/math/asinf.h
    M libc/src/__support/math/asinpi.h
    M libc/src/__support/math/asinpif.h
    M libc/src/__support/math/atan2f.h
    M libc/src/__support/math/atan2f16.h
    M libc/src/__support/math/atan_utils.h
    M libc/src/__support/math/atanf.h
    M libc/src/__support/math/hypot.h
    R libc/src/__support/math/inv_trigf_utils.h
    M libc/src/mathvec/abi_prefix.h
    M libc/src/sys/time/CMakeLists.txt
    A libc/src/sys/time/gettimeofday.h
    M libc/src/sys/time/linux/CMakeLists.txt
    A libc/src/sys/time/linux/gettimeofday.cpp
    M libc/src/time/CMakeLists.txt
    R libc/src/time/gettimeofday.h
    M libc/src/time/linux/CMakeLists.txt
    R libc/src/time/linux/gettimeofday.cpp
    M libc/test/include/CMakeLists.txt
    A libc/test/include/alloca_test.cpp
    M libc/test/src/math/smoke/hypot_test.cpp
    M libc/test/src/stdfix/DiviFxTest.h
    M libc/test/src/sys/socket/linux/CMakeLists.txt
    M libc/test/src/sys/socket/linux/bind_test.cpp
    M libc/test/src/sys/socket/linux/connect_accept_test.cpp
    M libc/test/src/sys/socket/linux/listen_test.cpp
    M libc/test/src/sys/socket/linux/sockaddr_storage_test.cpp
    M libc/test/src/sys/socket/linux/socket_test_support.h
    M libc/test/src/sys/socket/linux/sockname_test.cpp
    M libc/test/src/sys/time/CMakeLists.txt
    A libc/test/src/sys/time/gettimeofday_test.cpp
    M libc/test/src/time/CMakeLists.txt
    R libc/test/src/time/gettimeofday_test.cpp
    A libc/utils/docgen/time.yaml
    M libcxx/src/support/runtime/exception_pointer_msvc.ipp
    M libsycl/include/sycl/__impl/queue.hpp
    M libsycl/src/event.cpp
    M libsycl/unittests/event/event.cpp
    A lld/docs/DTLTO.md
    R lld/docs/DTLTO.rst
    A lld/docs/ELF/large_sections.md
    R lld/docs/ELF/large_sections.rst
    A lld/docs/ELF/linker_script.md
    R lld/docs/ELF/linker_script.rst
    A lld/docs/ELF/start-stop-gc.md
    R lld/docs/ELF/start-stop-gc.rst
    A lld/docs/ELF/warn_backrefs.md
    R lld/docs/ELF/warn_backrefs.rst
    A lld/docs/MachO/index.md
    R lld/docs/MachO/index.rst
    A lld/docs/MachO/ld64-vs-lld.md
    R lld/docs/MachO/ld64-vs-lld.rst
    A lld/docs/NewLLD.md
    R lld/docs/NewLLD.rst
    A lld/docs/ReleaseNotes.md
    R lld/docs/ReleaseNotes.rst
    A lld/docs/WebAssembly.md
    R lld/docs/WebAssembly.rst
    M lld/docs/conf.py
    A lld/docs/error_handling_script.md
    R lld/docs/error_handling_script.rst
    A lld/docs/index.md
    R lld/docs/index.rst
    A lld/docs/missingkeyfunction.md
    R lld/docs/missingkeyfunction.rst
    A lld/docs/windows_support.md
    R lld/docs/windows_support.rst
    M lldb/bindings/python/CMakeLists.txt
    M lldb/bindings/python/python-wrapper.swig
    M lldb/docs/CMakeLists.txt
    M lldb/docs/dil-expr-lang.ebnf
    M lldb/docs/resources/test.md
    A lldb/examples/python/templates/scripted_stackframe_recognizer.py
    M lldb/include/lldb/Core/Section.h
    A lldb/include/lldb/Interpreter/Interfaces/ScriptedStackFrameRecognizerInterface.h
    M lldb/include/lldb/Interpreter/ScriptInterpreter.h
    M lldb/include/lldb/Target/StackFrameRecognizer.h
    M lldb/include/lldb/lldb-enumerations.h
    M lldb/include/lldb/lldb-forward.h
    A lldb/packages/Python/lldbsuite/support/xcode.py
    M lldb/packages/Python/lldbsuite/test/dotest.py
    M lldb/packages/Python/lldbsuite/test/dotest_args.py
    M lldb/source/API/SBSection.cpp
    M lldb/source/Commands/CommandObjectMemory.cpp
    M lldb/source/Expression/DWARFExpression.cpp
    M lldb/source/Interpreter/ScriptInterpreter.cpp
    M lldb/source/Plugins/ObjectFile/ELF/ELFHeader.cpp
    M lldb/source/Plugins/ObjectFile/ELF/ObjectFileELF.cpp
    M lldb/source/Plugins/ObjectFile/Mach-O/ObjectFileMachO.cpp
    M lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_x86.cpp
    M lldb/source/Plugins/Process/Utility/NativeRegisterContextDBReg_x86.h
    M lldb/source/Plugins/ScriptInterpreter/Python/CMakeLists.txt
    M lldb/source/Plugins/ScriptInterpreter/Python/Interfaces/ScriptInterpreterPythonInterfaces.cpp
    M lldb/source/Plugins/ScriptInterpreter/Python/Interfaces/ScriptInterpreterPythonInterfaces.h
    M lldb/source/Plugins/ScriptInterpreter/Python/Interfaces/ScriptedPythonInterface.cpp
    A lldb/source/Plugins/ScriptInterpreter/Python/Interfaces/ScriptedStackFrameRecognizerPythonInterface.cpp
    A lldb/source/Plugins/ScriptInterpreter/Python/Interfaces/ScriptedStackFrameRecognizerPythonInterface.h
    M lldb/source/Plugins/ScriptInterpreter/Python/SWIGPythonBridge.h
    M lldb/source/Plugins/ScriptInterpreter/Python/ScriptInterpreterPython.cpp
    M lldb/source/Plugins/ScriptInterpreter/Python/ScriptInterpreterPythonImpl.h
    M lldb/source/Plugins/SymbolFile/NativePDB/UdtRecordCompleter.cpp
    M lldb/source/Plugins/SymbolLocator/DebugSymbols/SymbolLocatorDebugSymbols.cpp
    M lldb/source/Target/SectionLoadList.cpp
    M lldb/source/Target/StackFrameRecognizer.cpp
    M lldb/source/Target/Target.cpp
    M lldb/source/ValueObject/DILEval.cpp
    M lldb/test/API/commands/frame/recognizer/TestFrameRecognizer.py
    M lldb/test/API/commands/frame/recognizer/recognizer.py
    M lldb/test/API/commands/frame/var-dil/expr/Literals/TestFrameVarDILLiterals.py
    M lldb/test/API/commands/frame/var-dil/expr/Literals/main.cpp
    A lldb/test/API/commands/frame/var-dil/expr/NullptrVar/Makefile
    A lldb/test/API/commands/frame/var-dil/expr/NullptrVar/TestFrameVarDILNullptrVar.py
    A lldb/test/API/commands/frame/var-dil/expr/NullptrVar/main.c
    M lldb/test/API/functionalities/thread/finish-from-empty-func/TestEmptyFuncThreadStepOut.py
    M lldb/test/API/functionalities/thread/finish-from-empty-func/main.c
    M lldb/test/Shell/SymbolFile/NativePDB/Inputs/globals-fundamental.lldbinit
    M lldb/test/Shell/SymbolFile/NativePDB/globals-fundamental.cpp
    A lldb/test/Shell/SymbolFile/NativePDB/static-class-constants.cpp
    M lldb/tools/lldb-server/lldb-gdbserver.cpp
    M lldb/tools/lldb-test/lldb-test.cpp
    M lldb/unittests/Expression/DWARFExpressionTest.cpp
    M lldb/unittests/ScriptInterpreter/Python/PythonTestSuite.cpp
    M llvm/CMakeLists.txt
    M llvm/docs/AMDGPUDMAOperations.md
    M llvm/docs/ReleaseNotes.md
    M llvm/docs/TableGen/ProgRef.rst
    M llvm/include/llvm/ADT/GenericConvergenceVerifier.h
    M llvm/include/llvm/ADT/GenericCycleImpl.h
    M llvm/include/llvm/ADT/GenericCycleInfo.h
    M llvm/include/llvm/ADT/GenericUniformityImpl.h
    M llvm/include/llvm/ADT/GenericUniformityInfo.h
    M llvm/include/llvm/CodeGen/LibcallLoweringInfo.h
    M llvm/include/llvm/CodeGen/MachineCycleAnalysis.h
    M llvm/include/llvm/DWP/DWP.h
    M llvm/include/llvm/IR/CycleInfo.h
    M llvm/include/llvm/IR/GenericConvergenceVerifierImpl.h
    M llvm/include/llvm/IR/IntrinsicsAMDGPU.td
    M llvm/include/llvm/IR/Module.h
    M llvm/include/llvm/IR/PatternMatch.h
    M llvm/include/llvm/ObjectYAML/BBAddrMapYAML.h
    M llvm/include/llvm/Support/LSP/Transport.h
    M llvm/include/llvm/TargetParser/ARMTargetParserCommon.h
    M llvm/lib/Analysis/CFG.cpp
    M llvm/lib/Analysis/HashRecognize.cpp
    M llvm/lib/Analysis/ScalarEvolution.cpp
    M llvm/lib/Analysis/UniformityAnalysis.cpp
    M llvm/lib/CodeGen/AsmPrinter/DwarfExpression.cpp
    M llvm/lib/CodeGen/AtomicExpandPass.cpp
    M llvm/lib/CodeGen/DwarfEHPrepare.cpp
    M llvm/lib/CodeGen/ExpandIRInsts.cpp
    M llvm/lib/CodeGen/LibcallLoweringInfo.cpp
    M llvm/lib/CodeGen/MachineCycleAnalysis.cpp
    M llvm/lib/CodeGen/MachineSink.cpp
    M llvm/lib/CodeGen/MachineUniformityAnalysis.cpp
    M llvm/lib/CodeGen/PreISelIntrinsicLowering.cpp
    M llvm/lib/CodeGen/SafeStack.cpp
    M llvm/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp
    M llvm/lib/CodeGen/StackProtector.cpp
    M llvm/lib/CodeGen/TargetLoweringObjectFileImpl.cpp
    M llvm/lib/DWP/DWP.cpp
    M llvm/lib/IR/CycleInfo.cpp
    M llvm/lib/IR/Module.cpp
    M llvm/lib/IR/Verifier.cpp
    M llvm/lib/IR/VerifierAMDGPU.cpp
    M llvm/lib/LTO/LTO.cpp
    M llvm/lib/MC/MCDXContainerWriter.cpp
    M llvm/lib/ObjectYAML/BBAddrMapYAML.cpp
    M llvm/lib/ObjectYAML/ELFEmitter.cpp
    M llvm/lib/Support/KnownBits.cpp
    M llvm/lib/Support/LSP/Transport.cpp
    M llvm/lib/TableGen/Record.cpp
    M llvm/lib/Target/AArch64/AArch64.h
    M llvm/lib/Target/AArch64/AArch64ISelLowering.cpp
    M llvm/lib/Target/AArch64/AArch64ISelLowering.h
    M llvm/lib/Target/AArch64/AArch64MachineFunctionInfo.cpp
    A llvm/lib/Target/AArch64/AArch64PTrueCoalescing.cpp
    M llvm/lib/Target/AArch64/AArch64PassRegistry.def
    M llvm/lib/Target/AArch64/AArch64PointerAuth.cpp
    M llvm/lib/Target/AArch64/AArch64TargetMachine.cpp
    M llvm/lib/Target/AArch64/CMakeLists.txt
    M llvm/lib/Target/AArch64/GISel/AArch64O0PreLegalizerCombiner.cpp
    M llvm/lib/Target/AArch64/GISel/AArch64PreLegalizerCombiner.cpp
    M llvm/lib/Target/AMDGPU/AMDGPU.td
    M llvm/lib/Target/AMDGPU/AMDGPUGlobalISelDivergenceLowering.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUHWEvents.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUHWEvents.def
    M llvm/lib/Target/AMDGPU/AMDGPUHWEvents.h
    M llvm/lib/Target/AMDGPU/AMDGPUInstructionSelector.cpp
    M llvm/lib/Target/AMDGPU/AMDGPULegalizerInfo.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUWaitSGPRHazards.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUWaitcntUtils.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUWaitcntUtils.h
    M llvm/lib/Target/AMDGPU/AsmParser/AMDGPUAsmParser.cpp
    M llvm/lib/Target/AMDGPU/GCNHazardRecognizer.cpp
    M llvm/lib/Target/AMDGPU/GCNSubtarget.h
    M llvm/lib/Target/AMDGPU/MIMGInstructions.td
    M llvm/lib/Target/AMDGPU/SIFoldOperands.cpp
    M llvm/lib/Target/AMDGPU/SIISelLowering.cpp
    M llvm/lib/Target/AMDGPU/SIInsertWaitcnts.cpp
    M llvm/lib/Target/AMDGPU/SIInstrInfo.cpp
    M llvm/lib/Target/AMDGPU/SILowerSGPRSpills.cpp
    M llvm/lib/Target/AMDGPU/SIRegisterInfo.cpp
    M llvm/lib/Target/AMDGPU/SOPInstructions.td
    M llvm/lib/Target/AMDGPU/Utils/AMDGPUBaseInfo.cpp
    M llvm/lib/Target/AMDGPU/Utils/AMDGPUBaseInfo.h
    M llvm/lib/Target/AMDGPU/VOP3Instructions.td
    M llvm/lib/Target/DirectX/DXILWriter/DXILWriterPass.cpp
    M llvm/lib/Target/Hexagon/HexagonRDFOpt.cpp
    M llvm/lib/Target/LoongArch/LoongArchISelLowering.cpp
    M llvm/lib/Target/PowerPC/PPCSchedule.td
    M llvm/lib/Target/PowerPC/PPCSchedule440.td
    M llvm/lib/Target/PowerPC/PPCScheduleA2.td
    M llvm/lib/Target/PowerPC/PPCScheduleE500.td
    M llvm/lib/Target/PowerPC/PPCScheduleE500mc.td
    M llvm/lib/Target/PowerPC/PPCScheduleE5500.td
    M llvm/lib/Target/PowerPC/PPCScheduleG3.td
    M llvm/lib/Target/PowerPC/PPCTargetTransformInfo.cpp
    M llvm/lib/Target/RISCV/RISCVISelLowering.cpp
    M llvm/lib/Target/RISCV/RISCVInstrInfo.cpp
    M llvm/lib/Target/RISCV/RISCVInstrInfoP.td
    M llvm/lib/Target/RISCV/RISCVLoadStoreOptimizer.cpp
    M llvm/lib/Target/RISCV/RISCVRegisterInfo.td
    M llvm/lib/Target/SPIRV/SPIRV.h
    M llvm/lib/Target/SPIRV/SPIRVEmitIntrinsics.cpp
    M llvm/lib/Target/SPIRV/SPIRVInstructionSelector.cpp
    M llvm/lib/Target/SPIRV/SPIRVNonSemanticDebugHandler.cpp
    M llvm/lib/Target/SPIRV/SPIRVNonSemanticDebugHandler.h
    M llvm/lib/Target/SPIRV/SPIRVPrepareFunctions.cpp
    M llvm/lib/Target/SPIRV/SPIRVTargetMachine.cpp
    M llvm/lib/Target/WebAssembly/MCTargetDesc/WebAssemblyInstPrinter.cpp
    M llvm/lib/Target/WebAssembly/WebAssembly.h
    M llvm/lib/Target/WebAssembly/WebAssemblyCleanCodeAfterTrap.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyCodeGenPassBuilder.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyFixBrTableDefaults.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyPassRegistry.def
    M llvm/lib/Target/WebAssembly/WebAssemblySetP2AlignOperands.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyTargetMachine.cpp
    M llvm/lib/Target/X86/X86ISelDAGToDAG.cpp
    M llvm/lib/TargetParser/AMDGPUTargetParser.cpp
    M llvm/lib/TargetParser/ARMTargetParserCommon.cpp
    M llvm/lib/Transforms/IPO/AttributorAttributes.cpp
    M llvm/lib/Transforms/IPO/Instrumentor.cpp
    M llvm/lib/Transforms/InstCombine/InstCombineCalls.cpp
    M llvm/lib/Transforms/InstCombine/InstCombineCasts.cpp
    M llvm/lib/Transforms/Scalar/ConstraintElimination.cpp
    M llvm/lib/Transforms/Scalar/DeadStoreElimination.cpp
    M llvm/lib/Transforms/Scalar/GVN.cpp
    M llvm/lib/Transforms/Scalar/LoopIdiomRecognize.cpp
    M llvm/lib/Transforms/Scalar/LoopStrengthReduce.cpp
    M llvm/lib/Transforms/Utils/BasicBlockUtils.cpp
    M llvm/lib/Transforms/Utils/FixIrreducible.cpp
    M llvm/lib/Transforms/Vectorize/SLPVectorizer.cpp
    M llvm/lib/Transforms/Vectorize/SLPVectorizer/SLPUtils.cpp
    M llvm/lib/Transforms/Vectorize/SLPVectorizer/SLPUtils.h
    M llvm/test/Analysis/HashRecognize/cyclic-redundancy-check.ll
    M llvm/test/Analysis/ScalarEvolution/exit-count-non-strict.ll
    M llvm/test/Analysis/ScalarEvolution/incorrect-exit-count.ll
    M llvm/test/Assembler/callbr.ll
    M llvm/test/CodeGen/AArch64/GlobalISel/knownbits-urem.mir
    A llvm/test/CodeGen/AArch64/GlobalISel/knownbits-vashr.mir
    M llvm/test/CodeGen/AArch64/O3-pipeline.ll
    M llvm/test/CodeGen/AArch64/sign-return-address.ll
    M llvm/test/CodeGen/AArch64/sve-fixed-length-masked-64-128bit-loads.ll
    M llvm/test/CodeGen/AArch64/sve-fixed-length-masked-64-128bit-stores.ll
    A llvm/test/CodeGen/AArch64/sve-ptrue-coalesce.mir
    A llvm/test/CodeGen/AArch64/windows-pac-invalid-a-key.ll
    M llvm/test/CodeGen/AArch64/wineh-bti.ll
    M llvm/test/CodeGen/AMDGPU/GlobalISel/divergence-divergent-i1-used-outside-loop.ll
    M llvm/test/CodeGen/AMDGPU/GlobalISel/divergence-structurizer.ll
    M llvm/test/CodeGen/AMDGPU/GlobalISel/inst-select-amdgcn.exp.compr.mir
    M llvm/test/CodeGen/AMDGPU/GlobalISel/llvm.amdgcn.intersect_ray.ll
    M llvm/test/CodeGen/AMDGPU/add-max.ll
    M llvm/test/CodeGen/AMDGPU/atomic_optimizations_dpp_lds_expected_active_lanes.ll
    M llvm/test/CodeGen/AMDGPU/atomic_optimizations_global_pointer.ll
    M llvm/test/CodeGen/AMDGPU/atomic_optimizations_local_pointer.ll
    M llvm/test/CodeGen/AMDGPU/atomic_optimizations_pixelshader.ll
    M llvm/test/CodeGen/AMDGPU/bf16-math.ll
    M llvm/test/CodeGen/AMDGPU/eliminate-frame-index-flat-scratch-svs.mir
    M llvm/test/CodeGen/AMDGPU/expert_scheduling_gfx12.mir
    M llvm/test/CodeGen/AMDGPU/gfx11-sgpr-hazard-latency.mir
    M llvm/test/CodeGen/AMDGPU/global-saddr-atomics-min-max-system.ll
    M llvm/test/CodeGen/AMDGPU/global_atomics_scan_fadd.ll
    M llvm/test/CodeGen/AMDGPU/global_atomics_scan_fmax.ll
    M llvm/test/CodeGen/AMDGPU/global_atomics_scan_fmin.ll
    M llvm/test/CodeGen/AMDGPU/global_atomics_scan_fsub.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.dual_intersect_ray.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.exp.compr.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.fma.legacy.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.intersect_ray.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.mov.dpp8.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.permlane.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.add.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.and.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.fadd.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.fmax.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.fmin.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.fsub.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.max.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.min.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.or.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.sub.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.umax.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.umin.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.reduce.xor.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.sudot4.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.sudot8.ll
    M llvm/test/CodeGen/AMDGPU/llvm.amdgcn.tanh.ll
    M llvm/test/CodeGen/AMDGPU/memset-pattern.ll
    M llvm/test/CodeGen/AMDGPU/s-wakeup-barrier.ll
    M llvm/test/CodeGen/AMDGPU/uaddsat.ll
    M llvm/test/CodeGen/AMDGPU/unsupported-av-load.ll
    M llvm/test/CodeGen/AMDGPU/unsupported-av-store.ll
    M llvm/test/CodeGen/AMDGPU/valu-mask-write-hazard.mir
    M llvm/test/CodeGen/ARM/select-imm.ll
    M llvm/test/CodeGen/DirectX/ContainerData/ContainerFlags.ll
    A llvm/test/CodeGen/Hexagon/rdfopt-liveins-hang.mir
    A llvm/test/CodeGen/LoongArch/lasx/issue207316.ll
    M llvm/test/CodeGen/LoongArch/lasx/xvexth.ll
    M llvm/test/CodeGen/LoongArch/lsx/vexth.ll
    M llvm/test/CodeGen/RISCV/rvp-simd-32.ll
    M llvm/test/CodeGen/RISCV/rvp-simd-64.ll
    A llvm/test/CodeGen/RISCV/rvp-widening-convert-isel.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-default-address-space.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-init-expr.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-multi-gve.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-no-backing-var.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-no-type.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-path-null.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-skip-static-member.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-skip-type-not-in-regs.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable-static-member.ll
    A llvm/test/CodeGen/SPIRV/debug-info/debug-global-variable.ll
    M llvm/test/CodeGen/SPIRV/hlsl-resources/SignedBufferLoadStore.ll
    M llvm/test/CodeGen/SPIRV/hlsl-resources/UnsignedBufferLoadStore.ll
    M llvm/test/CodeGen/SPIRV/sitofp-with-bool.ll
    M llvm/test/CodeGen/SPIRV/uitofp-with-bool.ll
    A llvm/test/CodeGen/X86/tailcall-i686-pic.ll
    A llvm/test/Instrumentation/Instrumentor/load_store_gpu_ind.json
    A llvm/test/Instrumentation/Instrumentor/load_store_gpu_ind.ll
    A llvm/test/MC/AMDGPU/amdhsa-kernel-prologue.s
    M llvm/test/MC/AMDGPU/hsa-gfx1250-v4.s
    M llvm/test/MC/AMDGPU/hsa-gfx1251-v4.s
    M llvm/test/MC/Disassembler/WebAssembly/wasm.txt
    A llvm/test/MC/Hexagon/relax-align.s
    M llvm/test/TableGen/true-false.td
    A llvm/test/ThinLTO/X86/Inputs/cache-defined-globals-order.ll
    A llvm/test/ThinLTO/X86/cache-defined-globals-order.ll
    A llvm/test/Transforms/ConstraintElimination/and-negative.ll
    M llvm/test/Transforms/ConstraintElimination/eq.ll
    M llvm/test/Transforms/ConstraintElimination/ne.ll
    M llvm/test/Transforms/ConstraintElimination/reproducer-remarks.ll
    M llvm/test/Transforms/ConstraintElimination/trunc.ll
    A llvm/test/Transforms/IndVarSimplify/iv-widen-addrec-flag-inferred-late.ll
    M llvm/test/Transforms/InstCombine/known-bits.ll
    M llvm/test/Transforms/InstCombine/sincos.ll
    M llvm/test/Transforms/LoopIdiom/cyclic-redundancy-check.ll
    M llvm/test/Transforms/LoopVectorize/VPlan/expand-scev.ll
    M llvm/test/Transforms/LoopVectorize/nested-loops-scev-expansion.ll
    M llvm/test/Transforms/PhaseOrdering/constraint-eliminiation-interactions.ll
    M llvm/test/Transforms/SLPVectorizer/X86/copyable-with-non-scheduled-parent-node.ll
    A llvm/test/Transforms/SLPVectorizer/X86/masked-blended-loads.ll
    M llvm/test/Transforms/SLPVectorizer/X86/mul-shl-nsw-intmin.ll
    A llvm/test/Transforms/SLPVectorizer/sub-nsw-icmp-eq-zero-reorder.ll
    M llvm/test/Transforms/VectorCombine/X86/fold-signbit-reduction-cmp.ll
    M llvm/test/Verifier/matrix-intrinsics.ll
    A llvm/test/tools/llvm-dwp/SystemZ/big_endian_info_v5.s
    M llvm/test/tools/llvm-dwp/X86/compress.test
    A llvm/test/tools/llvm-reduce/remove-funcs-inline-history.ll
    M llvm/tools/llvm-reduce/deltas/ReduceFunctions.cpp
    M llvm/unittests/Frontend/OpenMPIRBuilderTest.cpp
    M llvm/unittests/FuzzMutate/StrategiesTest.cpp
    M llvm/unittests/IR/MetadataTest.cpp
    M llvm/unittests/IR/PatternMatch.cpp
    M llvm/unittests/Target/AMDGPU/AMDGPUMCExprTest.cpp
    M llvm/unittests/Target/AMDGPU/AMDGPUUnitTests.cpp
    M llvm/unittests/Target/AMDGPU/AMDGPUUnitTests.h
    M llvm/unittests/Target/AMDGPU/CSETest.cpp
    M llvm/unittests/Target/AMDGPU/DwarfRegMappings.cpp
    M llvm/unittests/Target/AMDGPU/ExecMayBeModifiedBeforeAnyUse.cpp
    M llvm/unittests/Target/AMDGPU/PALMetadata.cpp
    M llvm/unittests/Target/AMDGPU/UniformityAnalysisTest.cpp
    M llvm/unittests/Transforms/Utils/CodeExtractorTest.cpp
    M llvm/utils/gn/README.rst
    M llvm/utils/gn/build/BUILD.gn
    M llvm/utils/gn/build/BUILDCONFIG.gn
    M llvm/utils/gn/build/buildflags.gni
    M llvm/utils/gn/build/symlink_or_copy.gni
    M llvm/utils/gn/build/toolchain/BUILD.gn
    M llvm/utils/gn/secondary/BUILD.gn
    M llvm/utils/gn/secondary/bolt/tools/driver/BUILD.gn
    M llvm/utils/gn/secondary/clang-tools-extra/clang-doc/tool/BUILD.gn
    M llvm/utils/gn/secondary/clang-tools-extra/clangd/BUILD.gn
    M llvm/utils/gn/secondary/clang-tools-extra/clangd/xpc/framework/BUILD.gn
    M llvm/utils/gn/secondary/clang/lib/Headers/BUILD.gn
    M llvm/utils/gn/secondary/clang/tools/clang-ssaf-linker/BUILD.gn
    M llvm/utils/gn/secondary/clang/tools/driver/BUILD.gn
    M llvm/utils/gn/secondary/lld/tools/lld/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-ar/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-cxxfilt/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-debuginfod-find/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-debuginfod/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-dwp/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-libtool-darwin/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-lipo/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-ml/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-nm/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-objcopy/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-objdump/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-rc/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-readobj/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-readtapi/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-size/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-strings/BUILD.gn
    M llvm/utils/gn/secondary/llvm/tools/llvm-symbolizer/BUILD.gn
    M mlir/lib/Dialect/OpenACC/Transforms/ACCCGToGPU.cpp
    M mlir/test/Integration/Dialect/Vector/CPU/compress.mlir
    M mlir/test/Integration/Dialect/Vector/CPU/expand.mlir
    M mlir/test/Integration/Dialect/Vector/CPU/gather.mlir
    M mlir/test/Integration/Dialect/Vector/CPU/maskedload.mlir
    M mlir/test/Integration/Dialect/Vector/CPU/maskedstore.mlir
    M mlir/test/Integration/Dialect/Vector/CPU/scatter.mlir
    M offload/plugins-nextgen/level_zero/src/L0Plugin.cpp
    M orc-rt/include/CMakeLists.txt
    A orc-rt/include/orc-rt/CCallback.h
    M orc-rt/include/orc-rt/Session.h
    M orc-rt/include/orc-rt/TaskGroup.h
    A orc-rt/test/unit/CCallbackTest.cpp
    M orc-rt/test/unit/CMakeLists.txt
    M orc-rt/test/unit/SessionTest.cpp
    M orc-rt/test/unit/TaskGroupTest.cpp
    M runtimes/cmake/config-Fortran.cmake
    M utils/bazel/.bazelrc
    M utils/bazel/llvm-project-overlay/clang-tools-extra/clangd/BUILD.bazel
    M utils/bazel/llvm-project-overlay/clang-tools-extra/include-cleaner/BUILD.bazel
    M utils/bazel/llvm-project-overlay/clang/BUILD.bazel
    M utils/bazel/llvm-project-overlay/libc/BUILD.bazel
    M utils/bazel/llvm-project-overlay/libc/test/src/sys/socket/BUILD.bazel
    M utils/bazel/llvm-project-overlay/llvm/BUILD.bazel
    M utils/bazel/llvm-project-overlay/llvm/lit_test.bzl
    A utils/bazel/llvm-project-overlay/llvm/utils/lit/BUILD.bazel
    M utils/bazel/llvm-project-overlay/llvm/utils/lit/tests/BUILD.bazel
    M utils/bazel/llvm-project-overlay/mlir/tblgen.bzl
    M utils/bazel/llvm-project-overlay/mlir/test/BUILD.bazel

  Log Message:
  -----------
  Rebase

Created using spr 1.3.7


Compare: https://github.com/llvm/llvm-project/compare/2b43f724c974...aef6bde636a7

To unsubscribe from these emails, change your notification settings at https://github.com/llvm/llvm-project/settings/notifications


More information about the All-commits mailing list